@@ -20,7 +20,7 @@ scriptCaptureR = options[1]
 
 #comes ".../chronojump-captured"
 #will be ".../chronojump-captured-000.txt", 001 ... 999
-filenameBegins = options[2] 
+filenameBegins = options[2]
 
 source(scriptCaptureR)
 
@@ -29,6 +29,12 @@ DebugFileName <- paste(options[5], "/chronojump-debug.txt", sep="")
 
 CROSSVALIDATESMOOTH <- FALSE
 
+if(options[33] == 1) {
+	cutByTriggers <- TRUE
+} else {
+	cutByTriggers <- FALSE
+}
+
 
 f <- file("stdin")
 open(f)
