@@ -60,7 +60,8 @@ assignOptions <- function(options) {
 		    Analysis		= options[11],	
 		    AnalysisVariables	= unlist(strsplit(options[12], "\\;")),
 		    AnalysisOptions	= options[13],
-		    CheckFullyExtended	= as.numeric(options[14]),
+		    #CheckFullyExtended	= as.numeric(options[14]),
+		    CheckFullyExtended	= 0, 	#deactivated just after 1.7.0
 		    EncoderConfigurationName =	options[15],	#just the name of the EncoderConfiguration	
 		    diameter		= as.numeric(unlist(strsplit(options[16], "\\;"))), #comes in cm, will be converted to m. Since 1.5.1 can be different diameters separated by ;
 		    #diameter    = getInertialDiametersPerTick(as.numeric(unlist(strsplit("1.5; 1.75; 2.65; 3.32; 3.95; 4.07; 4.28; 4.46; 4.54; 4.77; 4.96; 5.13; 5.3; 5.55", "\\;")))),
@@ -78,7 +79,11 @@ assignOptions <- function(options) {
 		    Title		= options[27],
 		    OperatingSystem	= options[28],	#if this changes, change it also at call_graph.R
 		    Debug		= options[31],
-		    CrossValidate	= options[32]
+		    CrossValidate	= options[32],
+		    TriggersOn		= as.numeric(unlist(strsplit(options[33], "\\;")))
+		    #TriggerOn on capture is +1/-1 to indicate use or not.
+		    #On analyze is first ms where trigger is pressed at each repetition, or -1 if they are not going to be used
+
 		    #Unassigned here:
 		    #	englishWords [29]
 		    #	translatedWords [30]
@@ -264,20 +269,17 @@ findDistanceAbsoluteEC <- function(position)
 	return ( (maxA - minB) + (maxC - minB) )
 }
 	
-
-getSpeedSafe <- function(displacement, smoothing) {
-	#x vector should contain at least 4 different values
-	if(length(displacement) >= 4)
-		return(getSpeed(displacement, smoothing))
-	else
-		return(list(y=rep(0,length(displacement))))
-}
 #unused since 1.6.0 because first and last displacement values make change too much the initial and end curve
 #getSpeedOld <- function(displacement, smoothing) {
 #	#no change affected by encoderConfiguration
 #	return (smooth.spline( 1:length(displacement), displacement, spar=smoothing))
 #}
-getSpeed <- function(displacement, smoothing) {
+getSpeed <- function(displacement, smoothing)
+{
+	#x vector should contain at least 4 different values
+	if(length(displacement) < 4)
+		return(list(y=rep(0,length(displacement))))
+
 	#no change affected by encoderConfiguration
 	
 	#use position because this does not make erronously change the initial and end of the curve
@@ -531,7 +533,7 @@ kinematicsF <- function(displacement, repOp, smoothingOneEC, smoothingOneC, g, i
 
 	print(c("repOp$eccon, smoothing:", repOp$eccon, smoothing))
 
-	speed <- getSpeedSafe(displacement, smoothing)
+	speed <- getSpeed(displacement, smoothing)
 	
 	accel <- getAccelerationSafe(speed)
 	
@@ -724,8 +726,8 @@ findPropulsiveEnd <- function(accel, concentric, maxSpeedTInConcentric,
 	}
 	else
 		propulsiveEnd = length(concentric)
-	
-return (propulsiveEnd)
+
+	return (propulsiveEnd)
 }
 
 pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, inertiaMomentum) 
@@ -774,7 +776,8 @@ isInertial <- function(encoderConfigurationName) {
 	   encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALMOVPULLEY" ||
 	   encoderConfigurationName == "ROTARYAXISINERTIAL" ||
 	   encoderConfigurationName == "ROTARYAXISINERTIALLATERAL" || 
-	   encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY"
+	   encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY" ||
+	   encoderConfigurationName == "ROTARYAXISINERTIALLATERALMOVPULLEY"
 	   )
 		return(TRUE)
 	else
@@ -802,7 +805,7 @@ getDynamics <- function(encoderConfigurationName,
 	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2" ||
 	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2INV" ||
 	   encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYFRICTION" ||
-	   encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYAXIS" ) 
+	   encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYAXIS")
 	{
 		massExtra = getMass(massExtra, gearedDown, anglePush)
 	} 
@@ -819,21 +822,22 @@ getDynamics <- function(encoderConfigurationName,
 
 #mass extra can be connected to body or connected to a pulley depending on encoderConfiguration
 getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel, 
-				   massBody, massExtra, massTotal,
-				   exercisePercentBodyWeight, gearedDown, anglePush, angleWeight) 
+                                   massBody, massExtra, massTotal,
+                                   exercisePercentBodyWeight, gearedDown, anglePush, angleWeight) 
 { 
-	force = NULL
-	if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
-		force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel)
-	} else if(encoderConfigurationName == "LINEARONPLANE"){
-		force <- (massBody + massExtra)*(accel + g*sin(anglePush * pi / 180))
-	} else {
-		force <- massTotal*(accel+g)	#g:9.81 (used when movement is against gravity)
-	}
+  force = NULL
+  if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
+    force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel)
+    } else if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLEMOVPULLEY") {
+      force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel) / gearedDown
+    } else if(encoderConfigurationName == "LINEARONPLANE"){
+      force <- (massBody + massExtra)*(accel + g*sin(anglePush * pi / 180))
+    } else {
+      force <- massTotal*(accel+g)	#g:9.81 (used when movement is against gravity)
+    }
+  power <- force*speed
 
-	power <- force*speed
-
-	return(list(mass=massTotal, force=force, power=power))
+  return(list(mass=massTotal, force=force, power=power))
 }
 
 #diameter: diameter of the axis (where string is wrapped)
@@ -846,6 +850,8 @@ getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel,
 #  ROTARYFRICTIONAXISINERTIAL Rotary friction encoder connected to inertial machine on the axis
 #  ROTARYAXISINERTIAL Rotary axis encoder  connected to inertial machine on the axis
 #  ROTARYAXISINERTIALMOVPULLEY Rotari axis encoder connected to inertial machine on the axis and the subject pulling from a moving pulley
+#  ROTARYAXISINERTIALLATERALMOVPULLEY Rotari axis encoder connected to inertial machine on the axis and the subject pulling from a moving pulley
+#       and performing and horizontal movement
 
 getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter, mass, inertiaMomentum, gearedDown, smoothing)
 {
@@ -908,10 +914,11 @@ getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter
 
   } else if(encoderConfigurationName == "ROTARYAXISINERTIALLATERAL" ||
               encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALLATERAL" ||
-              encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL"){
-    angle = position.m * 2 / diameter.m
-    angleSpeed = speed * 2 / diameter.m
-    angleAccel = accel * 2 / diameter.m
+              encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL" ||
+              encoderConfigurationName == "ROTARYAXISINERTIALLATERALMOVPULLEY"){
+    angle = position.m * 2 / gearedDown / diameter.m
+    angleSpeed = speed * 2 / gearedDown / diameter.m
+    angleAccel = accel * 2 / gearedDown / diameter.m
     anglePush = 0 #TODO: send from C#
     
     forceDisc = abs(inertiaMomentum * angleAccel) * (2 / diameter.m)
@@ -935,7 +942,7 @@ getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter
 
 
 #in signals and curves, need to do conversions (invert, diameter)
-getDisplacement <- function(encoderConfigurationName, displacement, diameter, diameterExt) {
+getDisplacement <- function(encoderConfigurationName, displacement, diameter, diameterExt, gearedDown) {
 	#no change
 	#WEIGHTEDMOVPULLEYLINEARONPERSON1, WEIGHTEDMOVPULLEYLINEARONPERSON1INV,
 	#WEIGHTEDMOVPULLEYLINEARONPERSON2, WEIGHTEDMOVPULLEYLINEARONPERSON2INV,
@@ -956,6 +963,9 @@ getDisplacement <- function(encoderConfigurationName, displacement, diameter, di
 	  #On geared down machines the displacement of the subject is multiplied by gearedDown
 	  #default is: gearedDown = 2. Future maybe this will be a parameter
 	  displacement = displacement * 2
+  } else if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLEMOVPULLEY")
+  {
+    displacement = displacement * gearedDown
   } else if(encoderConfigurationName == "ROTARYFRICTIONAXIS") 
   {
 	  #On rotary friction axis the displacement of the subject is proportional to the axis diameter
@@ -986,7 +996,8 @@ getDisplacementInertial <- function(displacement, encoderConfigurationName, diam
 	#now convert it to mm of body displacement
 	if(encoderConfigurationName == "ROTARYAXISINERTIAL" ||
 	     encoderConfigurationName == "ROTARYAXISINERTIALLATERAL" ||
-	     encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY") {
+	     encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY" ||
+	     encoderConfigurationName == "ROTARYAXISINERTIALLATERALMOVPULLEY") {
 	        ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks per revolution
 	        
 	        #Number of revolutions that the flywheel rotates every millisecond
@@ -1000,7 +1011,6 @@ getDisplacementInertial <- function(displacement, encoderConfigurationName, diam
 	} else if(encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL" ||
                 encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL" ||
                 encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALMOVPULLEY"){
-	        
 	        displacement = displacement * diameter * gearedDown / diameterExt #displacement of the axis
 	        
 	} else if(encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALMOVPULLEY"){
@@ -1101,115 +1111,116 @@ getDisplacementInertialBody <- function(positionStart, displacement, draw, title
 	return(displacementPerson)
 }
 
+#DISABLED just after 1.7.0
 #used when user captures without string fully extended
 #signal is the information coming from the encoder, graph is to debug
 #see codeExplained/image detect-and-fix-inertial-string-not-fully-extended.png
-fixInertialSignalIfNotFullyExtended <- function(signal, checkRevolutions, saveFile, specialDataFile, graph)
-{
-	write("at fixInertialSignalIfNotFullyExtended", stderr())
-	angle <- cumsum(signal) #360 degrees every 200 ticks
-
-	maximums <- extrema(angle)$maxindex[,1]
-	minimums <- extrema(angle)$minindex[,1]
-	maximumsCopy <- maximums #store this value
-	minimumsCopy <- minimums #store this value
-		
-	#if we have more than 2 max & mins, remove the first and last value
-	if(length(maximums) > 2 & length(minimums) > 2)
-	{
-		#if there's any max extrema value negative (remove it), same for positive min values
-		maximums.temp = NULL
-		minimums.temp = NULL
-		for( i in maximums )
-			if(angle[i] > 0)
-				maximums.temp <- c(maximums.temp, i)
-		for( i in minimums )
-			if(angle[i] < 0)
-				minimums.temp <- c(minimums.temp, i)
-		
-		maximums <- maximums.temp
-		minimums <- minimums.temp
-
-		if(length(maximums) < 1 | length(minimums) < 1)
-			return(signal)
-
-
-		#remove the first value of the maximums OR minimums (just the first one of both)
-		if(maximums[1] < minimums[1])
-			maximums <- maximums[-1]
-		else
-			minimums <- minimums[-1]
-		
-		if(length(maximums) < 1 | length(minimums) < 1)
-			return(signal)
-
-
-		#remove the last value of the maximums OR minimums (just the last one of both)
-		if(maximums[length(maximums)] > minimums[length(minimums)])
-			maximums <- maximums[-length(maximums)]
-		else
-			minimums <- minimums[-length(minimums)]
-		
-	}
-
-	#return if no data
-	if(length(maximums) < 1 | length(minimums) < 1)
-		return(signal)
-
-	#ensure both maximums and minimums have same length
-	while(length(maximums) != length(minimums))
-	{
-		if(length(maximums) > length(minimums))
-			maximums <- maximums[-length(maximums)]
-		else if(length(maximums) < length(minimums))
-			minimums <- minimums[-length(minimums)]
-	}
-
-	meanByExtrema <- mean(c(angle[maximums], angle[minimums]))
-	angleCorrected <- angle - meanByExtrema
-
-	#remove the initial part of the signal. Remove from ms 1 to when angleCorrected crosses 0
-	angleCorrectedCrossZero = extrema(angleCorrected)$cross[1,1]
-
-	if(graph) {
-		par(mfrow=c(1,2))
-
-		#1st graph (left)
-		plot(angle, type="l", lty=2, xlab="time", ylab="Angle", main="String NOT fully extended", 
-		     ylim=c(min(c(angle[minimums], -angle[maximums])) - abs(meanByExtrema), max(c(angle[maximums], -angle[minimums])) + abs(meanByExtrema)))
-		lines(abs(angle)*-1, lwd=2)
-		points(maximumsCopy, angle[maximumsCopy], col="black", cex=1)
-		points(minimumsCopy, angle[minimumsCopy], col="black", cex=1)
-		points(maximums, angle[maximums], col="green", cex=3)
-		points(minimums, angle[minimums], col="green", cex=3)
-		abline(h = meanByExtrema, col="red")
-		text(x = 0, y = meanByExtrema, labels = round(meanByExtrema,2), adj=0)
-
-		#2nd graph (right)
-		plot(angleCorrected, type="l", lty=2, xlab="time", ylab="angle", main="Corrected set", 
-		     ylim=c(min(c(angle[minimums], -angle[maximums])) - 2*abs(meanByExtrema), max(c(angle[maximums], -angle[minimums]))))
-		lines(abs(angleCorrected)*-1, lwd=2)
-		abline(v=c(angleCorrectedCrossZero, length(angleCorrected)), col="green")
-		mtext("Start", at=angleCorrectedCrossZero, side=3, col="green")
-		mtext("EnfixInertialSignalIfNotFullyExtendedd", at=length(angleCorrected), side=3, col="green")
-
-		par(mfrow=c(1,1))
-	}
-
-	#define new signal only if the error in extended string is more than 4 revolutions 
-	#(this value can be changed from gui)
-	if( abs(meanByExtrema) > (checkRevolutions * 200) ) {
-		#write(signal, file="/tmp/old.txt", ncolumns=length(signal), sep=", ")
-		signal <- signal[angleCorrectedCrossZero:length(signal)]
-
-		write("SIGNAL CORRECTED", specialDataFile)
-		
-		#write to file and return displacement to be used
-		write(signal, file=saveFile, ncolumns=length(signal), sep=", ")
-	}
-	
-	return(signal)
-}
+#fixInertialSignalIfNotFullyExtended <- function(signal, checkRevolutions, saveFile, specialDataFile, graph)
+#{
+#	write("at fixInertialSignalIfNotFullyExtended", stderr())
+#	angle <- cumsum(signal) #360 degrees every 200 ticks
+#
+#	maximums <- extrema(angle)$maxindex[,1]
+#	minimums <- extrema(angle)$minindex[,1]
+#	maximumsCopy <- maximums #store this value
+#	minimumsCopy <- minimums #store this value
+#
+#	#if we have more than 2 max & mins, remove the first and last value
+#	if(length(maximums) > 2 & length(minimums) > 2)
+#	{
+#		#if there's any max extrema value negative (remove it), same for positive min values
+#		maximums.temp = NULL
+#		minimums.temp = NULL
+#		for( i in maximums )
+#			if(angle[i] > 0)
+#				maximums.temp <- c(maximums.temp, i)
+#		for( i in minimums )
+#			if(angle[i] < 0)
+#				minimums.temp <- c(minimums.temp, i)
+#
+#		maximums <- maximums.temp
+#		minimums <- minimums.temp
+#
+#		if(length(maximums) < 1 | length(minimums) < 1)
+#			return(signal)
+#
+#
+#		#remove the first value of the maximums OR minimums (just the first one of both)
+#		if(maximums[1] < minimums[1])
+#			maximums <- maximums[-1]
+#		else
+#			minimums <- minimums[-1]
+#
+#		if(length(maximums) < 1 | length(minimums) < 1)
+#			return(signal)
+#
+#
+#		#remove the last value of the maximums OR minimums (just the last one of both)
+#		if(maximums[length(maximums)] > minimums[length(minimums)])
+#			maximums <- maximums[-length(maximums)]
+#		else
+#			minimums <- minimums[-length(minimums)]
+#
+#	}
+#
+#	#return if no data
+#	if(length(maximums) < 1 | length(minimums) < 1)
+#		return(signal)
+#
+#	#ensure both maximums and minimums have same length
+#	while(length(maximums) != length(minimums))
+#	{
+#		if(length(maximums) > length(minimums))
+#			maximums <- maximums[-length(maximums)]
+#		else if(length(maximums) < length(minimums))
+#			minimums <- minimums[-length(minimums)]
+#	}
+#
+#	meanByExtrema <- mean(c(angle[maximums], angle[minimums]))
+#	angleCorrected <- angle - meanByExtrema
+#
+#	#remove the initial part of the signal. Remove from ms 1 to when angleCorrected crosses 0
+#	angleCorrectedCrossZero = extrema(angleCorrected)$cross[1,1]
+#
+#	if(graph) {
+#		par(mfrow=c(1,2))
+#
+#		#1st graph (left)
+#		plot(angle, type="l", lty=2, xlab="time", ylab="Angle", main="String NOT fully extended",
+#		     ylim=c(min(c(angle[minimums], -angle[maximums])) - abs(meanByExtrema), max(c(angle[maximums], -angle[minimums])) + abs(meanByExtrema)))
+#		lines(abs(angle)*-1, lwd=2)
+#		points(maximumsCopy, angle[maximumsCopy], col="black", cex=1)
+#		points(minimumsCopy, angle[minimumsCopy], col="black", cex=1)
+#		points(maximums, angle[maximums], col="green", cex=3)
+#		points(minimums, angle[minimums], col="green", cex=3)
+#		abline(h = meanByExtrema, col="red")
+#		text(x = 0, y = meanByExtrema, labels = round(meanByExtrema,2), adj=0)
+#
+#		#2nd graph (right)
+#		plot(angleCorrected, type="l", lty=2, xlab="time", ylab="angle", main="Corrected set",
+#		     ylim=c(min(c(angle[minimums], -angle[maximums])) - 2*abs(meanByExtrema), max(c(angle[maximums], -angle[minimums]))))
+#		lines(abs(angleCorrected)*-1, lwd=2)
+#		abline(v=c(angleCorrectedCrossZero, length(angleCorrected)), col="green")
+#		mtext("Start", at=angleCorrectedCrossZero, side=3, col="green")
+#		mtext("EnfixInertialSignalIfNotFullyExtendedd", at=length(angleCorrected), side=3, col="green")
+#
+#		par(mfrow=c(1,1))
+#	}
+#
+#	#define new signal only if the error in extended string is more than 4 revolutions
+#	#(this value can be changed from gui)
+#	if( abs(meanByExtrema) > (checkRevolutions * 200) ) {
+#		#write(signal, file="/tmp/old.txt", ncolumns=length(signal), sep=", ")
+#		signal <- signal[angleCorrectedCrossZero:length(signal)]
+#
+#		write("SIGNAL CORRECTED", specialDataFile)
+#
+#		#write to file and return displacement to be used
+#		write(signal, file=saveFile, ncolumns=length(signal), sep=", ")
+#	}
+#
+#	return(signal)
+#}
 
 
 
@@ -1325,12 +1336,27 @@ cvPar <- function(x, y, parRange, cvProp = 0.8) {
 #----------- end spar with crossvalidation -------------
 
 #----------- Begin debug file output -------------
+#http://stackoverflow.com/a/34996874
+write_list <- function (outlist, outfile,append=FALSE) {
+	for (i in 1:length(outlist)) {
+		if (i==1) app=append else app=TRUE
+		if (is.character(outlist[[i]]) || is.numeric(outlist[[i]])) write(paste(outlist[[i]],collapse = " "),outfile, append=app)
+		else
+			if (is.data.frame(outlist[[i]])) write.table(outlist[[i]],outfile, append=app, quote=FALSE, sep="\t")
+			else
+				if (is.POSIXlt(outlist[[i]])) write (as.character(outlist[[i]]),outfile, append=app)
+				else
+					if  (is.list(outlist[[i]])) write_list(outlist = outlist[[i]], outfile, append = TRUE)
+
+	}
+}
+
 debugParameters <- function (parameterList, currentFunction) 
 {
 	if(is.null(DEBUG) || DEBUG == FALSE || is.null(DebugFileName) || DebugFileName == "")
 		return()
 
-        write(paste("Parameters of the", currentFunction, "function are:\n"), DebugFileName, append=TRUE)
+        write(paste("\n\n[Parameters of the", currentFunction, "function are]:\n"), DebugFileName, append=TRUE)
         
         #based on http://stackoverflow.com/a/34996874
         for (i in 1:length(parameterList)) {
@@ -1347,9 +1373,13 @@ debugParameters <- function (parameterList, currentFunction)
 			writedebugParameters(parameterList, i)
                         write(as.character(parameterList[[i]]), DebugFileName, append=TRUE)
                 }
+                else if (is.logical(parameterList[[i]])) {
+			writedebugParameters(parameterList, i)
+                        write(as.character(parameterList[[i]]), DebugFileName, append=TRUE)
+                }
                 else if  (is.list(parameterList[[i]])) {
 			writedebugParameters(parameterList, i)
-                        write_list(parameterList = parameterList[[i]], DebugFileName, append = TRUE)
+                        write_list(parameterList[[i]], DebugFileName, append = TRUE)
                 }
                 else if (is.matrix(parameterList[[i]])) {
 			writedebugParameters(parameterList, i)
@@ -1372,11 +1402,13 @@ test_debugParameters <- function() {
         charVariable = c("Hello", "how", "are", "you")
         dataframeVariable = as.data.frame(matrix(c(10,20,40,50), ncol = 2))
         matrixVariable = matrix(c(100,200,400,500), ncol = 2)
+	booleanVariable = TRUE
 
 	l = list(numVariable = numVariable,
 		 charVariable = charVariable,
 		 dataframeVariable = dataframeVariable,
-		 matrixVariable = matrixVariable)
+		 matrixVariable = matrixVariable,
+		 booleanVariable = booleanVariable)
         
         debugParameters(l, "test_debugParameters")
 }
@@ -1390,3 +1422,4 @@ listN <- function(...){
 }
 
 #----------- End debug file output -------------
+
