@@ -43,7 +43,8 @@ public class ChronoJump
 	private string messageToShowOnBoot = "";
 	private string messageCrashedBefore = "";
 	private bool chronojumpHasToExit = false;
-		
+	private Config configChronojump;
+
 	[Widget] Gtk.Button fakeSplashButton; //raised when splash win ended
 	Thread thread;
 	bool needEndSplashWin = false;
@@ -77,6 +78,15 @@ public class ChronoJump
 		var envPath = Environment.GetEnvironmentVariable ("PATH");
 		var rBinPath = "";
 		baseDirectory = Util.GetPrefixDir();
+
+		/*
+		 * location of gtkrc file
+		 * DISABLED tight now because on windows there are inestabilities on jumps results
+		 * and on Mode menu
+		 */
+		//Rc.AddDefaultFile (Util.GetThemeFile());
+		//LogB.Information("gtk theme:" + Util.GetThemeFile());
+
 		if(UtilAll.IsWindows()) {
 			//Environment.SetEnvironmentVariable ("R_HOME", RelativeToPrefix ("library"));
 			//rBinPath = RelativeToPrefix ("lib");
@@ -191,8 +201,6 @@ public class ChronoJump
 	new ChronoJump(args);
 	}
 
-	bool createdSplashWin = false;
-
 	public static string RelativeToPrefix(string relativePath) {
 		return System.IO.Path.Combine(baseDirectory, relativePath);
 	}
@@ -204,7 +212,6 @@ public class ChronoJump
 
 		//start threading to show splash window
 		SplashWindow.Show();
-		createdSplashWin = true;
 
 		fakeSplashButton = new Gtk.Button();
 		fakeSplashButton.Clicked += new EventHandler(on_splash_ended);
@@ -226,15 +233,24 @@ public class ChronoJump
 	bool allSQLCallsDoneOnSqliteThingsThread;
 
 	//used when Chronojump is being running two or more times (quadriple-click on start)
-	bool quitNow = false;	
+	bool quitNowCjTwoTimes = false;
 
-	protected void sqliteThings () {
-		bool crashedBefore = checkIfChronojumpExitAbnormally();
-		if(crashedBefore) {
-			if(chronojumpIsExecutingNTimes()) {
-				quitNow = true;
+	protected void sqliteThings ()
+	{
+		configChronojump = new Config();
+		configChronojump.Read();
+
+		bool badExit = checkIfChronojumpExitAbnormally();
+		if(badExit) {
+			if(chronojumpIsExecutingNTimes())
+			{
+				messageToShowOnBoot += Catalog.GetString("Chronojump is already running") + "\n\n" +
+					Catalog.GetString("Chronojump will exit now.");
+
+				chronojumpHasToExit = true;
+				quitNowCjTwoTimes = true;
 				LogB.Error("Chronojump is already running.");
-				Application.Quit();
+
 				return;
 			}
 			else
@@ -250,6 +266,8 @@ public class ChronoJump
 		Util.CreateMultimediaDirsIfNeeded();
 		//to store encoder data and graphs
 		UtilEncoder.CreateEncoderDirIfNeeded();
+		//to store force sensor data and graphs
+		Util.CreateForceSensorDirIfNeeded();
 
 //TODO: when a session is deleted, encoder data has to be deleted, also multimedia videos, I suppose. Show message to user warning about it
 //TODO: encoder weight auto written depending on person loaded, and changes if it changes person or weight
@@ -384,24 +402,6 @@ public class ChronoJump
 
 		//connect to server to Ping
 		versionAvailable = "";
-		/*
-		pingStart = false;
-		pingEnd = false;
-		
-		// disable server connection on start until server is not working on windows again 
-		bool connectServerAtStart = false;
-		if(connectServerAtStart) {
-			thread = new Thread(new ThreadStart(findVersion));
-			GLib.Idle.Add (new GLib.IdleHandler (PulseGTKPing));
-			thread.Start(); 
-		
-			//wait until pinging process start
-			while(! pingStart) {
-			}
-		}
-		else
-			on_find_version_cancelled(new object(), new EventArgs());
-		*/
 		versionAvailable = Constants.ServerOffline;
 	
 
@@ -455,7 +455,7 @@ public class ChronoJump
 
 
 		//if chronojump chrashed before
-		if(crashedBefore) {
+		if(badExit) {
 			if( versionAvailableKnown.Length > 0 && new Version(versionAvailableKnown) > new Version(progVersion) ) 
 				messageToShowOnBoot += "\n" + Catalog.GetString("Chronojump crashed before.") + "\n" +
 				       Catalog.GetString("Please, update to new version: ") + versionAvailableKnown + "\n";
@@ -489,82 +489,74 @@ public class ChronoJump
 
 	}
 
-	private void findVersion() {
-		LogB.Debug("--1--");
-		//pingStart = true;
-
-		LogB.Debug("--2--");
-		//maybe other thread doesn't create at time the splash win
-		//then just wait
-		while(! createdSplashWin)
-			;
-		
-		LogB.Debug("--2.1--");
-			
-		try {
-			if(splashWin.FakeButtonCreated)
-				LogB.Information("Created splashWin.FakeButton");
-			else
-				LogB.Warning("NOT Created splashWin.FakeButton, si es bloqueja, posar aquí un while (mentre no estigui creat)");
-
-			splashWin.FakeButtonCancel.Clicked += new EventHandler(on_find_version_cancelled);
-
-			LogB.Debug("--3--");
-		} catch {
-			LogB.Warning("Problem with splash win");
-		}
-
-		versionAvailable = Server.Ping(true, progName, UtilAll.ReadVersion()); //doInsertion
-		
-		LogB.Debug("--4--");
-		LogB.Information(" version:  ", versionAvailable);
-		LogB.Debug("\n--5--");
-		//pingEnd = true;
-		LogB.Debug("--6--");
-	}
-		
 	private void on_find_version_cancelled(object o, EventArgs args) {
 		versionAvailable = Constants.ServerOffline;
 		//pingEnd = true;
 	}
 
-	protected void readMessageToStart() {
-		if(messageToShowOnBoot.Length > 0) {
-			ErrorWindow errorWin;
-			if(chronojumpHasToExit) {
-				messageToShowOnBoot += "\n<b>" + string.Format(Catalog.GetString("Chronojump will exit now.")) + "</b>\n";
-
-				errorWin = ErrorWindow.Show(messageToShowOnBoot);
-				errorWin.Show_button_open_database_folder();
-				errorWin.Button_accept.Clicked += new EventHandler(on_message_boot_accepted_quit);
-			} else { 
-				errorWin = ErrorWindow.Show(messageToShowOnBoot);
-				errorWin.Show_send_log();
-				errorWin.ProgVersion = progVersion;
-				errorWin.Button_accept_label(Catalog.GetString("Open Chronojump"));
-				errorWin.Button_accept.Clicked += new EventHandler(on_message_boot_accepted_continue);
+	protected void readMessageToStart()
+	{
+		//don't show error message at start if Compujump
+		if(messageToShowOnBoot.Length > 0 && ! configChronojump.Compujump)
+		{
+			if(chronojumpHasToExit)
+			{
+				if(quitNowCjTwoTimes) {
+					splashWin.UpdateLabel(messageToShowOnBoot);
+					splashWin.FakeButtonClose.Clicked += new EventHandler(on_message_boot_accepted_quit_not_deleting_runningfilename);
+				} else {
+					messageToShowOnBoot += "\n<b>" + string.Format(Catalog.GetString("Chronojump will exit now.")) + "</b>\n";
+					splashWin.UpdateLabel(messageToShowOnBoot);
+					splashWin.Show_button_open_database_folder();
+					splashWin.Button_close.Clicked += new EventHandler(on_message_boot_accepted_quit_nice);
+				}
+				splashWin.ShowButtonClose();
+			} else {
+				startChronojump(true); //sendLog
 			}
 		} else {
-			startChronojump();
+			startChronojump(false);
 		}
 	}
 
-	private void on_message_boot_accepted_continue (object o, EventArgs args) {
-		startChronojump();
+	private void on_message_boot_accepted_continue (object o, EventArgs args)
+	{
+		startChronojump(false);
 	}
 
-	private void on_message_boot_accepted_quit (object o, EventArgs args) {
-		try {
-			File.Delete(runningFileName);
-		} catch {
-			//done because if database dir is moved in a chronojump conversion (eg from before installer to installjammer) maybe it will not find this runningFileName
+	private void on_message_boot_accepted_quit_nice (object o, EventArgs args)
+	{
+		quitChronojump(true);
+	}
+	private void on_message_boot_accepted_quit_not_deleting_runningfilename (object o, EventArgs args)
+	{
+		quitChronojump(false);
+	}
+	private void quitChronojump(bool deleteRunningFileName)
+	{
+		if(deleteRunningFileName)
+		{
+			try {
+				File.Delete(runningFileName);
+			} catch {
+				//done because if database dir is moved in a chronojump conversion
+				//(eg from before installer to installjammer) maybe it will not find this runningFileName
+			}
 		}
-		Log.End();
-		//Log.Delete();
+
+		if(splashWin != null)
+			splashWin.Destroy();
+		else
+			SplashWindow.Hide();
+
+		if(! quitNowCjTwoTimes)
+			Log.End();
+
 		Application.Quit();
 	}
 
-	private void startChronojump() {
+
+	private void startChronojump(bool sendLog) {
 
 		//wait until all sql calls are done in other thread
 		//then there will be no more a try to open an already opened dbcon
@@ -573,7 +565,10 @@ public class ChronoJump
 		}
 		LogB.SQL("all SQL done! starting Chronojump");
 
-		new ChronoJumpWindow(progVersion, progName, runningFileName);
+		if(sendLog)
+			new ChronoJumpWindow(progVersion, progName, runningFileName, splashWin, true, messageToShowOnBoot);
+		else
+			new ChronoJumpWindow(progVersion, progName, runningFileName, splashWin, false, "");
 	}
 
 	private static void createBlankDB() {
@@ -605,19 +600,16 @@ public class ChronoJump
 	/* splash window things 
 	 * --------------------*/
 
-	private void splashMessageChange(int messageInt) {
+	private void splashMessageChange(int messageInt)
+	{
 	       splashMessage = Catalog.GetString(Constants.SplashMessages[messageInt]);
-		needUpdateSplashMessage = true;
+	       needUpdateSplashMessage = true;
+	       System.Threading.Thread.Sleep(50);
 	}
 	
 	protected bool PulseGTK ()
 	{
-		if(quitNow) 
-			return false;
-
-		//if( ( needEndSplashWin && pingEnd ) 
-		//		|| ! thread.IsAlive) {
-		if( needEndSplashWin || ! thread.IsAlive ) {
+		if( quitNowCjTwoTimes || needEndSplashWin || ! thread.IsAlive ) {
 			LogB.ThreadEnding();
 			fakeSplashButton.Click();
 
@@ -656,39 +648,16 @@ public class ChronoJump
 		return true;
 	}
 	
-	private void on_splash_ended(object o, EventArgs args) {
+	private void on_splash_ended(object o, EventArgs args)
+	{
 		LogB.Information("splash screen going to END");
 		fakeSplashButton.Clicked -= new EventHandler(on_splash_ended);
-		if(splashWin != null)
-			splashWin.Destroy();
-		else
-			SplashWindow.Hide();
 
 		LogB.Information("splash screen ENDED!");
+
 		readMessageToStart();
 	}
 
-	/*
-	protected bool PulseGTKPing ()
-	{
-		if(pulseGTKPingShouldEnd) {
-			splashWin.CancelButtonShow(false);
-			LogB.Information("ping going to END");
-			return false;
-		}
-
-		if(splashShowButton)
-			splashWin.CancelButtonShow(true); //show cancel button on splash win
-		else
-			splashWin.CancelButtonShow(false);
-
-		Thread.Sleep (50);
-		LogB.Debug(" (PulseGTKPing:" + thread.ThreadState.ToString() + ") ");
-		if(thread.ThreadState == System.Threading.ThreadState.Stopped)
-			pulseGTKPingShouldEnd = true;
-		return true;
-	}
-	*/
 	
 	/* ---------------------
 	 * other support methods 
