@@ -141,6 +141,8 @@ public class Constants
 	public const string EncoderExerciseTable = "encoderExercise";
 	public const string Encoder1RMTable = "encoder1RM";
 	public const string ExecuteAutoTable = "executeAuto";
+	public const string TriggerTable = "trigger";
+	public const string ForceRFDTable = "forceRFD";
 
 	// Dummy variables that exists for translating purposes
 	// pragma warning is to avoid warnings of "defined and not used" for these variables.
@@ -192,6 +194,11 @@ public class Constants
 	public static string SimulatedTestsNotAllowed = Catalog.GetString("Chronopic is disconnected.") + "\n\n" + 
 		string.Format(Catalog.GetString("If you want to simulate tests, use {0} session."), "SIMULATED");
 
+	//Compujump strings
+	public static string RFIDDisconnectedMessage = Catalog.GetString("RFID cable has been disconnected!") + "\n\n" +
+		Catalog.GetString("Please, connect it and restart Chronojump.");
+	public static string RFIDNotInServerMessage = Catalog.GetString("This RFID is not registered on server.");
+
 	//server
 	public const string ServerPingTable = "SPing"; 
 	public const string ServerEvaluatorTable = "SEvaluator"; 
@@ -237,8 +244,16 @@ public class Constants
 	public static string TakeOffWeightName = "TakeOffWeight"; //translate (take off?)
 
 
-	public static string SpreadsheetString = "\n\n" + Catalog.GetString("When import from your spreadsheet (OpenOffice, R, MS Excel, ...)\nremember the separator character is semicolon <b>;</b>, or comma <b>,</b>.") + 
-			"\n\n" + Catalog.GetString("This can be changed on preferences.");
+	public static string GetSpreadsheetString(string CSVExportDecimalSeparator)
+	{
+		string sep = ";";
+		if(CSVExportDecimalSeparator != "COMMA")
+			sep = ",";
+
+		return "\n\n" + Catalog.GetString("Importing from your spreadsheet (LibreOffice, R, MS Excel, ...)") + "\n" +
+			Catalog.GetString("Remember the separator character is:") + " <b>" + sep + "</b>" + "\n\n" +
+			Catalog.GetString("This can be changed at preferences.");
+	}
 
 /*	OLD, check this
 	public static string PotencyLewisCMJFormula = Catalog.GetString("Peak Power")+ " CMJ (Lewis) " +
@@ -421,13 +436,8 @@ public class Constants
 	public static string FileNameCSVName1Icon = "import-csv-name-1-column.png";
 	public static string FileNameCSVName2Icon = "import-csv-name-2-columns.png";
 
-	public static string FileNameJumps = "stock_up.png";
-	public static string FileNameJumpsRJ = "stock_up_down.png";
-	public static string FileNameRuns = "stock_right.png";
-	public static string FileNameRunsInterval = "stock_right_left.png";
 	public static string FileNameEncoderGravitatory = "stock_down.png";
 	public static string FileNameEncoderInertial = "stock_inertial.png";
-	public static string FileNameReactionTime = "reaction_time_menu.png";
 	public static string FileNamePulse = "pulse_menu.png";
 	public static string FileNameMultiChronopic = "multichronopic_menu.png";
 	
@@ -592,13 +602,17 @@ public class Constants
 	};
 
 	public static string [] SplashMessages = {
-		Catalog.GetString("Initializing"),		//0
-		Catalog.GetString("Checking database"),		//1
-		Catalog.GetString("Creating database"),		//2
-		Catalog.GetString("Making database backup"),	//3
-		Catalog.GetString("Updating database"),		//4
-		Catalog.GetString("Connecting to server"),	//5
-		Catalog.GetString("Preparing main Window"),	//6
+		"Initializing",			//0
+		"Checking database",		//1
+		"Creating database",		//2
+		"Making database backup",	//3
+		"Updating database",		//4
+		"Connecting to server",		//5
+		"Preparing main Window",	//6
+		"Loading preferences",		//7
+		"Creating widgets", 		//8
+		"Creating encoder widgets", 	//9
+		"Starting main window", 	//10
 	};
 	
 	public static string DatabaseNotFound = Catalog.GetString("Error. Cannot find database.");
@@ -656,7 +670,7 @@ public class Constants
 		//Catalog.GetString("P = 24.6 * (Total time + Flight time) / Contact time") + 
 		Catalog.GetString("Jumps with TC and TF:") + " " + Catalog.GetString("Developed by Chronojump team") + 
 		"\n" +
-		Catalog.GetString("Calcule the potential energies on fall and after the jump.") + "\n" + 
+		Catalog.GetString("Calculate the potential energies on fall and after the jump.") + "\n" +
 		Catalog.GetString("Divide them by time during force is applied.") +
 		"\n\n" +
 		//P = mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tt;
@@ -709,10 +723,15 @@ public class Constants
 	public static string CameraNotFound = Catalog.GetString("Sorry, no cameras found.");
 	
 	public enum BellModes {
-		JUMPS, RUNS, ENCODER
+		JUMPS, RUNS, ENCODERGRAVITATORY, ENCODERINERTIAL
 	}
 
-	public enum Menuitem_modes { JUMPSSIMPLE, JUMPSREACTIVE, RUNSSIMPLE, RUNSINTERVALLIC, POWERGRAVITATORY, POWERINERTIAL, OTHER }
+	public enum Menuitem_modes {
+		UNDEFINED,
+		JUMPSSIMPLE, JUMPSREACTIVE,
+		RUNSSIMPLE, RUNSINTERVALLIC,
+		POWERGRAVITATORY, POWERINERTIAL,
+		FORCESENSOR, RT, OTHER } //OTHER can be: Multichronopic, Pulse
 
 	public static string All = "All";
 	public static string None = "None";
@@ -792,6 +811,7 @@ public class Constants
 	public static string FileNameEncoderWeightedMovPulleyOnLinearEncoder = "encoder-linear-on-weighted-moving-pulley.png";
 	public static string FileNameEncoderLinearOnPlane = "encoder-linear-inclined-plane.png";	
 	public static string FileNameEncoderLinearOnPlaneWeightDiffAngle = "encoder-linear-inclined-plane-weight-diff-angle.png";	
+	public static string FileNameEncoderLinearOnPlaneWeightDiffAngleMovPulley = "encoder-linear-inclined-plane-weight-diff-angle-mov-pulley.png";
 
 	//rotary friction
 	public static string FileNameEncoderFrictionSide = "encoder-rotary-friction-pulley.png";
@@ -809,6 +829,7 @@ public class Constants
 	public static string FileNameEncoderAxisInertial = "encoder-rotary-axis-inertial.png";
 	public static string FileNameEncoderAxisInertialLateral = "encoder-rotary-axis-inertial-lateral.png";
 	public static string FileNameEncoderAxisInertialMovPulley = "encoder-rotary-axis-inertial-mov-pulley.png";
+	public static string FileNameEncoderAxisInertialMovPulleyLateral = "encoder-rotary-axis-inertial-mov-pulley-lateral.png";
 	public static string FileNameEncoderAxisWithMovPulley = "encoder-rotary-axis-on-fixed-pulley-with-weighted-moving-pulley.png";
 	
 	public static string FileNameEncoderCalculeIM = "encoder-calcule-im.png";	
@@ -819,7 +840,7 @@ public class Constants
 		WEIGHTEDMOVPULLEYLINEARONPERSON1, WEIGHTEDMOVPULLEYLINEARONPERSON1INV,
 		WEIGHTEDMOVPULLEYLINEARONPERSON2, WEIGHTEDMOVPULLEYLINEARONPERSON2INV,
 		WEIGHTEDMOVPULLEYONLINEARENCODER, 
-		LINEARONPLANE, LINEARONPLANEWEIGHTDIFFANGLE, 
+		LINEARONPLANE, LINEARONPLANEWEIGHTDIFFANGLE, LINEARONPLANEWEIGHTDIFFANGLEMOVPULLEY,
 		// ---- ROTARY FRICTION ----
 		ROTARYFRICTIONSIDE, ROTARYFRICTIONAXIS,
 		WEIGHTEDMOVPULLEYROTARYFRICTION,
@@ -828,7 +849,7 @@ public class Constants
 		ROTARYFRICTIONSIDEINERTIALMOVPULLEY, ROTARYFRICTIONAXISINERTIALMOVPULLEY,
 		// ---- ROTARY AXIS ----
 		ROTARYAXIS, WEIGHTEDMOVPULLEYROTARYAXIS,
-		ROTARYAXISINERTIAL, ROTARYAXISINERTIALLATERAL, ROTARYAXISINERTIALMOVPULLEY
+		ROTARYAXISINERTIAL, ROTARYAXISINERTIALLATERAL, ROTARYAXISINERTIALMOVPULLEY, ROTARYAXISINERTIALLATERALMOVPULLEY
 	}
 
 	public static string DefaultEncoderConfigurationCode = "Linear - barbell";
