@@ -33,6 +33,7 @@ public abstract class EncoderCapture
 	public int Countdown;
 	
 	//stored to be realtime displayed
+	//this is unused if showOnlyBars (configChronojump.EncoderCaptureShowOnlyBars)
 	public List<Gdk.Point> EncoderCapturePoints;
 	public List<Gdk.Point> EncoderCapturePointsInertialDisc;
 	public int EncoderCapturePointsCaptured;
@@ -51,14 +52,22 @@ public abstract class EncoderCapture
 
 	protected static List<int> encoderReaded;	//data coming from encoder and converted
 	protected static List<int> encoderReadedInertialDisc;	//data coming from encoder and converted
+
+	private int TRIGGER_ON = 84; //'T' from TRIGGER_ON on encoder firmware
+	private int TRIGGER_OFF = 116; //'t' from TRIGGER_OFF on encoder firmware
+
+	//private BoolMsList boolMsList;
+	private TriggerList triggerList;
+
+	private int lastTriggerOn;
 	
 	/*
-	 * sum: sum ob byteReaded, it's the vertical position
+	 * sum: sum on byteReaded, it's the vertical position
 	 * sumInertialDisc: on inertial this has the sum of the disc, while sum has the position of the body (always <= 0 (starting position))
 	 * on inertial we need both
 	 */
 	protected double sum;	
-	protected double sumInertialDisc;
+	protected int sumInertialDisc;
 
 	protected int i;
 	protected int msCount;
@@ -77,60 +86,48 @@ public abstract class EncoderCapture
 	protected int consecutiveZerosMax;
 		
 	//specific of some subclasses
-	protected bool inertialShouldCheckStartDirection;
-	protected bool inertialCaptureDirectionInverted;
 	protected bool lastDirectionStoredIsUp;
 	protected bool capturingFirstPhase;
 
+	protected static SerialPort sp;
+	private Random rand;
+	protected bool finish;
+	protected bool capturingInertialBG;
+	protected bool showOnlyBars;
+
+	//get the moment where we cross 0 first time on inertial calibrated
+	//signal will be saved from here
+	protected int inertialCalibratedFirstCross0Pos;
+	protected bool inertialCalibrated;
+
 	//capture is simulated (a signal file is readed)
-	private static bool simulated = false;
-	private int [] simulatedInts;
-	private int simulatedCount;
+	private bool simulated = false;
+	//private int [] simulatedInts;
+	//private int simulatedCount;
 
 	
 	// ---- private stuff ----
-		
-	private static SerialPort sp;
 	private bool cancel;
-	private bool finish;
-	
-	/*
-	public static bool CheckPort(string port)
-	{
-		if(File.Exists(UtilAll.GetECapSimSignalFileName())) { //simulatedEncoder
-			simulated = true;
-			return true;
-		}
 
-		simulated = false;
-
-		LogB.Information("testing encoder port: ", port);
-		sp = new SerialPort(port);
-		sp.BaudRate = 115200;
-		LogB.Information("testing 1: sp created");
-		try {
-			sp.Open();
-			LogB.Information("testing 2: sp opened");
-			sp.Close();
-			LogB.Information("testing 3: sp closed. Success!");
-		} catch {
-			LogB.Error("testing encoder port failed");
-			return false;
-		}
-		return true;
-	}
-	*/
 
 	//if cont (continuous mode), then will not end when too much time passed before start
-	public void InitGlobal (int widthG, int heightG, int time, int timeEnd, bool cont, string eccon, string port)
+	public void InitGlobal (int widthG, int heightG, int time, int timeEnd, bool cont, string eccon, string port, bool capturingInertialBG, bool showOnlyBars, bool simulated)
 	{
 		this.widthG = widthG;
 		this.heightG = heightG;
 		this.cont = cont;
 		this.eccon = eccon;
-		
+		this.capturingInertialBG = capturingInertialBG;
+		this.showOnlyBars = showOnlyBars;
+		this.simulated = simulated;
+
 		//---- a) open port -----
-		if(! simulated) {
+		if(simulated)
+		{
+			rand = new Random(40);
+			SimulatedReset();
+		}
+		else if(! simulated && ! capturingInertialBG) {
 			LogB.Debug("runEncoderCaptureCsharp start port:", port);
 			sp = new SerialPort(port);
 			sp.BaudRate = 115200;
@@ -151,10 +148,15 @@ public abstract class EncoderCapture
 
 		encoderReaded = new List<int>();
 		encoderReadedInertialDisc = new List<int>();
-		EncoderCapturePoints = new List<Gdk.Point>();
-		EncoderCapturePointsInertialDisc = new List<Gdk.Point>();
-		EncoderCapturePointsCaptured = 0;
-		EncoderCapturePointsPainted = 0; 	//-1 means delete screen
+
+		if(! showOnlyBars)
+		{
+			EncoderCapturePoints = new List<Gdk.Point>();
+			EncoderCapturePointsInertialDisc = new List<Gdk.Point>();
+			EncoderCapturePointsCaptured = 0;
+			EncoderCapturePointsPainted = 0; 	//-1 means delete screen
+		}
+
 		sum = 0;
 		
 		i = -20; //delete first records because there's encoder bug
@@ -186,32 +188,54 @@ public abstract class EncoderCapture
 		lastNonZero = 0;
 		
 		//this will be used to stop encoder automatically (on !cont mode)
+		//or to save this set and wait for the next on cont mode
 		consecutiveZeros = -1;		
 		consecutiveZerosMax = timeEnd * 1000;
-	
-		//only can be true on inertial capture subclass
-		inertialShouldCheckStartDirection = false;
-		inertialCaptureDirectionInverted = false;
 
 		initSpecific();
 
+		//prepare for receiving triggers from encoder
+		triggerList = new TriggerList();
+		Util.FileDelete(Util.GetEncoderTriggerFileName());
+
 		cancel = false;
 		finish = false;
 	}
-	
+
 	protected virtual void initSpecific()
 	{
 	}
 
-	public bool Capture(string outputData1, EncoderRProcCapture encoderRProcCapture)
+	public virtual void InitCalibrated(int angleNow)
 	{
+		inertialCalibrated = false;
+	}
+
+	public bool Capture(string outputData1, EncoderRProcCapture encoderRProcCapture, bool compujump, bool cutByTriggers)
+	{
+		/*
+		 * removed at 1.7.0
 		if(simulated) {
 			bool success = initSimulated();
 			if(! success)
 				return false;
 		}
+		*/
+
+		lastTriggerOn = 0;
+		inertialCalibratedFirstCross0Pos = 0;
+
+		if(capturingInertialBG)
+		{
+			/*
+			 * reset capture list. If not done here, list will grow at each set
+			 * also this fixes the initial 0s after a set
+			 */
+			EncoderCaptureInertialBackgroundStatic.Initialize();
+		}
 
 		do {
+			//1 read data
 			try {
 				byteReaded = readByte();
 			} catch {
@@ -223,7 +247,56 @@ public abstract class EncoderCapture
 				break;
 			}
 
+			//2 check if readed data is a trigger
+			if(byteReaded == TRIGGER_ON)
+			{
+				Trigger trigger = new Trigger(Trigger.Modes.ENCODER, i, true);
+				if(triggerList.IsSpurious(trigger))
+				{
+					triggerList.RemoveLastOff();
+					continue;
+				}
+
+				if(cutByTriggers)
+				{
+					ecc = new EncoderCaptureCurve(lastTriggerOn, i);
+					lastTriggerOn = i;
+
+					double [] curve = new double[ecc.endFrame - ecc.startFrame];
+					//int mySum = 0;
+					for(int k=0, j=ecc.startFrame; j < ecc.endFrame ; j ++) {
+						curve[k] = encoderReaded[j];
+						k ++;
+						//mySum += encoderReaded[j];
+					}
+					//ecc.up = (mySum >= 0);
+					ecc.up = true; //make all concentric for the swimming application
+					LogB.Debug("curve stuff" + ecc.startFrame + ":" + ecc.endFrame + ":" + encoderReaded.Count);
+
+					bool success = encoderRProcCapture.SendCurve(
+							ecc.startFrame,
+							UtilEncoder.CompressData(curve, 25)	//compressed
+							);
+					if(! success)
+						cancel = true;
+
+					Ecca.curvesAccepted ++;
+					Ecca.ecc.Add(ecc);
+					LogB.Information(ecc.ToString());
+				}
+				triggerList.Add(trigger);
+				continue;
+			}
+			else if(byteReaded == TRIGGER_OFF)
+			{
+				Trigger trigger  = new Trigger(Trigger.Modes.ENCODER, i, false);
+				triggerList.Add(trigger);
+				continue;
+			}
+
+			//3 if is not trigger: convertByte
 			byteReaded = convertByte(byteReaded);
+			//LogB.Information(" byte: " + byteReaded);
 
 			i = i+1;
 			if(i >= 0) 
@@ -231,11 +304,40 @@ public abstract class EncoderCapture
 				if(cont)
 					recordedTimeCont ++;
 
-				if(inertialCaptureDirectionInverted)
-					byteReaded *= -1;
-
 				if(byteReaded == 0)
+				{
 					consecutiveZeros ++;
+
+					//clean variables when we are on cont and long time elapsed
+					if(cont && Ecca.curvesAccepted == 0 && consecutiveZeros >= consecutiveZerosMax)
+					{
+						LogB.Information("Cleaning on capture");
+
+						//remove this time on existing trigger records
+						triggerList.Substract(consecutiveZeros);
+
+						consecutiveZeros = -1;
+						encoderReadedInertialDisc = new List<int>();
+						encoderReaded = new List<int>();
+
+						if(capturingInertialBG)
+						{
+							//empty EncoderCaptureInertialBackgroundStatic.ListCaptured
+							EncoderCaptureInertialBackgroundStatic.Initialize();
+						}
+
+						if(! showOnlyBars)
+						{
+							EncoderCapturePoints = new List<Gdk.Point>();
+							EncoderCapturePointsInertialDisc = new List<Gdk.Point>();
+							EncoderCapturePointsCaptured = 0;
+							EncoderCapturePointsPainted = -1; 	//-1 means delete screen
+						}
+
+						i = -1; //will be 0 on next loop start
+						continue;
+					}
+				}
 				else
 					consecutiveZeros = -1;
 
@@ -254,26 +356,35 @@ public abstract class EncoderCapture
 					finish = true;
 					LogB.Information("SHOULD FINISH");
 				}
-				
+
+
+				//on inertialCalibrated set mark where 0 is crossed for the first time
+				if(inertialCalibrated && inertialCalibratedFirstCross0Pos == 0)
+				{
+					if( ( sumInertialDisc <= 0 && sumInertialDisc + byteReaded > 0 ) ||
+							( sumInertialDisc >= 0 && sumInertialDisc + byteReaded < 0 ) )
+						inertialCalibratedFirstCross0Pos = i;
+				}
 
 				sumInertialDisc += byteReaded;
 				encoderReadedInertialDisc.Add(byteReaded);
 
-				if(inertialChangedConToEcc())
+				if(inertialCalibrated && sumInertialDisc > 0)
 					byteReaded *= -1;
 
 				sum += byteReaded;
 				encoderReaded.Add(byteReaded);
 
-				assignEncoderCapturePoints();
-				
-				EncoderCapturePointsCaptured = i;
 
-				//this only applies to inertial subclass
-				if(inertialShouldCheckStartDirection)
-					inertialCheckIfInverted();
+				if(! showOnlyBars)
+				{
+					assignEncoderCapturePoints();
 
-				encoderCapturePointsAdaptativeDisplay();
+					EncoderCapturePointsCaptured = i;
+				}
+
+				if(! showOnlyBars)
+					encoderCapturePointsAdaptativeDisplay();
 
 				// ---- prepare to send to R ----
 
@@ -296,6 +407,7 @@ public abstract class EncoderCapture
 				if(directionNow != directionLastMSecond) {
 					directionLastMSecond = directionNow;
 					directionChangeCount = 0;
+
 				} 
 				else if(directionNow != directionCompleted) {
 					//we are in a different direction than the last completed
@@ -308,6 +420,18 @@ public abstract class EncoderCapture
 						sendCurveMaybe = true;
 				}
 
+				/*
+				 * on inertialCalibrated don't send curve until 0 is crossed
+				 * this ensures first stored phase will be ecc, that's what the rest of the program is expecting
+				 * TODO: maybe this can be problematic with triggers maybe can be desinchronized, just move values
+				 */
+				if(inertialCalibrated && inertialCalibratedFirstCross0Pos == 0)
+					sendCurveMaybe = false;
+
+				//if cutByTriggers, triggers send the curve at the beginning of this method
+				if(cutByTriggers)
+					sendCurveMaybe = false;
+
 				if(sendCurveMaybe)
 				{
 					//int startFrame = previousFrameChange - directionChangeCount;	//startFrame
@@ -331,6 +455,10 @@ public abstract class EncoderCapture
 					if(startFrame < 0)
 						startFrame = 0;
 
+					//on inertial start when crossing 0 first time
+					if(inertialCalibrated && startFrame < inertialCalibratedFirstCross0Pos)
+						startFrame = inertialCalibratedFirstCross0Pos;
+
 					LogB.Information("TTTT - i," + i.ToString() +
 						       	"; directionChangeCount: " + 
 						       	directionChangeCount.ToString() + 
@@ -402,13 +530,23 @@ public abstract class EncoderCapture
 						 */
 
 
-						if( shouldSendCurve() ) {
-							encoderRProcCapture.SendCurve(
+						if( shouldSendCurve() )
+						{
+							//if compujump, wakeup screen if it's off
+							//do it on the first repetition because it will not be sleeping on the rest of repetitions
+							if(compujump && Ecca.curvesAccepted == 0)
+								Networks.WakeUpRaspberryIfNeeded();
+
+							bool success = encoderRProcCapture.SendCurve(
+									ecc.startFrame,
 									UtilEncoder.CompressData(curve, 25)	//compressed
 									);
+							if(! success)
+								cancel = true;
 
 							Ecca.curvesAccepted ++;
 							Ecca.ecc.Add(ecc);
+							LogB.Information(ecc.ToString());
 
 							lastDirectionStoredIsUp = ecc.up;
 						}
@@ -433,19 +571,21 @@ public abstract class EncoderCapture
 		//leave some time to capture.R be able to paint data, and to create two Roptions.txt file correctly
 		if(simulated)
 			System.Threading.Thread.Sleep(2000);
-		else 
+		else if(! capturingInertialBG)
 			sp.Close();
 
 		if(cancel)
 			return false;
 
 		saveToFile(outputData1);
-		
+
 		LogB.Debug("runEncoderCaptureCsharp ended");
 
 		return true;
 	}
 
+	/*
+	 * removed at 1.7.0
 	private bool initSimulated()
 	{
 		if(! File.Exists(UtilAll.GetECapSimSignalFileName()))
@@ -455,16 +595,62 @@ public abstract class EncoderCapture
 		simulatedInts = Util.ReadFileAsInts(filename);
 		return true;
 	}
+	*/
 
-	private int readByte() 
+	private bool simulatedGoingUp = false;
+	private int simulatedMaxValue = 400;
+	private int simulatedLength;
+	private int simulatedMaxLength = 4000; //when signal stops
+
+	public void SimulatedReset()
 	{
+		simulatedLength = 0;
+	}
+
+	private int simulateByte()
+	{
+		System.Threading.Thread.Sleep(1);
+
+		//return 0's to end if signal needs to end
+		simulatedLength ++;
+		if(simulatedLength > simulatedMaxLength)
+			return 0;
+
+		//get new value
+		int simValue;
+		if(simulatedGoingUp)
+			simValue = rand.Next(0, 4);
+		else
+			simValue = rand.Next(-4, 0);
+
+		//change direction if needed
+		if(simulatedGoingUp && sum > simulatedMaxValue)
+			simulatedGoingUp = false;
+		else if(! simulatedGoingUp && sum < -1 * simulatedMaxValue)
+			simulatedGoingUp = true;
+
+		return simValue;
+	}
+
+	protected int readByte()
+	{
+		/*
+		 * removed at 1.7.0
 		if(simulated) {
 			return simulatedInts[simulatedCount ++];
 		} else {
-			return sp.ReadByte();
-		}
+		*/
+			if(capturingInertialBG)
+				return (int) EncoderCaptureInertialBackgroundStatic.GetNext();
+			else {
+				if(simulated)
+					return simulateByte();
+				else
+					return sp.ReadByte();
+			}
+		//}
 	}
-	private int convertByte(int b) 
+	protected int convertByte(int b)
 	{
 		if(simulated) {
 			if(b >= 48)
@@ -483,8 +669,6 @@ public abstract class EncoderCapture
 	protected virtual void assignEncoderCapturePoints() 
 	{
 		int xWidth = recordingTime;
-		if(cont)
-			xWidth = recordedTimeCont;
 
 		EncoderCapturePoints.Add(new Gdk.Point(
 				Convert.ToInt32(widthG * i / xWidth),
@@ -497,25 +681,33 @@ public abstract class EncoderCapture
 	{
 		//adaptative displayed height
 		//if points go outside the graph, duplicate size of graph
-		if(EncoderCapturePoints[i].Y > heightG || EncoderCapturePoints[i].Y < 0) 
+		bool needToChangeGraph = false;
+		if(EncoderCapturePoints[i].Y > heightG || EncoderCapturePoints[i].Y < 0)
 		{
 			realHeightG *= 2;
-
-			int xWidth = recordingTime;
-			if(cont)
-				xWidth = recordedTimeCont;
-
-			double sum2=0;
-			for(int j=0; j <= i; j ++) {
-				sum2 += encoderReaded[j];
-				EncoderCapturePoints[j] = new Gdk.Point(
-						Convert.ToInt32(widthG * j / xWidth),
-						Convert.ToInt32( (heightG/2) - ( sum2 * heightG / realHeightG) )
-						);
-			}
-			EncoderCapturePointsCaptured = i;
-			EncoderCapturePointsPainted = -1; //mark meaning screen should be erased
+			needToChangeGraph = true;
 		}
+		if(cont && i >= recordingTime)
+		{
+			recordingTime *= 2;
+			needToChangeGraph = true;
+		}
+
+		if(! needToChangeGraph)
+			return;
+
+		int xWidth = recordingTime;
+
+		double sum2=0;
+		for(int j=0; j <= i; j ++) {
+			sum2 += encoderReaded[j];
+			EncoderCapturePoints[j] = new Gdk.Point(
+					Convert.ToInt32(widthG * j / xWidth),
+					Convert.ToInt32( (heightG/2) - ( sum2 * heightG / realHeightG) )
+					);
+		}
+		EncoderCapturePointsCaptured = i;
+		EncoderCapturePointsPainted = -1; //mark meaning screen should be erased
 	}
 
 	/*
@@ -570,9 +762,10 @@ public abstract class EncoderCapture
 
 		if(count > allowedZeroMSAtStart)
 		{
-			l.RemoveRange(0, count-allowedZeroMSAtStart);
+			l.RemoveRange(0, count - allowedZeroMSAtStart);
+			triggerList.Substract(count - allowedZeroMSAtStart);
 		} // else: not enough zeros at start, don't need to trim 
-		
+
 		return l; 
 	}
 	
@@ -593,12 +786,19 @@ public abstract class EncoderCapture
 		writer.Close();
 		((IDisposable)writer).Dispose();
 	}
-	
-	//this methods only applies to inertial subclass
-	protected virtual void inertialCheckIfInverted() {
+
+	public void SaveTriggers(int signalID)
+	{
+		triggerList.SQLInsert(signalID);
 	}
-	protected virtual bool inertialChangedConToEcc() {
-		return false;
+
+	public TriggerList GetTriggers()
+	{
+		return triggerList;
+	}
+
+	public string Eccon {
+		get { return eccon; }
 	}
 
 	public void Cancel() {
@@ -608,7 +808,6 @@ public abstract class EncoderCapture
 	public void Finish() {
 		finish = true;
 	}
-	
 }
 
 
@@ -617,7 +816,7 @@ public class EncoderCaptureGravitatory : EncoderCapture
 	public EncoderCaptureGravitatory() 
 	{
 	}
-	
+
 	protected override void initSpecific()
 	{
 		realHeightG = 2 * 1000 ; //1 meter up / 1 meter down
@@ -634,89 +833,30 @@ public class EncoderCaptureGravitatory : EncoderCapture
 
 public class EncoderCaptureInertial : EncoderCapture
 {
-	private bool inertialFirstEccPhaseDone;
-		
 	public EncoderCaptureInertial() 
 	{
 	}
-	
+
 	protected override void initSpecific()
 	{
 		realHeightG = 2 * 5000 ; //5 meters up / 5 meters down
-
-		inertialShouldCheckStartDirection = true;
-
-		inertialFirstEccPhaseDone = false;
 	}
-	
-	protected override void inertialCheckIfInverted() 
+
+	public override void InitCalibrated(int angleNow)
 	{
-		/*
-		 * 1) on inertial, when we start we should go down (because exercise starts in full extension)
-		 * if at the beginning we detect movement as positive means that the encoder is connected backwards or
-		 * the disc is in a position that makes the start in that direction
-		 * we use the '20' to detect when 'some' movement has been done
-		 * Just -1 all the past and future values of this capture
-		 * (we use the 'sum > 0' to know that it's going upwards)
-		 *
-		 * 2) here sum == sumInertialDisc and encoderReaded == encoderReadedInertialDisc
-		 * because this variables change later (when sum < -25 )
-		 */
-		if(Math.Abs(sum) > 20) 
-		{
-			inertialShouldCheckStartDirection = false;
+		inertialCalibrated = true;
+		sum = angleNow;
+		if(sum > 0)
+			sum *= -1;
 
-			if(sum > 0) {
-				inertialCaptureDirectionInverted = true;
-				byteReaded *= -1;
-				directionNow *= -1;
-				directionLastMSecond *= -1;
-				sum *= -1;
-				sumInertialDisc *= -1;
-			
-				int xWidth = recordingTime;
-				if(cont)
-					xWidth = recordedTimeCont;
-
-				for(int j=0; j <= i; j ++) {
-					encoderReaded[j] *= -1;
-					encoderReadedInertialDisc[j] *= -1;
-				}
-				double sum2=0;
-				for(int j=0; j <= i; j ++) {
-					sum2 += encoderReaded[j];
-					EncoderCapturePoints[j] = new Gdk.Point(
-							Convert.ToInt32(widthG * j / xWidth),
-							Convert.ToInt32( (heightG/2) - ( sum2 * heightG / realHeightG) )
-							);
-					//same for InertialDisc. Read comment 2 on the top of this method
-					EncoderCapturePointsInertialDisc[j] = new Gdk.Point(
-							Convert.ToInt32(widthG * j / xWidth),
-							Convert.ToInt32( (heightG/2) - ( sum2 * heightG / realHeightG) )
-							);
-				}
-				EncoderCapturePointsCaptured = i;
-				EncoderCapturePointsPainted = -1; //mark meaning screen should be erased
-			}
-		}
+		sumInertialDisc = angleNow;
 	}
-	
-	protected override bool inertialChangedConToEcc() 
-	{
-		if(byteReaded == 0)
-			return false;
 
-		if(inertialFirstEccPhaseDone && sumInertialDisc > 0)
-			return true;
-
-		return false;
-	}
-	
 	protected override void assignEncoderCapturePoints() 
 	{
 		int xWidth = recordingTime;
-		if(cont)
-			xWidth = recordedTimeCont;
+//		if(cont)
+//			xWidth = recordedTimeCont;
 
 		EncoderCapturePoints.Add(new Gdk.Point(
 				Convert.ToInt32(widthG * i / xWidth),
@@ -732,43 +872,51 @@ public class EncoderCaptureInertial : EncoderCapture
 	{
 		//adaptative displayed height
 		//if points go outside the graph, duplicate size of graph
+		bool needToChangeGraph = false;
 		if(
-				EncoderCapturePoints[i].Y > heightG || EncoderCapturePoints[i].Y < 0 ||
-				EncoderCapturePointsInertialDisc[i].Y > heightG || 
-				EncoderCapturePointsInertialDisc[i].Y < 0 ) {
+				EncoderCapturePoints[i].Y > heightG ||
+				EncoderCapturePoints[i].Y < 0 ||
+				EncoderCapturePointsInertialDisc[i].Y > heightG ||
+				EncoderCapturePointsInertialDisc[i].Y < 0)
+		{
 			realHeightG *= 2;
-
-			int xWidth = recordingTime;
-			if(cont)
-				xWidth = recordedTimeCont;
-
-			double sum2 = 0;
-			double sum2InertialDisc = 0;
-			for(int j=0; j <= i; j ++) {
-				sum2 += encoderReaded[j];
-				sum2InertialDisc += encoderReadedInertialDisc[j];
-				EncoderCapturePoints[j] = new Gdk.Point(
-						Convert.ToInt32(widthG * j / xWidth),
-						Convert.ToInt32( (heightG/2) - ( sum2 * heightG / realHeightG) )
-						);
-				EncoderCapturePointsInertialDisc[j] = new Gdk.Point(
-						Convert.ToInt32(widthG * j / xWidth),
-						Convert.ToInt32( (heightG/2) - ( sum2InertialDisc * heightG / realHeightG) )
-						);
-			}
-			EncoderCapturePointsCaptured = i;
-			EncoderCapturePointsPainted = -1; //mark meaning screen should be erased and start painting from the beginning
+			needToChangeGraph = true;
 		}
+		if(cont && i >= recordingTime)
+		{
+			recordingTime *= 2;
+			needToChangeGraph = true;
+		}
+
+		if(! needToChangeGraph)
+			return;
+
+		int xWidth = recordingTime;
+		//if(cont)
+		//	xWidth = recordedTimeCont;
+
+		double sum2 = 0;
+		double sum2InertialDisc = 0;
+		for(int j=0; j <= i; j ++)
+		{
+			sum2 += encoderReaded[j];
+			sum2InertialDisc += encoderReadedInertialDisc[j];
+			EncoderCapturePoints[j] = new Gdk.Point(
+					Convert.ToInt32(widthG * j / xWidth),
+					Convert.ToInt32( (heightG/2) - ( sum2 * heightG / realHeightG) )
+					);
+			EncoderCapturePointsInertialDisc[j] = new Gdk.Point(
+					Convert.ToInt32(widthG * j / xWidth),
+					Convert.ToInt32( (heightG/2) - ( sum2InertialDisc * heightG / realHeightG) )
+					);
+		}
+		EncoderCapturePointsCaptured = i;
+		EncoderCapturePointsPainted = -1; //mark meaning screen should be erased and start painting from the beginning
 	}
 	
 
 	protected override void markDirectionChanged() 
 	{
-		//If min height is very low, a micromovement will be used to cut phases incorrectly
-		//put a safe value like <25 . is below (more negative)  the 20 used on inertialCheckIfInverted
-		if(! inertialFirstEccPhaseDone && sum < 25)
-			inertialFirstEccPhaseDone = true;
-
 		directionChangeCount = 0;
 		directionCompleted = directionNow;
 	}
@@ -777,11 +925,18 @@ public class EncoderCaptureInertial : EncoderCapture
 	{
 		TextWriter writer = File.CreateText(file);
 
-		encoderReadedInertialDisc = trimInitialZeros(encoderReadedInertialDisc);
+		//on inertialCalibrated remove from the beginnig to the moment where 0 is crossed
+		if(inertialCalibrated && inertialCalibratedFirstCross0Pos != 0 &&
+				encoderReadedInertialDisc.Count > inertialCalibratedFirstCross0Pos)
+			encoderReadedInertialDisc.RemoveRange(0, inertialCalibratedFirstCross0Pos);
+		else
+			encoderReadedInertialDisc = trimInitialZeros(encoderReadedInertialDisc);
 
+		LogB.Information("Saving to disk");
 		string sep = "";
 		foreach(int k in encoderReadedInertialDisc) {
 			writer.Write(sep + k); //store the raw file (before encoderConfigurationConversions)
+			//LogB.Information(sep + k);
 			sep = ", ";
 		}
 
@@ -810,3 +965,72 @@ public class EncoderCaptureIMCalc : EncoderCapture
 	}
 	
 }
+
+/*
+public class BoolMsList
+{
+	private List<BoolMs> l;
+	public BoolMsList()
+	{
+		l = new List<BoolMs>();
+	}
+
+	public void Add(bool b, int ms)
+	{
+		l.Add(new BoolMs(b, ms));
+	}
+
+	public void Substract(int msToSubstract)
+	{
+		foreach(BoolMs boolMs in l)
+			boolMs.Substract(msToSubstract);
+	}
+
+	//just to debug
+	public void Print()
+	{
+		LogB.Information("Printing BoolMSList");
+		foreach(BoolMs boolMs in l)
+			LogB.Information(boolMs.ToString());
+	}
+
+	public void Write()
+	{
+		//save triggers to file (if any)
+		if(l == null || l.Count == 0)
+			return;
+
+		LogB.Debug("runEncoderCaptureCsharp saving triggers");
+		TextWriter writer = File.CreateText(Util.GetEncoderTriggerDateTimeFileName());
+
+		foreach(BoolMs boolMs in l)
+			writer.WriteLine(boolMs.ToString());
+
+		writer.Flush();
+		writer.Close();
+		((IDisposable)writer).Dispose();
+	}
+}
+
+public class BoolMs
+{
+	private bool b;
+	private int ms;
+
+	public BoolMs(bool b, int ms)
+	{
+		this.b = b;
+		this.ms = ms;
+	}
+
+	public void Substract(int msToSubstract)
+	{
+		ms -= msToSubstract;
+	}
+
+	public override string ToString()
+	{
+		return b.ToString() + ": " + ms.ToString();
+	}
+}
+*/
