@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -82,8 +82,6 @@ public class JumpExecute : EventExecute
 		}
 		
 		fakeButtonUpdateGraph = new Gtk.Button();
-		fakeButtonEventEnded = new Gtk.Button();
-		fakeButtonFinished = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
 		
 		simulated = false;
@@ -139,7 +137,6 @@ public class JumpExecute : EventExecute
 
 			//prepare jump for being cancelled if desired
 			cancel = false;
-			totallyCancelled = false;
 			
 			jumpPhase = jumpPhases.PRE_OR_DOING;
 	
@@ -221,7 +218,6 @@ public class JumpExecute : EventExecute
 
 			//prepare jump for being cancelled if desired
 			cancel = false;
-			totallyCancelled = false;
 
 			jumpPhase = jumpPhases.PRE_OR_DOING;
 
@@ -275,12 +271,20 @@ public class JumpExecute : EventExecute
 		
 		bool ok;
 		int phase = 0;
-		
+
+		//prepare variables to allow being cancelled or finished
+		if(! simulated)
+			Chronopic.InitCancelAndFinish();
+
 		do {
 			if(simulated)
 				ok = true;
-			else 
+			else
+			{
+				LogB.Information("calling Read_event");
 				ok = cp.Read_event(out timestamp, out platformState);
+				LogB.Information("Read_event done!");
+			}
 
 
 			/*
@@ -421,16 +425,9 @@ public class JumpExecute : EventExecute
 					loggedState = States.OFF;
 				}
 			}
-//Log.WriteLine("PREEXIT");
 		} while ( ! success && ! cancel );
-//Log.WriteLine("EXIT");
-		
-		if(cancel) {
-			//event will be raised, and managed in chronojump.cs
-			fakeButtonFinished.Click();
 
-			totallyCancelled = true;
-		}
+		LogB.Information("Exited waitEvent main bucle");
 	}
 	
 	protected override bool shouldFinishByTime() {
@@ -439,10 +436,10 @@ public class JumpExecute : EventExecute
 	
 	protected override void write()
 	{
-		string tcString = "";
+		// string tcString = "";
 		if(hasFall) {
 			//Log.WriteLine("TC: {0}", tc.ToString());
-			tcString = " " + Catalog.GetString("TC") + ": " + Util.TrimDecimals( tc.ToString(), pDN ) ;
+			// tcString = " " + Catalog.GetString("TC") + ": " + Util.TrimDecimals( tc.ToString(), pDN ) ;
 		} else {
 			tc = 0;
 		}
@@ -472,9 +469,6 @@ public class JumpExecute : EventExecute
 		eventDone = new Jump(uniqueID, personID, sessionID, type, tv, tc, fall, 
 				weight, description, angle, Util.BoolToNegativeInt(simulated)); 
 		
-		//event will be raised, and managed in chronojump.cs
-		fakeButtonFinished.Click();
-	
 		PrepareEventGraphJumpSimpleObject = new PrepareEventGraphJumpSimple(tv, tc, sessionID, personID, table, type);
 		needUpdateGraphType = eventType.JUMP;
 		needUpdateGraph = true;
@@ -519,8 +513,6 @@ public class JumpRjExecute : JumpExecute
 {
 	string tvString;
 	string tcString;
-	int jumps; //total number of jumps
-	double time; //time elapsed
 	string limited; //the teorically values, eleven jumps: "11=J" (time recorded in "time"), 10 seconds: "10=T" (jumps recorded in jumps)
 	double limitAsDouble;	//-1 for non limited (unlimited repetitive jump until "finish" is clicked)
 	bool jumpsLimited;
@@ -582,8 +574,6 @@ public class JumpRjExecute : JumpExecute
 		else { hasFall = false; }
 		
 		fakeButtonUpdateGraph = new Gtk.Button();
-		fakeButtonEventEnded = new Gtk.Button();
-		fakeButtonFinished = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
 		
 		simulated = false;
@@ -664,11 +654,9 @@ public class JumpRjExecute : JumpExecute
 
 			//prepare jump for being cancelled if desired
 			cancel = false;
-			totallyCancelled = false;
 			
 			//prepare jump for being finished earlier if desired
 			finish = false;
-			totallyFinished = false;
 			
 			jumpPhase = jumpPhases.PRE_OR_DOING;
 			
@@ -701,6 +689,10 @@ public class JumpRjExecute : JumpExecute
 
 		int countForSavingTempTable = 0;
 	
+		//prepare variables to allow being cancelled or finished
+		if(! simulated)
+			Chronopic.InitCancelAndFinish();
+
 		do {
 			if(simulated) 
 				ok = true;
@@ -836,20 +828,11 @@ public class JumpRjExecute : JumpExecute
 				jumpPhase = jumpPhases.PLATFORM_END;
 
 				writeRj(false); //tempTable
-				
-				totallyFinished = true;
 			} else {
 				//cancel a jump if clicked finish before any events done
 				cancel = true;
 			}
 		}
-		//if(cancel || finish) 
-		if(cancel) {
-			//event will be raised, and managed in chronojump.cs
-			fakeButtonFinished.Click();
-			
-			totallyCancelled = true;
-		}
 	}
 
 	protected override bool shouldFinishByTime() {
@@ -1075,10 +1058,6 @@ public class JumpRjExecute : JumpExecute
 				feedbackMessage = "";
 			needShowFeedbackMessage = true; 
 		
-
-			//event will be raised, and managed in chronojump.cs
-			fakeButtonFinished.Click();
-
 			needEndEvent = true; //used for hiding some buttons on eventWindow, and also for updateTimeProgressBar here
 		}
 	}
