@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -68,8 +68,6 @@ public class MultiChronopicExecute : EventExecute
 
 	static bool firstValue;
 	
-	private MultiChronopic multiChronopicDone;
-	
 	
 	public MultiChronopicExecute() {
 	}
@@ -180,8 +178,6 @@ public class MultiChronopicExecute : EventExecute
 
 	private void initValues() {
 		fakeButtonUpdateGraph = new Gtk.Button();
-		fakeButtonEventEnded = new Gtk.Button();
-		fakeButtonFinished = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
 		simulated = false;
 
@@ -239,12 +235,9 @@ public class MultiChronopicExecute : EventExecute
 		
 			//prepare jump for being cancelled if desired
 			cancel = false;
-			totallyCancelledMulti1 = false;
 
 			//prepare jump for being finished earlier if desired
 			finish = false;
-			totallyFinishedMulti1 = false;
-
 		
 			if(chronopics > 1) {
 				platformState2 = chronopicInitialValue(cp2);
@@ -260,10 +253,6 @@ public class MultiChronopicExecute : EventExecute
 					return;
 				}
 			
-				totallyCancelledMulti2 = false;
-				totallyFinishedMulti2 = false;
-
-
 				if(chronopics > 2) {
 					platformState3 = chronopicInitialValue(cp3);
 
@@ -278,9 +267,6 @@ public class MultiChronopicExecute : EventExecute
 						return;
 					}
 
-					totallyCancelledMulti3 = false;
-					totallyFinishedMulti3 = false;
-
 					if(chronopics > 3) {
 						platformState4 = chronopicInitialValue(cp4);
 
@@ -294,9 +280,6 @@ public class MultiChronopicExecute : EventExecute
 							chronopicHasBeenDisconnected();
 							return;
 						}
-					
-						totallyCancelledMulti4 = false;
-						totallyFinishedMulti4 = false;
 					}
 				}
 			}
@@ -332,6 +315,10 @@ public class MultiChronopicExecute : EventExecute
 
 			//start thread
 			if(chronopics > 0) {
+				//prepare variables to allow being cancelled or finished
+				if(! simulated)
+					Chronopic.InitCancelAndFinish();
+
 				thread = new Thread(new ThreadStart(waitEventPre));
 				if(chronopics > 1) {
 					thread2 = new Thread(new ThreadStart(waitEventPre2));
@@ -495,47 +482,18 @@ public class MultiChronopicExecute : EventExecute
 		} while ( ! success && ! cancel && ! finish );
 	
 		if (finish) {
-			finishThisCp(cpNum);
+			finishThisCp();
 
 			//call write on gui/chronojump.cs, because if done in execute/MultiChronopic, 
 			//will be called n times if n chronopics are working
 			//write(false); //tempTable
-			
-			//event will be raised, and managed in chronojump.cs
-			//only one call (that comes from first chronopic)
-			if(cpNum == 1)
-				fakeButtonFinished.Click();
-		}
-		if(cancel) {
-			//event will be raised, and managed in chronojump.cs
-			fakeButtonFinished.Click();
-			cancelThisCp(cpNum);
 		}
 	}
 	
-	private void finishThisCp (int cp) {
-		if (cp==1)
-			totallyFinishedMulti1 = true;
-		else if (cp==2)
-			totallyFinishedMulti2 = true;
-		else if (cp==3)
-			totallyFinishedMulti3 = true;
-		else // if (cp==4)
-			totallyFinishedMulti4 = true;
+	private void finishThisCp () {
 		needEndEvent = true;
 	}
 
-	private void cancelThisCp (int cp) {
-		if (cp==1)
-			totallyCancelledMulti1 = true;
-		else if (cp==2)
-			totallyCancelledMulti2 = true;
-		else if (cp==3)
-			totallyCancelledMulti3 = true;
-		else // if (cp==4)
-			totallyCancelledMulti4 = true;
-	}
-
 	protected override bool shouldFinishByTime() {
 		return false; //this kind of events (simple or Dj jumps) cannot be finished by time
 	}
