@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -79,8 +79,6 @@ public class RunExecute : EventExecute
 		this.speedStartArrival = speedStartArrival;	
 		
 		fakeButtonUpdateGraph = new Gtk.Button();
-		fakeButtonEventEnded = new Gtk.Button();
-		fakeButtonFinished = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
 
 		simulated = false;
@@ -171,7 +169,6 @@ public class RunExecute : EventExecute
 
 		//prepare jump for being cancelled if desired
 		cancel = false;
-		totallyCancelled = false;
 
 		//start thread
 		thread = new Thread(new ThreadStart(waitEvent));
@@ -193,6 +190,10 @@ public class RunExecute : EventExecute
 		bool success = false;
 		bool ok;
 
+		//prepare variables to allow being cancelled or finished
+		if(! simulated)
+			Chronopic.InitCancelAndFinish();
+
 		do {
 			if(simulated)
 				ok = true;
@@ -251,7 +252,8 @@ public class RunExecute : EventExecute
 									else if(checkDoubleContactMode == 
 											Constants.DoubleContact.LAST) {
 										//user want last flight time, take that
-										timestamp = timestamp;
+										// It doesn't change the timestamp so this is the same as:
+										// timestamp = timestamp;
 									}
 									else {	/* do the avg of all flights and contacts
 										   then add to last timestamp */
@@ -321,13 +323,6 @@ public class RunExecute : EventExecute
 				}
 			}
 		} while ( ! success && ! cancel );
-
-		if(cancel) {
-			//event will be raised, and managed in chronojump.cs
-			fakeButtonFinished.Click();
-
-			totallyCancelled = true;
-		}
 	}
 	
 	protected override bool shouldFinishByTime() {
@@ -419,11 +414,7 @@ public class RunExecute : EventExecute
 		
 		//define the created object
 		eventDone = new Run(uniqueID, personID, sessionID, type, distance, time, description, Util.BoolToNegativeInt(simulated), !startIn); 
-		
-		
-		//event will be raised, and managed in chronojump.cs
-		fakeButtonFinished.Click();
-		
+
 		//app1.PrepareRunSimpleGraph(time, distance/time);
 		PrepareEventGraphRunSimpleObject = new PrepareEventGraphRunSimple(time, distance/time, sessionID, personID, table, type);
 		needUpdateGraphType = eventType.RUN;
@@ -512,8 +503,6 @@ public class RunIntervalExecute : RunExecute
 		this.speedStartArrival = speedStartArrival;	
 	
 		fakeButtonUpdateGraph = new Gtk.Button();
-		fakeButtonEventEnded = new Gtk.Button();
-		fakeButtonFinished = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
 
 		simulated = false;
@@ -548,6 +537,10 @@ public class RunIntervalExecute : RunExecute
 		double timestampDCContactTimes = -1;//sum of the contact times that happen in small time
 		double timestampDCn = 0; //number of flight times
 		
+		//prepare variables to allow being cancelled or finished
+		if(! simulated)
+			Chronopic.InitCancelAndFinish();
+
 		do {
 			if(simulated) 
 				ok = true;
@@ -613,7 +606,8 @@ public class RunIntervalExecute : RunExecute
 									else if(checkDoubleContactMode == 
 											Constants.DoubleContact.LAST) {
 										//user want last flight time, take that
-										timestamp = timestamp;
+										// so we don't need to change timestamp. Or we could do (it triggers a warning):
+										// timestamp = timestamp;
 									}
 									else {	/* do the avg of all flights and contacts
 										   then add to last timestamp */
@@ -746,19 +740,11 @@ public class RunIntervalExecute : RunExecute
 			//write only if there's a run at minimum
 			if(Util.GetNumberOfJumps(intervalTimesString, false) >= 1) {
 				writeRunInterval(false); //tempTable = false
-			
-				totallyFinished = true;
 			} else {
 				//cancel a run if clicked finish before any events done, or ended by time without events
 				cancel = true;
 			}
 		}
-		if(cancel || finish) {
-			//event will be raised, and managed in chronojump.cs
-			fakeButtonFinished.Click();
-			
-			totallyCancelled = true;
-		}
 	}
 
 	protected override string countDownMessage() {
@@ -875,16 +861,14 @@ public class RunIntervalExecute : RunExecute
 						if(intervalTimesString[0] == '-') {
 							//this dialog can make crash the software because the non-gui part calls it
 							//new DialogMessage(Constants.MessageTypes.WARNING, 
-							//		Catalog.GetString("Run will not be recorded, 1st track is out of time"));
+							//		Catalog.GetString("Race will not be recorded, 1st lap is out of time"));
 
-							feedbackMessage = Catalog.GetString("Run will not be recorded. Out of time.");
+							feedbackMessage = Catalog.GetString("Race will not be recorded. Out of time.");
 							needShowFeedbackMessage = true; 
-							LogB.Information("Run will not be recorded, 1st track is out of time");
+							LogB.Information("Race will not be recorded, 1st lap is out of time");
 	
 							//mark for not having problems with cancelled
 							cancel = true;
-							//event will be raised, and managed in chronojump.cs
-							fakeButtonFinished.Click();
 
 							//end this piece of code
 							return;
@@ -940,14 +924,14 @@ public class RunIntervalExecute : RunExecute
 			//define the created object
 			eventDone = new RunInterval(uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString, tracksHere, description, limitString, Util.BoolToNegativeInt(simulated), !startIn); 
 
-
-			string tempValuesString = "";
+			/*
+			string tempValuesString;
 			if(tracksLimited) 
 				tempValuesString = " (" + distanceIntervalFixed + "x" + tracksHere + "R), " + Catalog.GetString("Time") + ": " + Util.TrimDecimals( timeTotal.ToString(), pDN);
 			else
 				tempValuesString = " (" + distanceIntervalFixed + "x" + Util.TrimDecimals( timeTotal.ToString(), pDN) + "T), " + Catalog.GetString("Tracks") + ": " + tracksHere;
 
-			/*
+
 			string myStringPush =   Catalog.GetString("Last run") + ": " + RunnerName + ", " + 
 				type + tempValuesString + ", " +
 				Catalog.GetString("AVG Speed") + ": " + Util.TrimDecimals( 
@@ -961,10 +945,6 @@ public class RunIntervalExecute : RunExecute
 				feedbackMessage = "";
 			needShowFeedbackMessage = true; 
 
-
-			//event will be raised, and managed in chronojump.cs
-			fakeButtonFinished.Click();
-
 			PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
 					distanceIntervalFixed, Util.GetLast(intervalTimesString), 
 					intervalTimesString, distanceTotal, distancesString, startIn);
