@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -61,7 +61,7 @@ public partial class ChronoJumpWindow
 
 		LogB.Debug("At createTreeViewEncoderCapture");
 
-		bool showStartAndDuration = encoderCaptureOptionsWin.check_show_start_and_duration.Active;
+		bool showStartAndDuration = preferences.encoderShowStartAndDuration;
 
 		string [] columnsString = {
 			Catalog.GetString("n") + "\n",
@@ -442,7 +442,6 @@ public partial class ChronoJumpWindow
 			TreePath path = encoderCaptureListStore.GetPath(iter);
 			EncoderCurve curve = (EncoderCurve) encoderCaptureListStore.GetValue (iter, 0);
 			
-			bool found = false;
 			string eccon = findEccon(true);
 			if(eccon == "c") {
 				if(Convert.ToDouble(curve.Start) <= msCentral && 
@@ -486,38 +485,46 @@ public partial class ChronoJumpWindow
 	}
 
 
-	string [] treeviewEncoderAnalyzeHeaders = {
-		Catalog.GetString("Repetition") + "\n",
-		Catalog.GetString("Series") + "\n",
-		Catalog.GetString("Exercise") + "\n",
-		Catalog.GetString("Laterality") + "\n",
-		Catalog.GetString("Extra weight") + "\n (Kg)",
-		Catalog.GetString("Total weight") + "\n (Kg)",
-		Catalog.GetString("Inertia M.") + "\n (Kg*cm^2)",
-		Catalog.GetString("Start") + "\n (s)",
-		Catalog.GetString("Duration") + "\n (s)",
-		Catalog.GetString("Distance") + "\n (cm)",
-		"v" + "\n (m/s)",
-		"vmax" + "\n (m/s)",
-		"t->vmax" + "\n (s)",
-		"p" + "\n (W)",
-		"pmax" + "\n (W)",
-		"t->pmax" + "\n (s)",
-		"pmax/t->pmax" + "\n (W/s)",
-		"F" + "\n (N)",
-		"Fmax" + "\n (N)",
-		"t->Fmax" + "\n (s)"
-	};
+	//on screen shown on s but export is in ms
+	public string [] GetTreeviewEncoderAnalyzeHeaders(bool screenOrCSV)
+	{
+		string timeUnits = "(s)";
+		if(! screenOrCSV)
+			timeUnits = "(ms)";
+
+		string [] treeviewEncoderAnalyzeHeaders = {
+			Catalog.GetString("Repetition") + "\n",
+			Catalog.GetString("Series") + "\n",
+			Catalog.GetString("Exercise") + "\n",
+			Catalog.GetString("Laterality") + "\n",
+			Catalog.GetString("Extra weight") + "\n(Kg)",
+			Catalog.GetString("Total weight") + "\n(Kg)",
+			Catalog.GetString("Inertia M.") + "\n(Kg*cm^2)",
+			Catalog.GetString("Start") + "\n" + timeUnits,
+			Catalog.GetString("Duration") + "\n" + timeUnits,
+			Catalog.GetString("Distance") + "\n(cm)",
+			"v" + "\n(m/s)",
+			"vmax" + "\n(m/s)",
+			"t->vmax" + "\n" + timeUnits,
+			"p" + "\n(W)",
+			"pmax" + "\n(W)",
+			"t->pmax" + "\n" + timeUnits,
+			"pmax/t->pmax" + "\n(W/s)",
+			"F" + "\n(N)",
+			"Fmax" + "\n(N)",
+			"t->Fmax" + "\n" + timeUnits
+		};
+		return treeviewEncoderAnalyzeHeaders;
+	}
 
 	bool lastTreeviewEncoderAnalyzeIsNeuromuscular = false;
 
 	private int createTreeViewEncoderAnalyze(string contents) {
-		string [] columnsString = treeviewEncoderAnalyzeHeaders;
+		string [] columnsString = GetTreeviewEncoderAnalyzeHeaders(true); //screen
 
 		ArrayList encoderAnalyzeCurves = new ArrayList ();
 
 		//write exercise and extra weight data
-		ArrayList curvesData = new ArrayList();
 		string exerciseName = "";
 		double totalMass = 0; 
 		if(radio_encoder_analyze_individual_current_set.Active) {	//current set
@@ -525,10 +532,11 @@ public partial class ChronoJumpWindow
 			totalMass = findMass(Constants.MassType.DISPLACED);
 		} else {						//not current set
 			//TODO:
-			curvesData = SqliteEncoder.Select(
+			/*SqliteEncoder.Select(
 					false, -1, currentPerson.UniqueID, currentSession.UniqueID, currentEncoderGI,
 					-1, "curve", EncoderSQL.Eccons.ALL, 
 					true, true);
+			*/
 		}
 
 		string line;
