@@ -58,9 +58,12 @@ public class CJTests
 		CONTACTS_EXECUTE_TEST,
 		ENCODER_SIGNAL_LOAD,
 		ENCODER_ECC_CON_INVERT,
+		ENCODER_CAPTURE,
+		ENCODER_CAPTURE_CALIBRATE,
 		ENCODER_RECALCULATE,
 		ENCODER_SET_SAVE_REPS,
 		ENCODER_SET_SAVE_REPS_BUCLE,
+		WAIT_5_SECONDS,
 		BUCLE_1_ON,
 		BUCLE_1_OFF,
 		BUCLE_2_ON,
@@ -159,6 +162,40 @@ public class CJTests
 		CJTests.Types.END
 	};
 
+	/*
+	 * howto simulate inertial capture
+	 * open chronojump, inertial mode, load simulated session, preferences / debug,
+	 * main menu: 70 (simulated session), click on guiTests
+	 * go to inertial mode, click on calibrate
+	 */
+	public static List<Types> SequenceEncoderInertialCapture = new List<Types>
+	{
+		CJTests.Types.MODE_POWERINERTIAL,
+//		CJTests.Types.SESSION_LOAD, //better load it manually because it's a long process
+//		CJTests.Types.ENCODER_CAPTURE_CALIBRATE,
+		CJTests.Types.BUCLE_1_ON,
+			CJTests.Types.PERSON_SELECT, //bucle1startPos //repeat from here //when all persons have done a jumps/runs test, will end
+			CJTests.Types.ENCODER_CAPTURE,
+			CJTests.Types.ENCODER_CAPTURE,
+			CJTests.Types.ENCODER_CAPTURE,
+			CJTests.Types.ENCODER_CAPTURE, //4 captures for each person on simulated session
+		CJTests.Types.BUCLE_1_OFF,
+		CJTests.Types.END
+	};
+	public static List<Types> SequenceEncoderGravitatoryCapture = new List<Types>
+	{
+		CJTests.Types.MODE_POWERGRAVITATORY,
+//		CJTests.Types.SESSION_LOAD, //better load it manually because it's a long process
+		CJTests.Types.BUCLE_1_ON,
+			CJTests.Types.PERSON_SELECT, //bucle1startPos //repeat from here //when all persons have done a jumps/runs test, will end
+			CJTests.Types.ENCODER_CAPTURE,
+			CJTests.Types.ENCODER_CAPTURE,
+			CJTests.Types.ENCODER_CAPTURE,
+			CJTests.Types.ENCODER_CAPTURE, //4 captures for each person on simulated session
+		CJTests.Types.BUCLE_1_OFF,
+		CJTests.Types.END
+	};
+
 	public CJTests(List<Types> sequence)
 	{
 		this.sequence = sequence;
@@ -267,29 +304,35 @@ public partial class ChronoJumpWindow
 	
 	public void chronojumpWindowTestsNext() 
 	{
+		LogB.Information("At chronojumpWindowTestsNext 0");
 		if(! testsActive)
 			return;
 
+		LogB.Information("At chronojumpWindowTestsNext 1");
 		//needed for SequenceContactsExecute50_10 (but doesn't work properly). Find other solution:
 		//http://www.mono-project.com/docs/gui/gtksharp/responsive-applications/
 		//
 		//force GUI update
 		//System.Threading.Thread.Sleep(250); //ok there's an sleep, but screen is not updated. Maybe need to open a new thread before each next call to ensure gui is updated
 		//http://mono.1490590.n4.nabble.com/Force-UI-Update-td3488126.html
-		while (Gtk.Application.EventsPending ())
-			        Gtk.Application.RunIteration ();
-		//System.Threading.Thread.Sleep(250); //ok there's an sleep, but screen is not updated. Maybe need to open a new thread before each next call to ensure gui is updated
+		//this works, and is used on 1.7.0, but does not work after ENCODER_CAPTURE test
+		//while (Gtk.Application.EventsPending ())
+		//	        Gtk.Application.RunIteration ();
+		System.Threading.Thread.Sleep(250); //ok there's an sleep, but screen is not updated. Maybe need to open a new thread before each next call to ensure gui is updated
 
+		LogB.Information("At chronojumpWindowTestsNext 2");
 		if(cjTest.Next())
 			chronojumpWindowTestsDo();
 		else {
 			testsActive = false;
 			testsReport();
 		}
+		LogB.Information("At chronojumpWindowTestsNext 3");
 	}
 
 	private void chronojumpWindowTestsDo() 
 	{
+		LogB.Information("At chronojumpWindowTestsDo");
 		//if process is very fast (no threads, no GUI problems) just call next from this method
 		bool callNext = false;
 		
@@ -347,6 +390,13 @@ public partial class ChronoJumpWindow
 				chronojumpWindowTestsEncoderEccConInvert();
 				callNext = true;
 				break;
+			case CJTests.Types.ENCODER_CAPTURE:
+				chronojumpWindowTestsEncoderCapture();
+				break;
+			case CJTests.Types.ENCODER_CAPTURE_CALIBRATE:
+				chronojumpWindowTestsEncoderCaptureCalibrate();
+				callNext = true;
+				break;
 			case CJTests.Types.ENCODER_RECALCULATE:
 				chronojumpWindowTestsEncoderRecalculate();
 				break;
@@ -357,6 +407,10 @@ public partial class ChronoJumpWindow
 			case CJTests.Types.ENCODER_SET_SAVE_REPS_BUCLE:
 				chronojumpWindowTestsEncoderSetSaveRepsBucle();
 				break;
+			case CJTests.Types.WAIT_5_SECONDS:
+				chronojumpWindowTestsWait5seconds();
+				callNext = true;
+				break;
 		}
 
 		if(! bucleContinues)
@@ -400,6 +454,20 @@ public partial class ChronoJumpWindow
 			else
 				radio_menuitem_mode_runs_simple.Active = true;
 		}
+		else if(m == Constants.Menuitem_modes.POWERGRAVITATORY)
+		{
+			if(radio_menuitem_mode_power_gravitatory.Active)
+				select_menuitem_mode_toggled(Constants.Menuitem_modes.POWERGRAVITATORY);
+			else
+				radio_menuitem_mode_power_gravitatory.Active = true;
+		}
+		else if(m == Constants.Menuitem_modes.POWERINERTIAL)
+		{
+			if(radio_menuitem_mode_power_inertial.Active)
+				select_menuitem_mode_toggled(Constants.Menuitem_modes.POWERINERTIAL);
+			else
+				radio_menuitem_mode_power_inertial.Active = true;
+		}
 		
 		LogB.TestEnd("chronojumpWindowTestsMode");
 	}
@@ -531,14 +599,29 @@ public partial class ChronoJumpWindow
 	{
 		LogB.TestStart("chronojumpWindowTestsEncoderEccConInvert");
 
-		if(combo_encoder_eccon.Active == 0)
-			combo_encoder_eccon.Active = 1;
-		else
-			combo_encoder_eccon.Active = 0;
-		
+		radio_encoder_eccon_concentric.Active = ! radio_encoder_eccon_concentric.Active;
+
 		LogB.TestEnd("chronojumpWindowTestsEncoderEccConInvert");
 	}
 	
+	private void chronojumpWindowTestsEncoderCapture()
+	{
+		LogB.TestStart("chronojumpWindowTestsEncoderCapture");
+
+		on_button_encoder_capture_clicked (new Object (), new EventArgs ());
+
+		LogB.TestEnd("chronojumpWindowTestsEncoderCapture");
+	}
+
+	private void chronojumpWindowTestsEncoderCaptureCalibrate()
+	{
+		LogB.TestStart("chronojumpWindowTestsEncoderCaptureCalibrate");
+
+		on_button_encoder_inertial_calibrate_clicked (new Object (), new EventArgs ());
+
+		LogB.TestEnd("chronojumpWindowTestsEncoderCaptureCalibrate");
+	}
+
 	private void chronojumpWindowTestsEncoderRecalculate()
 	{
 		LogB.TestStart("chronojumpWindowTestsEncoderRecalculate");
@@ -627,6 +710,16 @@ public partial class ChronoJumpWindow
 		}
 	}
 	
+	private void chronojumpWindowTestsWait5seconds()
+	{
+		LogB.TestStart("chronojumpWindowTestsWait5seconds");
+
+		System.Threading.Thread.Sleep(5000);
+
+		LogB.TestEnd("chronojumpWindowTestsWait5seconds");
+	}
+
+
 	void testsReport()
 	{
 		if(testsSuccededCount > 0 || testsFailedCount > 0)
