@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -57,7 +57,7 @@ public class EditJumpWindow : EditEventWindow
 
 	public EditJumpWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "edit_event", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "edit_event.glade", "edit_event", null);
 		gladeXML.Autoconnect(this);
 		this.parent =  parent;
 
@@ -67,7 +67,7 @@ public class EditJumpWindow : EditEventWindow
 		eventBigTypeString = Catalog.GetString("jump");
 	}
 
-	static new public EditJumpWindow Show (Gtk.Window parent, Event myEvent, bool weightPercentPreferred, int pDN)
+	static public EditJumpWindow Show (Gtk.Window parent, Event myEvent, bool weightPercentPreferred, int pDN)
 	{
 		if (EditJumpWindowBox == null) {
 			EditJumpWindowBox = new EditJumpWindow (parent);
@@ -449,7 +449,7 @@ public class EditJumpRjWindow : EditJumpWindow
 
 	EditJumpRjWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "edit_event", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "edit_event.glade", "edit_event", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		
@@ -582,7 +582,6 @@ public class RepairJumpRjWindow
 	[Widget] Gtk.TextView textview1;
 
 	static RepairJumpRjWindow RepairJumpRjWindowBox;
-	Gtk.Window parent;
 	//int pDN;
 
 	JumpType jumpType;
@@ -591,13 +590,13 @@ public class RepairJumpRjWindow
 
 	RepairJumpRjWindow (Gtk.Window parent, JumpRj myJump, int pDN) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "repair_sub_event", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "repair_sub_event.glade", "repair_sub_event", null);
 		gladeXML.Autoconnect(this);
 	
 		//put an icon to window
 		UtilGtk.IconWindow(repair_sub_event);
 	
-		this.parent = parent;
+		repair_sub_event.Parent = parent;
 		this.jumpRj = myJump;
 
 		//this.pDN = pDN;
@@ -969,7 +968,7 @@ public class RepairJumpRjWindow
 //---------------- in 0.9.3 included in main gui ---------
 //--------------------------------------------------------
 
-partial class ChronoJumpWindow
+public partial class ChronoJumpWindow
 {
 	//options jumps
 	[Widget] Gtk.SpinButton extra_window_jumps_spinbutton_weight;
@@ -981,7 +980,6 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_kg;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_weight;
 	[Widget] Gtk.Label extra_window_jumps_label_weight;
-	[Widget] Gtk.Label extra_window_jumps_label_cm;
 	[Widget] Gtk.CheckButton extra_window_jumps_check_dj_arms;
 
 	//slCMJ	
@@ -989,13 +987,10 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.Notebook notebook_options_after_execute;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_mode_vertical;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_mode_horizontal;
-	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_mode_lateral;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_dominance_this_limb;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_dominance_opposite;
-	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_dominance_unknown;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_fall_this_limb;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_fall_opposite;
-	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_fall_both;
 	[Widget] Gtk.SpinButton extra_window_jumps_spin_single_leg_distance;
 	[Widget] Gtk.SpinButton extra_window_jumps_spin_single_leg_angle;
 	
@@ -1082,7 +1077,7 @@ partial class ChronoJumpWindow
 	
 	private void on_extra_window_jumps_test_changed(object o, EventArgs args)
 	{
-		string jumpEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_jumps), selectJumpsString);
+		string jumpEnglishName = comboSelectJumps.GetSelectedNameEnglish();
 		currentJumpType = createJumpType(jumpEnglishName, true);
 	
 		extra_window_jumps_initialize(currentJumpType);
@@ -1100,7 +1095,7 @@ partial class ChronoJumpWindow
 	
 	private void on_extra_window_jumps_rj_test_changed(object o, EventArgs args)
 	{
-		string jumpEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_jumps_rj), selectJumpsRjString);
+		string jumpEnglishName = comboSelectJumpsRj.GetSelectedNameEnglish();
 		currentJumpRjType = createJumpType(jumpEnglishName, false);
 
 		extra_window_jumps_rj_initialize(currentJumpRjType);
@@ -1188,7 +1183,7 @@ partial class ChronoJumpWindow
 		
 		//intializeVariables if not done before
 		event_execute_initializeVariables(
-			! chronopicWin.Connected,	//is simulated
+			! cp2016.StoredCanCaptureContacts, //is simulated
 			currentPerson.UniqueID, 
 			currentPerson.Name, 
 			Catalog.GetString("Phases"),  	  //name of the different moments
@@ -1202,7 +1197,16 @@ partial class ChronoJumpWindow
 		if(eventGraph.personMAXAtSQLAllSessions > 0 || eventGraph.jumpsAtSQL.Length > 0)
 			PrepareJumpSimpleGraph(eventGraph, false); //don't animate
 	}
+	private void updateGraphJumpsReactive ()
+	{
+		if(event_execute_drawingarea == null || event_execute_pixmap == null)
+			return;
 
+		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
+		event_execute_table_jump_reactive_values.Hide();
+
+		//TODO paint graph of num of reactive jumps
+	}
 	
 	private void extra_window_jumps_rj_initialize(JumpType myJumpType) 
 	{
@@ -1267,18 +1271,16 @@ partial class ChronoJumpWindow
 		SqlitePreferences.Update("allowFinishRjAfterTime", checkbutton_allow_finish_rj_after_time.Active.ToString(), false);
 	}
 
-	private void on_more_jumps_update_test (object o, EventArgs args) {
+	private void on_more_jumps_update_test (object o, EventArgs args)
+	{
 		currentEventType = new JumpType(jumpsMoreWin.SelectedEventName);
-		string jumpTranslatedName = Util.FindOnArray(':',1,2, jumpsMoreWin.SelectedEventName, selectJumpsString);
-		
-		combo_select_jumps.Active = UtilGtk.ComboMakeActive(combo_select_jumps, jumpTranslatedName);	
+		comboSelectJumps.MakeActive(jumpsMoreWin.SelectedEventName);
 	}
 	
-	private void on_more_jumps_rj_update_test (object o, EventArgs args) {
+	private void on_more_jumps_rj_update_test (object o, EventArgs args) 
+	{
 		currentEventType = new JumpType(jumpsRjMoreWin.SelectedEventName);
-		string jumpTranslatedName = Util.FindOnArray(':',1,2, jumpsRjMoreWin.SelectedEventName, selectJumpsRjString);
-		
-		combo_select_jumps_rj.Active = UtilGtk.ComboMakeActive(combo_select_jumps_rj, jumpTranslatedName);	
+		comboSelectJumpsRj.MakeActive(jumpsRjMoreWin.SelectedEventName);
 	}
 	
 	//used from the dialogue "jumps more"
@@ -1454,7 +1456,7 @@ public class JumpsMoreWindow : EventMoreWindow
 
 	public JumpsMoreWindow (Gtk.Window parent, bool testOrDelete) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "jumps_runs_more.glade", "jumps_runs_more", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		this.testOrDelete = testOrDelete;
@@ -1666,7 +1668,7 @@ public class JumpsRjMoreWindow : EventMoreWindow
 	public JumpsRjMoreWindow (Gtk.Window parent, bool testOrDelete) {
 		//the glade window is the same as jumps_more
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "jumps_runs_more.glade", "jumps_runs_more", "chronojump");
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		this.testOrDelete = testOrDelete;
