@@ -148,17 +148,6 @@ public class PersonRecuperateWindow {
 	}
 */
 
-	/*
-	public int birthColumnCompare (TreeModel model, TreeIter iter1, TreeIter iter2)     {
-		DateTime val1; 
-		DateTime val2; 
-		val1 = UtilDate.DateAsDateTime(model.GetValue(iter1, firstColumn + 5).ToString());
-		val2 = UtilDate.DateAsDateTime(model.GetValue(iter2, firstColumn + 5).ToString());
-		
-		return DateTime.Compare(val1, val2);
-	}
-	*/
-
 	private void fillTreeView (Gtk.TreeView tv, TreeStore store, string searchFilterName) 
 	{
 		int except = currentSession.UniqueID;
@@ -854,6 +843,8 @@ public class PersonAddModifyWindow
 	GenericWindow genericWin;
 
 	bool adding;
+	private bool descriptionChanging = false;
+	private bool textviewpsChanging = false;
 
 	private Person currentPerson;
 	private Session currentSession;
@@ -1035,6 +1026,8 @@ public class PersonAddModifyWindow
 
 	void on_entries_required_changed (object o, EventArgs args)
 	{
+		entry1.Text = Util.MakeValidSQL(entry1.Text);
+
 		if(entry1.Text.ToString().Length > 0)
 			image_name.Hide();
 		else {
@@ -1220,7 +1213,6 @@ public class PersonAddModifyWindow
 		combo_countries.Sensitive = false;
 	}
 
-
 	private void fillDialog ()
 	{
 		int mySportID;
@@ -1283,7 +1275,12 @@ public class PersonAddModifyWindow
 			tb2.Text = myPS.Comments;
 			textview_ps_comments.Buffer = tb2;
 		}
-			
+
+		textview_description.Buffer.Changed += new EventHandler(descriptionChanged);
+		descriptionChanging = false;
+		textview_ps_comments.Buffer.Changed += new EventHandler(textviewpsChanged);
+		textviewpsChanging = false;
+
 		sport = SqliteSport.Select(false, mySportID);
 		combo_sports.Active = UtilGtk.ComboMakeActive(sportsTranslated, sport.ToString());
 
@@ -1292,8 +1289,37 @@ public class PersonAddModifyWindow
 		combo_levels.Active = UtilGtk.ComboMakeActive(levels, myLevelID + ":" + Util.FindLevelName(myLevelID));
 		
 	}
-		
-	
+
+	private void descriptionChanged(object o,EventArgs args)
+	{
+		if(descriptionChanging)
+			return;
+
+		descriptionChanging = true;
+
+		TextBuffer tb = o as TextBuffer;
+		if (o == null)
+			return;
+
+		tb.Text = Util.MakeValidSQL(tb.Text);
+		descriptionChanging = false;
+	}
+	private void textviewpsChanged(object o,EventArgs args)
+	{
+		if(textviewpsChanging)
+			return;
+
+		textviewpsChanging = true;
+
+		TextBuffer tb = o as TextBuffer;
+		if (o == null)
+			return;
+
+		tb.Text = Util.MakeValidSQL(tb.Text);
+		textviewpsChanging = false;
+	}
+
+
 	void on_button_calendar_clicked (object o, EventArgs args)
 	{
 		DateTime dt = dateTime;
@@ -1317,6 +1343,8 @@ public class PersonAddModifyWindow
 	}
 	void on_button_height_metric_accepted (object obj, EventArgs args)
 	{
+		genericWin.Button_accept.Clicked -= new EventHandler(on_button_height_metric_accepted);
+
 		string [] myStr = genericWin.TwoSpinSelected.Split(new char[] {':'});
 		spinbutton_height.Value = Util.ConvertFeetInchesToCm(
 			Convert.ToInt32(myStr[0]), 
@@ -1331,6 +1359,8 @@ public class PersonAddModifyWindow
 	}
 	void on_button_weight_metric_accepted (object obj, EventArgs args)
 	{
+		genericWin.Button_accept.Clicked -= new EventHandler(on_button_weight_metric_accepted);
+
 		spinbutton_weight.Value = Util.ConvertPoundsToKg(genericWin.SpinDoubleSelected);
 	}
 
@@ -1474,8 +1504,10 @@ public class PersonAddModifyWindow
 		genericWin.Button_accept.Clicked += new EventHandler(on_sport_add_accepted);
 	}
 
-	private void on_sport_add_accepted (object o, EventArgs args) {
+	private void on_sport_add_accepted (object o, EventArgs args)
+	{
 		genericWin.Button_accept.Clicked -= new EventHandler(on_sport_add_accepted);
+
 		string newSportName = genericWin.EntrySelected;
 		if(Sqlite.Exists(false, Constants.SportTable, newSportName) ||
 				newSportName == Catalog.GetString(Constants.SportUndefined) || //let's save problems
@@ -1514,7 +1546,8 @@ public class PersonAddModifyWindow
 		string errorMessage = "";
 
 		//Check if person name exists and weight is > 0
-		string personName = entry1.Text;
+		string personName = Util.MakeValidSQLAndFileName(entry1.Text);
+
 		if(personName == "")
 			errorMessage += "\n" + Catalog.GetString("Please, write the name of the person.");
 		if((double) spinbutton_weight.Value == 0)
@@ -1524,12 +1557,11 @@ public class PersonAddModifyWindow
 			return;
 		}
 
-
 		bool personExists;
 		if(adding)
-			personExists = Sqlite.Exists (false, Constants.PersonTable, Util.RemoveTilde(personName));
+			personExists = Sqlite.Exists (false, Constants.PersonTable, personName);
 		else
-			personExists = SqlitePerson.ExistsAndItsNotMe (currentPerson.UniqueID, Util.RemoveTilde(personName));
+			personExists = SqlitePerson.ExistsAndItsNotMe (currentPerson.UniqueID, personName);
 
 		if(personExists) 
 			errorMessage += string.Format(Catalog.GetString("Person: '{0}' exists. Please, use another name"), 
@@ -1588,14 +1620,15 @@ public class PersonAddModifyWindow
 			SqliteRun.Update(mRun.UniqueID, mRun.Type, mRun.Distance.ToString(), mRun.Time.ToString(), mRun.PersonID, mRun.Description);
 		}
 
+		string personName = Util.MakeValidSQLAndFileName(entry1.Text);
 
 		if(adding) {
 			//here we add rows in the database
 			LogB.Information("Going to insert person");
-			currentPerson = new Person (entry1.Text, sex, dateTime, 
+			currentPerson = new Person (personName, sex, dateTime,
 					Constants.RaceUndefinedID,
 					Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_countries), countries)),
-					textview_description.Buffer.Text,
+					textview_description.Buffer.Text, "", //future1: rfid
 					Constants.ServerUndefinedID, false); //dbconOpened
 					
 			LogB.Information("Going to insert personSession");
@@ -1609,10 +1642,10 @@ public class PersonAddModifyWindow
 			LogB.Information("inserted both");
 		} else {
 			//here we update rows in the database
-			currentPerson = new Person (currentPerson.UniqueID, entry1.Text, sex, dateTime, 
+			currentPerson = new Person (currentPerson.UniqueID, personName, sex, dateTime,
 					Constants.RaceUndefinedID,
 					Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_countries), countries)),
-					textview_description.Buffer.Text,
+					textview_description.Buffer.Text, "", //future1: rfid
 					serverUniqueID);
 			SqlitePerson.Update (currentPerson); 
 		
@@ -1948,7 +1981,7 @@ public class PersonAddMultipleWindow {
 					}
 					//if headers are active do not add first row
 					if( ! (headersActive && row == 0) ) {
-						PersonAddMultipleTable pamt = new PersonAddMultipleTable(fullname, maleOrFemale, weight);
+						PersonAddMultipleTable pamt = new PersonAddMultipleTable(Util.MakeValidSQL(fullname), maleOrFemale, weight);
 						array.Add(pamt);
 					}
 					
@@ -2039,6 +2072,7 @@ public class PersonAddMultipleWindow {
 			Gtk.Entry myEntry = new Gtk.Entry();
 			table_main.Attach (myEntry, (uint) 1, (uint) 2, (uint) count, (uint) count +1, 
 					Gtk.AttachOptions.Fill | Gtk.AttachOptions.Expand , Gtk.AttachOptions.Shrink, padding, padding);
+			myEntry.Changed += on_entry_changed;
 			myEntry.Show();
 			entries.Add(myEntry);
 
@@ -2093,7 +2127,16 @@ public class PersonAddMultipleWindow {
 	
 		button_accept.Sensitive = true;
 	}
-		
+
+	void on_entry_changed (object o, EventArgs args)
+	{
+		Gtk.Entry entry = o as Gtk.Entry;
+		if (o == null)
+			return;
+
+		entry.Text = Util.MakeValidSQL(entry.Text);
+	}
+
 	void fillTableFromCSV(ArrayList array) {
 		int i = 0;
 		foreach(PersonAddMultipleTable pamt in array) {
@@ -2226,7 +2269,7 @@ public class PersonAddMultipleWindow {
 							dateTime,
 							Constants.RaceUndefinedID,
 							Constants.CountryUndefinedID,
-							"", 					//description
+							"", "", 				//description, future1: rfid
 							Constants.ServerUndefinedID
 							);
 				
