@@ -27,6 +27,7 @@ using Glade;
 //using GLib; //for Value
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 using Mono.Unix;
 using System.Threading;
 using System.Globalization; //CultureInfo stuff
@@ -40,12 +41,20 @@ using ICSharpCode.SharpZipLib.GZip;
 using ICSharpCode.SharpZipLib;
 */
 
-public class PreferencesWindow {
-	
+public class PreferencesWindow
+{
 	[Widget] Gtk.Window preferences_win;
 	[Widget] Gtk.Notebook notebook;
 
-	//main tab
+	//appearance tab
+	[Widget] Gtk.CheckButton check_appearance_maximized;
+	[Widget] Gtk.CheckButton check_appearance_maximized_undecorated;
+	[Widget] Gtk.CheckButton check_appearance_person_win_hide;
+	[Widget] Gtk.CheckButton check_appearance_encoder_only_bars;
+	[Widget] Gtk.Alignment alignment_undecorated;
+	[Widget] Gtk.Alignment alignment_restart;
+
+	//database tab
 	[Widget] Gtk.Button button_data_folder_open;
 
 	[Widget] Gtk.CheckButton check_backup_multimedia_and_encoder;
@@ -76,6 +85,9 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_speed_km;
 	[Widget] Gtk.RadioButton radio_runs_speed_start_arrival; 
 	[Widget] Gtk.RadioButton radio_runs_speed_start_leaving; 
+	[Widget] Gtk.Image image_races_simple;
+	[Widget] Gtk.Image image_races_intervallic;
+	[Widget] Gtk.Notebook notebook_races_double_contacts;
 	[Widget] Gtk.Box vbox_runs_prevent_double_contact;
 	[Widget] Gtk.CheckButton checkbutton_runs_prevent_double_contact;
 	[Widget] Gtk.SpinButton spinbutton_runs_prevent_double_contact;
@@ -94,6 +106,10 @@ public class PreferencesWindow {
 	[Widget] Gtk.SpinButton spin_encoder_capture_inactivity_end_time;
 	[Widget] Gtk.Box hbox_combo_main_variable;
 	[Widget] Gtk.ComboBox combo_main_variable;
+	[Widget] Gtk.Image image_encoder_gravitatory;
+	[Widget] Gtk.Image image_encoder_inertial;
+	[Widget] Gtk.Notebook notebook_encoder_capture_gi;
+	[Widget] Gtk.VBox vbox_encoder_inertial; //change Visible param to not have a vertical big first page with only one row of info
 	[Widget] Gtk.SpinButton spin_encoder_capture_min_height_gravitatory;
 	[Widget] Gtk.SpinButton spin_encoder_capture_min_height_inertial;
 	[Widget] Gtk.CheckButton checkbutton_encoder_capture_fully_extended;
@@ -103,7 +119,10 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_4top;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_all;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_none;
+	[Widget] Gtk.SpinButton spin_encoder_capture_barplot_font_size;
 	[Widget] Gtk.CheckButton check_show_start_and_duration;
+	[Widget] Gtk.CheckButton check_encoder_capture_cut_by_triggers;
+	[Widget] Gtk.Image image_encoder_capture_cut_by_triggers_help;
 	
 	//encoder other tab
 	[Widget] Gtk.CheckButton checkbutton_encoder_propulsive;
@@ -114,6 +133,61 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted2;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted3;
 
+	//force sensor tab
+	[Widget] Gtk.HBox hbox_force_1;
+	[Widget] Gtk.HBox hbox_force_2;
+	[Widget] Gtk.HBox hbox_force_3;
+	[Widget] Gtk.HBox hbox_force_4;
+	[Widget] Gtk.HBox hbox_force_impulse;
+	[Widget] Gtk.CheckButton check_force_1;
+	[Widget] Gtk.CheckButton check_force_2;
+	[Widget] Gtk.CheckButton check_force_3;
+	[Widget] Gtk.CheckButton check_force_4;
+	[Widget] Gtk.CheckButton check_force_impulse;
+	[Widget] Gtk.ComboBox combo_force_1_function;
+	[Widget] Gtk.ComboBox combo_force_2_function;
+	[Widget] Gtk.ComboBox combo_force_3_function;
+	[Widget] Gtk.ComboBox combo_force_4_function;
+	[Widget] Gtk.ComboBox combo_force_impulse_function;
+	[Widget] Gtk.ComboBox combo_force_1_type;
+	[Widget] Gtk.ComboBox combo_force_2_type;
+	[Widget] Gtk.ComboBox combo_force_3_type;
+	[Widget] Gtk.ComboBox combo_force_4_type;
+	[Widget] Gtk.ComboBox combo_force_impulse_type;
+	[Widget] Gtk.HBox hbox_force_1_at_ms;
+	[Widget] Gtk.HBox hbox_force_2_at_ms;
+	[Widget] Gtk.HBox hbox_force_3_at_ms;
+	[Widget] Gtk.HBox hbox_force_4_at_ms;
+	[Widget] Gtk.HBox hbox_force_1_at_percent;
+	[Widget] Gtk.HBox hbox_force_2_at_percent;
+	[Widget] Gtk.HBox hbox_force_3_at_percent;
+	[Widget] Gtk.HBox hbox_force_4_at_percent;
+	[Widget] Gtk.HBox hbox_force_impulse_until_percent;
+	[Widget] Gtk.HBox hbox_force_1_from_to;
+	[Widget] Gtk.HBox hbox_force_2_from_to;
+	[Widget] Gtk.HBox hbox_force_3_from_to;
+	[Widget] Gtk.HBox hbox_force_4_from_to;
+	[Widget] Gtk.HBox hbox_force_impulse_from_to;
+	[Widget] Gtk.SpinButton spinbutton_force_1_at_ms;
+	[Widget] Gtk.SpinButton spinbutton_force_2_at_ms;
+	[Widget] Gtk.SpinButton spinbutton_force_3_at_ms;
+	[Widget] Gtk.SpinButton spinbutton_force_4_at_ms;
+	[Widget] Gtk.SpinButton spinbutton_force_1_at_percent;
+	[Widget] Gtk.SpinButton spinbutton_force_2_at_percent;
+	[Widget] Gtk.SpinButton spinbutton_force_3_at_percent;
+	[Widget] Gtk.SpinButton spinbutton_force_4_at_percent;
+	[Widget] Gtk.SpinButton spinbutton_force_impulse_until_percent;
+	[Widget] Gtk.SpinButton spinbutton_force_1_from;
+	[Widget] Gtk.SpinButton spinbutton_force_2_from;
+	[Widget] Gtk.SpinButton spinbutton_force_3_from;
+	[Widget] Gtk.SpinButton spinbutton_force_4_from;
+	[Widget] Gtk.SpinButton spinbutton_force_impulse_from;
+	[Widget] Gtk.SpinButton spinbutton_force_1_to;
+	[Widget] Gtk.SpinButton spinbutton_force_2_to;
+	[Widget] Gtk.SpinButton spinbutton_force_3_to;
+	[Widget] Gtk.SpinButton spinbutton_force_4_to;
+	[Widget] Gtk.SpinButton spinbutton_force_impulse_to;
+
 	//multimedia tab
 	[Widget] Gtk.CheckButton checkbutton_volume;
 	[Widget] Gtk.Box hbox_combo_camera;
@@ -131,6 +205,7 @@ public class PreferencesWindow {
 	//advanced tab
 	[Widget] Gtk.ComboBox combo_decimals;
 	[Widget] Gtk.CheckButton checkbutton_ask_deletion;
+	[Widget] Gtk.CheckButton checkbutton_mute_logs;
 	[Widget] Gtk.RadioButton radio_export_latin;
 	[Widget] Gtk.RadioButton radio_export_non_latin;
 	[Widget] Gtk.Label label_advanced_feedback;
@@ -146,6 +221,8 @@ public class PreferencesWindow {
 	static PreferencesWindow PreferencesWindowBox;
 	
 	private Preferences preferences; //stored to update SQL if anything changed
+	private List<ForceSensorRFD> rfdList; //stored to update SQL if anything changed
+	private ForceSensorImpulse impulse;
 	private Thread thread;
 
 	string databaseURL;
@@ -153,6 +230,12 @@ public class PreferencesWindow {
 	
 	ListStore langsStore;
 
+	const int JUMPSPAGE = 2;
+	const int RUNSPAGE = 3;
+	const int ENCODERCAPTUREPAGE = 4;
+	const int ENCODEROTHERPAGE = 5;
+	const int FORCEPAGE = 6;
+
 
 	PreferencesWindow () {
 		Glade.XML gladeXML;
@@ -170,25 +253,54 @@ public class PreferencesWindow {
 		FakeButtonDebugModeStart = new Gtk.Button();
 	}
 	
-	static public PreferencesWindow Show (Preferences preferences, Constants.Menuitem_modes menu_mode)
+	static public PreferencesWindow Show (Preferences preferences, List <ForceSensorRFD> rfdList, ForceSensorImpulse impulse,
+			Constants.Menuitem_modes menu_mode)
 	{
 		if (PreferencesWindowBox == null) {
 			PreferencesWindowBox = new PreferencesWindow ();
 		}
 
 		if(menu_mode !=	Constants.Menuitem_modes.JUMPSSIMPLE && menu_mode != Constants.Menuitem_modes.JUMPSREACTIVE)
-			PreferencesWindowBox.notebook.GetNthPage(1).Hide(); 
+			PreferencesWindowBox.notebook.GetNthPage(JUMPSPAGE).Hide();
 		if(menu_mode !=	Constants.Menuitem_modes.RUNSSIMPLE && menu_mode != Constants.Menuitem_modes.RUNSINTERVALLIC)
-			PreferencesWindowBox.notebook.GetNthPage(2).Hide(); 
+			PreferencesWindowBox.notebook.GetNthPage(RUNSPAGE).Hide();
 		if(menu_mode !=	Constants.Menuitem_modes.POWERGRAVITATORY && menu_mode != Constants.Menuitem_modes.POWERINERTIAL) {
-			PreferencesWindowBox.notebook.GetNthPage(3).Hide();
-			PreferencesWindowBox.notebook.GetNthPage(4).Hide();
+			PreferencesWindowBox.notebook.GetNthPage(ENCODERCAPTUREPAGE).Hide();
+			PreferencesWindowBox.notebook.GetNthPage(ENCODEROTHERPAGE).Hide();
 		}
+		if(menu_mode !=	Constants.Menuitem_modes.FORCESENSOR)
+			PreferencesWindowBox.notebook.GetNthPage(FORCEPAGE).Hide();
 
 		PreferencesWindowBox.preferences = preferences;
+		PreferencesWindowBox.rfdList = rfdList;
+		PreferencesWindowBox.impulse = impulse;
 
 		PreferencesWindowBox.createComboLanguage();
 
+		//appearence tab
+		if(preferences.maximized == Preferences.MaximizedTypes.NO)
+		{
+			PreferencesWindowBox.check_appearance_maximized.Active = false;
+			PreferencesWindowBox.alignment_undecorated.Visible = false;
+		}
+		else {
+			PreferencesWindowBox.check_appearance_maximized.Active = true;
+			PreferencesWindowBox.alignment_undecorated.Visible = true;
+			PreferencesWindowBox.check_appearance_maximized_undecorated.Active =
+				(preferences.maximized == Preferences.MaximizedTypes.YESUNDECORATED);
+		}
+
+		if(preferences.personWinHide)
+			PreferencesWindowBox.check_appearance_person_win_hide.Active = true;
+		else
+			PreferencesWindowBox.check_appearance_person_win_hide.Active = false;
+
+		if(preferences.encoderCaptureShowOnlyBars)
+			PreferencesWindowBox.check_appearance_encoder_only_bars.Active = true;
+		else
+			PreferencesWindowBox.check_appearance_encoder_only_bars.Active = false;
+
+
 		//multimedia tab
 		if(preferences.volumeOn)  
 			PreferencesWindowBox.checkbutton_volume.Active = true; 
@@ -238,11 +350,15 @@ public class PreferencesWindow {
 			PreferencesWindowBox.hbox_indexes.Hide();
 		}
 
-		if(preferences.askDeletion)  
+		if(preferences.askDeletion)
 			PreferencesWindowBox.checkbutton_ask_deletion.Active = true; 
 		else 
 			PreferencesWindowBox.checkbutton_ask_deletion.Active = false; 
-		
+
+		if(preferences.muteLogs)
+			PreferencesWindowBox.checkbutton_mute_logs.Active = true;
+		else
+			PreferencesWindowBox.checkbutton_mute_logs.Active = false;
 
 		if(preferences.weightStatsPercent)  
 			PreferencesWindowBox.radio_weight_percent.Active = true; 
@@ -269,6 +385,20 @@ public class PreferencesWindow {
 
 
 		//start of double contacts stuff ----
+		Pixbuf pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_simple.png");
+		PreferencesWindowBox.image_races_simple.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_multiple.png");
+		PreferencesWindowBox.image_races_intervallic.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_info.png");
+		PreferencesWindowBox.image_encoder_capture_cut_by_triggers_help.Pixbuf = pixbuf;
+
+		if(menu_mode ==	Constants.Menuitem_modes.RUNSSIMPLE)
+			PreferencesWindowBox.notebook_races_double_contacts.CurrentPage = 0;
+		else if(menu_mode == Constants.Menuitem_modes.RUNSINTERVALLIC)
+			PreferencesWindowBox.notebook_races_double_contacts.CurrentPage = 1;
+
 		PreferencesWindowBox.checkbutton_runs_prevent_double_contact.Active = 
 			(preferences.runDoubleContactsMode != Constants.DoubleContact.NONE);
 		PreferencesWindowBox.checkbutton_runs_i_prevent_double_contact.Active = 
@@ -311,6 +441,22 @@ public class PreferencesWindow {
 		PreferencesWindowBox.createComboEncoderCaptureMainVariable(
 				Constants.GetEncoderVariablesCapture(preferences.encoderCaptureMainVariable));
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_gravity.png");
+		PreferencesWindowBox.image_encoder_gravitatory.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_inertia.png");
+		PreferencesWindowBox.image_encoder_inertial.Pixbuf = pixbuf;
+
+		if(menu_mode ==	Constants.Menuitem_modes.POWERGRAVITATORY)
+		{
+			PreferencesWindowBox.vbox_encoder_inertial.Visible = false;
+			PreferencesWindowBox.notebook_encoder_capture_gi.CurrentPage = 0;
+		}
+		else if(menu_mode == Constants.Menuitem_modes.POWERINERTIAL)
+		{
+			PreferencesWindowBox.vbox_encoder_inertial.Visible = true;
+			PreferencesWindowBox.notebook_encoder_capture_gi.CurrentPage = 1;
+		}
+
 		PreferencesWindowBox.spin_encoder_capture_min_height_gravitatory.Value = preferences.encoderCaptureMinHeightGravitatory;
 		PreferencesWindowBox.spin_encoder_capture_min_height_inertial.Value = preferences.encoderCaptureMinHeightInertial;
 		PreferencesWindowBox.checkbutton_encoder_capture_fully_extended.Active = preferences.encoderCaptureCheckFullyExtended;
@@ -325,8 +471,10 @@ public class PreferencesWindow {
 			PreferencesWindowBox.radio_encoder_auto_save_curve_all.Active = true;
 		else
 			PreferencesWindowBox.radio_encoder_auto_save_curve_none.Active = true;
-	
+
+		PreferencesWindowBox.spin_encoder_capture_barplot_font_size.Value = preferences.encoderCaptureBarplotFontSize;
 		PreferencesWindowBox.check_show_start_and_duration.Active = preferences.encoderShowStartAndDuration;
+		PreferencesWindowBox.check_encoder_capture_cut_by_triggers.Active = preferences.encoderCaptureCutByTriggers;
 
 
 		//encoder other -->
@@ -346,6 +494,9 @@ public class PreferencesWindow {
 		//done here and not in glade to be shown with the decimal point of user language	
 		PreferencesWindowBox.label_encoder_con.Text = (0.7).ToString();
 	
+		//force
+		PreferencesWindowBox.initForceSensor();
+
 		//language -->
 		if(preferences.language == "")
 			PreferencesWindowBox.radio_language_detected.Active = true;
@@ -369,6 +520,24 @@ public class PreferencesWindow {
 		PreferencesWindowBox.preferences_win.Show ();
 		return PreferencesWindowBox;
 	}
+
+	//private void on_notebook_encoder_capture_gi_change_current_page (object o, Gtk.ChangeCurrentPageArgs args)
+	private void on_notebook_encoder_capture_gi_switch_page (object o, Gtk.SwitchPageArgs args)
+	{
+		vbox_encoder_inertial.Visible = (PreferencesWindowBox.notebook_encoder_capture_gi.CurrentPage == 1);
+	}
+
+	private void on_button_encoder_capture_cut_by_triggers_help_clicked (object o, EventArgs args)
+	{
+		new DialogMessage(Constants.MessageTypes.WARNING,
+				"If active, repetitions will be cut from set using triggers." + "\n" +
+				"Triggers will be produced by a button connected to the Chronopic." + "\n\n" +
+				"This will be only used on gravitatory mode, concentric contraction.");
+		/*
+		 * not on ecc-con because we cannot guaranteee that there will be an ecc and con phase,
+		 * and then R findECPhases() will fail
+		 */
+	}
 	
 	private void createComboEncoderCaptureMainVariable(string v) {
 		combo_main_variable = ComboBox.NewText ();
@@ -400,12 +569,314 @@ public class PreferencesWindow {
 		combo_camera.Active = UtilGtk.ComboMakeActive(devices, devices[current]);
 	}
 		
-	
+	private void on_check_appearance_maximized_toggled (object obj, EventArgs args)
+	{
+		alignment_undecorated.Visible = check_appearance_maximized.Active;
+	}
+
+	private void on_check_appearance_encoder_only_bars_toggled (object obj, EventArgs args) 
+	{
+		alignment_restart.Visible = ! check_appearance_encoder_only_bars.Active;
+	}
+
 	private void on_checkbutton_encoder_capture_fully_extended_toggled(object obj, EventArgs args) {
 		hbox_encoder_capture_fully_extended.Visible = checkbutton_encoder_capture_fully_extended.Active;
 	}
 
 
+	// ---- Force sensor stuff
+
+	private void initForceSensor ()
+	{
+		createForceCombos();
+		setRFDValues();
+		setImpulseValue();
+	}
+
+	private void check_force_visibilities()
+	{
+		hbox_force_1.Visible = (check_force_1.Active);
+		hbox_force_2.Visible = (check_force_2.Active);
+		hbox_force_3.Visible = (check_force_3.Active);
+		hbox_force_4.Visible = (check_force_4.Active);
+		hbox_force_impulse.Visible = (check_force_impulse.Active);
+	}
+
+	private void on_check_force_clicked (object o, EventArgs args)
+	{
+		check_force_visibilities();
+	}
+
+	private void createForceCombos ()
+	{
+		UtilGtk.ComboUpdate(combo_force_1_function, ForceSensorRFD.FunctionsArray(true), "");
+		UtilGtk.ComboUpdate(combo_force_2_function, ForceSensorRFD.FunctionsArray(true), "");
+		UtilGtk.ComboUpdate(combo_force_3_function, ForceSensorRFD.FunctionsArray(true), "");
+		UtilGtk.ComboUpdate(combo_force_4_function, ForceSensorRFD.FunctionsArray(true), "");
+		UtilGtk.ComboUpdate(combo_force_impulse_function, ForceSensorImpulse.FunctionsArray(true), "");
+
+		UtilGtk.ComboUpdate(combo_force_1_type, ForceSensorRFD.TypesArray(true), "");
+		UtilGtk.ComboUpdate(combo_force_2_type, ForceSensorRFD.TypesArray(true), "");
+		UtilGtk.ComboUpdate(combo_force_3_type, ForceSensorRFD.TypesArray(true), "");
+		UtilGtk.ComboUpdate(combo_force_4_type, ForceSensorRFD.TypesArray(true), "");
+		UtilGtk.ComboUpdate(combo_force_impulse_type, ForceSensorImpulse.TypesArrayImpulse(true), "");
+	}
+
+	private void on_combo_force_type_changed (object o, EventArgs args)
+	{
+		Gtk.ComboBox combo = o as ComboBox;
+		if (o == null)
+			return;
+
+		if(combo == combo_force_1_type)
+			combo_force_visibility(
+					UtilGtk.ComboGetActive(combo_force_1_type),
+					hbox_force_1_at_ms,
+					hbox_force_1_at_percent,
+					hbox_force_1_from_to);
+		else if(combo == combo_force_2_type)
+			combo_force_visibility(
+					UtilGtk.ComboGetActive(combo_force_2_type),
+					hbox_force_2_at_ms,
+					hbox_force_2_at_percent,
+					hbox_force_2_from_to);
+		else if(combo == combo_force_3_type)
+			combo_force_visibility(
+					UtilGtk.ComboGetActive(combo_force_3_type),
+					hbox_force_3_at_ms,
+					hbox_force_3_at_percent,
+					hbox_force_3_from_to);
+		else if(combo == combo_force_4_type)
+			combo_force_visibility(
+					UtilGtk.ComboGetActive(combo_force_4_type),
+					hbox_force_4_at_ms,
+					hbox_force_4_at_percent,
+					hbox_force_4_from_to);
+		else if(combo == combo_force_impulse_type)
+			combo_force_impulse_visibility(
+					UtilGtk.ComboGetActive(combo_force_impulse_type),
+					hbox_force_impulse_until_percent,
+					hbox_force_impulse_from_to);
+	}
+
+	private void combo_force_visibility (string selected, Gtk.HBox at_ms, Gtk.HBox at_percent, Gtk.HBox from_to)
+	{
+		//valid for active == "" and active == "RFD max"
+		at_ms.Visible = false;
+		from_to.Visible = false;
+		at_percent.Visible = false;
+
+		if(selected == Catalog.GetString(ForceSensorRFD.Type_INSTANTANEOUS_name))
+		{
+			at_ms.Visible = true;
+		}
+		else if(selected == Catalog.GetString(ForceSensorRFD.Type_AVERAGE_name))
+		{
+			from_to.Visible = true;
+		}
+		else if(selected == Catalog.GetString(ForceSensorRFD.Type_PERCENT_F_MAX_name))
+		{
+			at_percent.Visible = true;
+		}
+	}
+	private void combo_force_impulse_visibility (string selected, Gtk.HBox until_percent, Gtk.HBox from_to)
+	{
+		until_percent.Visible = false;
+		from_to.Visible = false;
+
+		if(selected == Catalog.GetString(ForceSensorImpulse.Type_IMP_UNTIL_PERCENT_F_MAX_name))
+		{
+			until_percent.Visible = true;
+		}
+		else if(selected == Catalog.GetString(ForceSensorImpulse.Type_IMP_RANGE_name))
+		{
+			from_to.Visible = true;
+		}
+	}
+
+	private void setRFDValues ()
+	{
+		setRFDValue(rfdList[0], check_force_1, combo_force_1_function, combo_force_1_type,
+				hbox_force_1_at_ms, spinbutton_force_1_at_ms,
+				hbox_force_1_at_percent, spinbutton_force_1_at_percent,
+				hbox_force_1_from_to, spinbutton_force_1_from, spinbutton_force_1_to);
+
+		setRFDValue(rfdList[1], check_force_2, combo_force_2_function, combo_force_2_type,
+				hbox_force_2_at_ms, spinbutton_force_2_at_ms,
+				hbox_force_2_at_percent, spinbutton_force_2_at_percent,
+				hbox_force_2_from_to, spinbutton_force_2_from, spinbutton_force_2_to);
+
+		setRFDValue(rfdList[2], check_force_3, combo_force_3_function, combo_force_3_type,
+				hbox_force_3_at_ms, spinbutton_force_3_at_ms,
+				hbox_force_3_at_percent, spinbutton_force_3_at_percent,
+				hbox_force_3_from_to, spinbutton_force_3_from, spinbutton_force_3_to);
+
+		setRFDValue(rfdList[3], check_force_4, combo_force_4_function, combo_force_4_type,
+				hbox_force_4_at_ms, spinbutton_force_4_at_ms,
+				hbox_force_4_at_percent, spinbutton_force_4_at_percent,
+				hbox_force_4_from_to, spinbutton_force_4_from, spinbutton_force_4_to);
+	}
+
+	private void setRFDValue(ForceSensorRFD rfd, Gtk.CheckButton check, Gtk.ComboBox combo_force_function, Gtk.ComboBox combo_force_type,
+				Gtk.HBox hbox_force_at_ms, Gtk.SpinButton spinbutton_force_at_ms,
+				Gtk.HBox hbox_force_at_percent, Gtk.SpinButton spinbutton_force_at_percent,
+				Gtk.HBox hbox_force_from_to, Gtk.SpinButton spinbutton_force_from, Gtk.SpinButton spinbutton_force_to)
+	{
+		check.Active = rfd.active;
+
+		combo_force_function.Active = UtilGtk.ComboMakeActive(combo_force_function, rfd.FunctionPrint(true));
+		combo_force_type.Active = UtilGtk.ComboMakeActive(combo_force_type, rfd.TypePrint(true));
+
+		hbox_force_at_ms.Visible = false;
+		hbox_force_at_percent.Visible = false;
+		hbox_force_from_to.Visible = false;
+
+		if(rfd.type == ForceSensorRFD.Types.INSTANTANEOUS)
+		{
+			hbox_force_at_ms.Visible = true;
+			spinbutton_force_at_ms.Value = rfd.num1;
+		}
+		else if(rfd.type == ForceSensorRFD.Types.AVERAGE)
+		{
+			hbox_force_from_to.Visible = true;
+			spinbutton_force_from.Value = rfd.num1;
+			spinbutton_force_to.Value = rfd.num2;
+		}
+		else if(rfd.type == ForceSensorRFD.Types.PERCENT_F_MAX)
+		{
+			hbox_force_at_percent.Visible = true;
+			spinbutton_force_at_percent.Value = rfd.num1;
+		}
+	}
+
+	private List<ForceSensorRFD> getRFDValues()
+	{
+		List<ForceSensorRFD> l = new List<ForceSensorRFD>();
+		l.Add(getRFDValue("RFD1", check_force_1, combo_force_1_function, combo_force_1_type,
+				spinbutton_force_1_at_ms, spinbutton_force_1_at_percent,
+				spinbutton_force_1_from, spinbutton_force_1_to));
+		l.Add(getRFDValue("RFD2", check_force_2, combo_force_2_function, combo_force_2_type,
+				spinbutton_force_2_at_ms, spinbutton_force_2_at_percent,
+				spinbutton_force_2_from, spinbutton_force_2_to));
+		l.Add(getRFDValue("RFD3", check_force_3, combo_force_3_function, combo_force_3_type,
+				spinbutton_force_3_at_ms, spinbutton_force_3_at_percent,
+				spinbutton_force_3_from, spinbutton_force_3_to));
+		l.Add(getRFDValue("RFD4", check_force_4, combo_force_4_function, combo_force_4_type,
+				spinbutton_force_4_at_ms, spinbutton_force_4_at_percent,
+				spinbutton_force_4_from, spinbutton_force_4_to));
+		return l;
+	}
+	private ForceSensorRFD getRFDValue(string code, Gtk.CheckButton check, Gtk.ComboBox combo_force_function, Gtk.ComboBox combo_force_type,
+				Gtk.SpinButton spinbutton_force_at_ms, Gtk.SpinButton spinbutton_force_at_percent,
+				Gtk.SpinButton spinbutton_force_from, Gtk.SpinButton spinbutton_force_to)
+	{
+		bool active = check.Active;
+		int num1 = -1;
+		int num2 = -1;
+
+		ForceSensorRFD.Functions function;
+		if(UtilGtk.ComboGetActive(combo_force_function) == ForceSensorRFD.Function_RAW_name)
+			function = ForceSensorRFD.Functions.RAW;
+		else //(UtilGtk.ComboGetActive(combo_force_function) == ForceSensorRFD.Function_FITTED_name)
+			function = ForceSensorRFD.Functions.FITTED;
+
+		ForceSensorRFD.Types type;
+		string typeStr = UtilGtk.ComboGetActive(combo_force_type);
+		if(typeStr == Catalog.GetString(ForceSensorRFD.Type_INSTANTANEOUS_name))
+		{
+			num1 = Convert.ToInt32(spinbutton_force_at_ms.Value);
+			type = ForceSensorRFD.Types.INSTANTANEOUS;
+		}
+		else if(typeStr == Catalog.GetString(ForceSensorRFD.Type_AVERAGE_name))
+		{
+			num1 = Convert.ToInt32(spinbutton_force_from.Value);
+			num2 = Convert.ToInt32(spinbutton_force_to.Value);
+			type = ForceSensorRFD.Types.AVERAGE;
+		}
+		else if(typeStr == Catalog.GetString(ForceSensorRFD.Type_PERCENT_F_MAX_name))
+		{
+			num1 = Convert.ToInt32(spinbutton_force_at_percent.Value);
+			type = ForceSensorRFD.Types.PERCENT_F_MAX;
+		}
+		else // (typeStr == Catalog.GetString(ForceSensorRFD.Type_RFD_MAX_name))
+			type = ForceSensorRFD.Types.RFD_MAX;
+
+		return new ForceSensorRFD(code, active, function, type, num1, num2);
+	}
+
+	private void setImpulseValue ()
+	{
+		check_force_impulse.Active = impulse.active;
+
+		combo_force_impulse_function.Active = UtilGtk.ComboMakeActive(combo_force_impulse_function, impulse.FunctionPrint(true));
+		combo_force_impulse_type.Active = UtilGtk.ComboMakeActive(combo_force_impulse_type, impulse.TypePrint(true));
+
+		hbox_force_impulse_until_percent.Visible = false;
+		hbox_force_impulse_from_to.Visible = false;
+
+		if(impulse.type == ForceSensorImpulse.Types.IMP_UNTIL_PERCENT_F_MAX)
+		{
+			hbox_force_impulse_until_percent.Visible = true;
+			//num1 is 0
+			spinbutton_force_impulse_until_percent.Value = impulse.num2;
+		}
+		else if(impulse.type == ForceSensorImpulse.Types.IMP_RANGE)
+		{
+			hbox_force_impulse_from_to.Visible = true;
+			spinbutton_force_impulse_from.Value = impulse.num1;
+			spinbutton_force_impulse_to.Value = impulse.num2;
+		}
+	}
+	private ForceSensorImpulse getImpulseValue ()
+	{
+		bool active = check_force_impulse.Active;
+		int num1 = -1;
+		int num2 = -1;
+
+		ForceSensorImpulse.Functions function;
+		if(UtilGtk.ComboGetActive(combo_force_impulse_function) == ForceSensorImpulse.Function_RAW_name)
+			function = ForceSensorImpulse.Functions.RAW;
+		else //(UtilGtk.ComboGetActive(combo_force_impulse_function) == ForceSensorImpulse.Function_FITTED_name)
+			function = ForceSensorImpulse.Functions.FITTED;
+
+		ForceSensorImpulse.Types type;
+		string typeStr = UtilGtk.ComboGetActive(combo_force_impulse_type);
+
+		if(typeStr == Catalog.GetString(ForceSensorImpulse.Type_IMP_UNTIL_PERCENT_F_MAX_name))
+		{
+			num1 = 0;
+			num2 = Convert.ToInt32(spinbutton_force_impulse_until_percent.Value);
+			type = ForceSensorImpulse.Types.IMP_UNTIL_PERCENT_F_MAX;
+		}
+		else // if(typeStr == Catalog.GetString(ForceSensorImpulse.Type_IMP_RANGE_name))
+		{
+			num1 = Convert.ToInt32(spinbutton_force_impulse_from.Value);
+			num2 = Convert.ToInt32(spinbutton_force_impulse_to.Value);
+			type = ForceSensorImpulse.Types.IMP_RANGE;
+		}
+
+		return new ForceSensorImpulse(active, function, type, num1, num2);
+	}
+
+	private void on_button_force_rfd_default_clicked (object o, EventArgs args)
+	{
+		Sqlite.Open();
+
+		SqliteForceSensor.DeleteAll(true);
+		SqliteForceSensor.InsertDefaultValues(true);
+
+		rfdList = SqliteForceSensor.SelectAll(false);
+		impulse = SqliteForceSensor.SelectImpulse(false);
+
+		setRFDValues();
+		setImpulseValue();
+
+		Sqlite.Close();
+	}
+
+	// ---- end of Force sensor stuff
+
+
 	// ---- Language stuff
 	
 	private void createComboLanguage() {
@@ -914,12 +1385,29 @@ public class PreferencesWindow {
 		button_accept.Sensitive = ! start;
 	}
 
-
 	//change stuff in Sqlite and in preferences object that will be retrieved by GetPreferences
 	void on_button_accept_clicked (object o, EventArgs args)
 	{
 		Sqlite.Open();
 
+
+		//appearance tab
+		Preferences.MaximizedTypes maximizedTypeFromGUI = get_maximized_from_gui();
+		if(preferences.maximized != maximizedTypeFromGUI)
+		{
+			SqlitePreferences.Update("maximized", maximizedTypeFromGUI.ToString(), true);
+			preferences.maximized = maximizedTypeFromGUI;
+		}
+
+		if( preferences.personWinHide != PreferencesWindowBox.check_appearance_person_win_hide.Active ) {
+			SqlitePreferences.Update("personWinHide", PreferencesWindowBox.check_appearance_person_win_hide.Active.ToString(), true);
+			preferences.personWinHide = PreferencesWindowBox.check_appearance_person_win_hide.Active;
+		}
+		if( preferences.encoderCaptureShowOnlyBars != PreferencesWindowBox.check_appearance_encoder_only_bars.Active ) {
+			SqlitePreferences.Update("encoderCaptureShowOnlyBars", PreferencesWindowBox.check_appearance_encoder_only_bars.Active.ToString(), true);
+			preferences.encoderCaptureShowOnlyBars = PreferencesWindowBox.check_appearance_encoder_only_bars.Active;
+		}
+		
 		if( preferences.digitsNumber != Convert.ToInt32(UtilGtk.ComboGetActive(combo_decimals)) ) {
 			SqlitePreferences.Update("digitsNumber", UtilGtk.ComboGetActive(combo_decimals), true);
 			preferences.digitsNumber = Convert.ToInt32(UtilGtk.ComboGetActive(combo_decimals));
@@ -929,7 +1417,7 @@ public class PreferencesWindow {
 			SqlitePreferences.Update("showPower", PreferencesWindowBox.checkbutton_power.Active.ToString(), true);
 			preferences.showPower = PreferencesWindowBox.checkbutton_power.Active;
 		}
-		
+
 		if( preferences.showStiffness != PreferencesWindowBox.checkbutton_stiffness.Active ) {
 			SqlitePreferences.Update("showStiffness", PreferencesWindowBox.checkbutton_stiffness.Active.ToString(), true);
 			preferences.showStiffness = PreferencesWindowBox.checkbutton_stiffness.Active;
@@ -963,6 +1451,11 @@ public class PreferencesWindow {
 			preferences.askDeletion = PreferencesWindowBox.checkbutton_ask_deletion.Active;
 		}
 
+		if( preferences.muteLogs != PreferencesWindowBox.checkbutton_mute_logs.Active ) {
+			SqlitePreferences.Update("muteLogs", PreferencesWindowBox.checkbutton_mute_logs.Active.ToString(), true);
+			preferences.muteLogs = PreferencesWindowBox.checkbutton_mute_logs.Active;
+		}
+
 		if( preferences.weightStatsPercent != PreferencesWindowBox.radio_weight_percent.Active ) {
 			SqlitePreferences.Update("weightStatsPercent", PreferencesWindowBox.radio_weight_percent.Active.ToString(), true);
 			preferences.weightStatsPercent = PreferencesWindowBox.radio_weight_percent.Active;
@@ -1114,11 +1607,20 @@ public class PreferencesWindow {
 			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.NONE;
 		}
 
+		preferences.encoderCaptureBarplotFontSize = preferencesChange(
+				"encoderCaptureBarplotFontSize",
+				preferences.encoderCaptureBarplotFontSize,
+				(int) PreferencesWindowBox.spin_encoder_capture_barplot_font_size.Value);
+
 		preferences.encoderShowStartAndDuration = preferencesChange(
 				"encoderShowStartAndDuration",
 				preferences.encoderShowStartAndDuration,
 				PreferencesWindowBox.check_show_start_and_duration.Active);
 		
+		preferences.encoderCaptureCutByTriggers = preferencesChange(
+				"encoderCaptureCutByTriggers",
+				preferences.encoderCaptureCutByTriggers,
+				PreferencesWindowBox.check_encoder_capture_cut_by_triggers.Active);
 
 		//---- end of encoder capture
 		
@@ -1146,9 +1648,33 @@ public class PreferencesWindow {
 
 		SqlitePreferences.Update("encoder1RMMethod", encoder1RMMethod.ToString(), true);
 		preferences.encoder1RMMethod = encoder1RMMethod;
-		
+
+		//---- force sensor
+
+		List<ForceSensorRFD> newRFDList = getRFDValues();
+		int i = 0;
+		foreach(ForceSensorRFD rfd in newRFDList)
+		{
+			if(rfdList[i].Changed(rfd))
+			{
+				SqliteForceSensor.Update(true, rfd);
+				rfdList[i] = rfd;
+			}
+			i ++;
+		}
+
+		ForceSensorImpulse newImpulse = getImpulseValue();
+		if(newImpulse.Changed(impulse))
+		{
+			SqliteForceSensor.UpdateImpulse(true, newImpulse);
+			impulse = newImpulse;
+		}
+
+		// end of force sensor
+
+
 		//---- end of encoder other
-		
+
 		//multimedia ----
 		if( preferences.volumeOn != PreferencesWindowBox.checkbutton_volume.Active ) {
 			SqlitePreferences.Update("volumeOn", PreferencesWindowBox.checkbutton_volume.Active.ToString(), true);
@@ -1203,6 +1729,17 @@ public class PreferencesWindow {
 		PreferencesWindowBox = null;
 	}
 
+	private Preferences.MaximizedTypes get_maximized_from_gui()
+	{
+		if( ! PreferencesWindowBox.check_appearance_maximized.Active )
+			return Preferences.MaximizedTypes.NO;
+
+		if( ! PreferencesWindowBox.check_appearance_maximized_undecorated.Active )
+			return Preferences.MaximizedTypes.YES;
+
+		return Preferences.MaximizedTypes.YESUNDECORATED;
+	}
+
 	private bool preferencesChange(string prefName, bool prefValue, bool bNew) 
 	{
 		if(prefValue != bNew)
@@ -1236,4 +1773,13 @@ public class PreferencesWindow {
 		get { return preferences;  }
 	}
 
+	public List<ForceSensorRFD> GetRFDList
+	{
+		get { return rfdList;  }
+	}
+
+	public ForceSensorImpulse GetImpulse
+	{
+		get { return impulse;  }
+	}
 }
