@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -37,13 +37,9 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label label_flicker_lights_cycle;
 	[Widget] Gtk.Label label_flicker_lights_frequency;
 
-	[Widget] Gtk.Label label_extra_window_radio_reaction_time;
 	[Widget] Gtk.RadioButton extra_window_radio_reaction_time;
-	[Widget] Gtk.Label label_extra_window_radio_reaction_time_animation_lights;
 	[Widget] Gtk.RadioButton extra_window_radio_reaction_time_animation_lights;
-	[Widget] Gtk.Label label_extra_window_radio_reaction_time_flicker;
 	[Widget] Gtk.RadioButton extra_window_radio_reaction_time_flicker;
-	[Widget] Gtk.Label label_extra_window_radio_reaction_time_discriminative;
 	[Widget] Gtk.RadioButton extra_window_radio_reaction_time_discriminative;
 
 	
@@ -53,6 +49,8 @@ public partial class ChronoJumpWindow
 		hbox_flicker_lights.Visible = false;
 		hbox_discriminative_lights.Visible = false;
 
+		vbox_last_test_buttons.Sensitive = false;
+
 		changeTestImage("","", "reaction_time.png");
 
 		currentReactionTimeType = new ReactionTimeType("reactionTime");
@@ -87,7 +85,7 @@ public partial class ChronoJumpWindow
 
 		//intializeVariables if not done before
 		event_execute_initializeVariables(
-			! chronopicWin.Connected,	//is simulated
+			! cp2016.StoredCanCaptureContacts, //is simulated
 			currentPerson.UniqueID, 
 			currentPerson.Name, 
 			Catalog.GetString("Phases"),  	  //name of the different moments
@@ -197,7 +195,7 @@ public partial class ChronoJumpWindow
 		int speed = Convert.ToInt32(spinbutton_flicker_lights_speed.Value);
 		ChronopicAuto cs = new ChronopicStartReactionTimeAnimation();
 		cs.CharToSend = "f";
-		cs.Write(chronopicWin.SP,speed);
+		cs.Write(cp2016.SP,speed);
 
 		on_button_execute_test_clicked(o, args);
 	}
@@ -328,7 +326,7 @@ public class EditReactionTimeWindow : EditEventWindow
 
 	EditReactionTimeWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "edit_event", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "edit_event.glade", "edit_event", "chronojump");
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		
