@@ -175,6 +175,7 @@ public class RepetitiveConditionsWindow
 		createComboEncoderAutomaticVariable();
 
 		bestSetValue = 0;
+		notebook_encoder_conditions.CurrentPage = 3; //power
 
 		putNonStandardIcons();
 	}
@@ -203,7 +204,8 @@ public class RepetitiveConditionsWindow
 		RepetitiveConditionsWindowBox.volumeOn = volumeOn;
 	}
 
-	void showWidgets(Constants.BellModes bellMode) {
+	void showWidgets(Constants.BellModes bellMode)
+	{
 		frame_best_and_worst.Hide();
 		frame_conditions.Hide();
 		hbox_jump_best_worst.Hide();
@@ -213,6 +215,7 @@ public class RepetitiveConditionsWindow
 		frame_encoder_automatic_conditions.Hide();
 		vbox_encoder_manual.Hide();
 		notebook_encoder_conditions.Hide();
+		checkbutton_inertial_discard_first_three.Hide();
 
 		if(bellMode == Constants.BellModes.JUMPS) {
 			frame_best_and_worst.Show();
@@ -224,12 +227,14 @@ public class RepetitiveConditionsWindow
 			hbox_run_best_worst.Show();
 			hbox_run_conditions.Show();
 			frame_conditions.Show();
-		} else { //encoder
-			notebook_encoder_conditions.CurrentPage = 3; //power
+		} else { //encoder (grav and inertial)
 			frame_encoder_automatic_conditions.Show();
 			vbox_encoder_manual.Show();
 			if(checkbutton_encoder_show_manual_feedback.Active)
 				notebook_encoder_conditions.Show();
+
+			if(bellMode == Constants.BellModes.ENCODERINERTIAL)
+				checkbutton_inertial_discard_first_three.Show();
 		}
 	}
 		
@@ -312,6 +317,36 @@ public class RepetitiveConditionsWindow
 		args.RetVal = true;
 	}
 
+	public bool FeedbackActive (Constants.BellModes bellMode)
+	{
+		if(bellMode == Constants.BellModes.JUMPS)
+		{
+			if(checkbutton_height_greater.Active || checkbutton_height_lower.Active ||
+					checkbutton_tf_greater.Active || checkbutton_tf_lower.Active ||
+					checkbutton_tc_lower.Active || checkbutton_tc_greater.Active ||
+					checkbutton_tf_tc_greater.Active || checkbutton_tf_tc_lower.Active)
+				return true;
+		}
+		else if(bellMode == Constants.BellModes.RUNS)
+		{
+			if(checkbutton_time_lower.Active || checkbutton_time_greater.Active)
+				return true;
+		}
+		else { //encoder (grav and inertial)
+			if(checkbutton_encoder_automatic_greater.Active || checkbutton_encoder_automatic_lower.Active ||
+					checkbutton_encoder_height_higher.Active || checkbutton_encoder_height_lower.Active ||
+					checkbutton_encoder_mean_speed_higher.Active || checkbutton_encoder_mean_speed_lower.Active ||
+					checkbutton_encoder_max_speed_higher.Active || checkbutton_encoder_max_speed_lower.Active ||
+					checkbutton_encoder_mean_force_higher.Active || checkbutton_encoder_mean_force_lower.Active ||
+					checkbutton_encoder_max_force_higher.Active || checkbutton_encoder_max_force_lower.Active ||
+					checkbutton_encoder_power_higher.Active || checkbutton_encoder_power_lower.Active ||
+					checkbutton_encoder_peakpower_higher.Active || checkbutton_encoder_peakpower_lower.Active)
+				return true;
+		}
+
+		return false;
+	}
+
 	public bool VolumeOn {
 		set { volumeOn = value; }
 	}
@@ -611,6 +646,14 @@ public class RepetitiveConditionsWindow
 		return -1;
 	}
 
+	public int Notebook_encoder_conditions_page {
+		set { notebook_encoder_conditions.CurrentPage = value; }
+	}
+
+	public bool Encoder_show_manual_feedback {
+		set { checkbutton_encoder_show_manual_feedback.Active = value; }
+	}
+
 	//height
 	public bool EncoderHeightHigher {
 		get { return checkbutton_encoder_height_higher.Active; }
@@ -629,16 +672,20 @@ public class RepetitiveConditionsWindow
 	//speed
 	public bool EncoderMeanSpeedHigher {
 		get { return checkbutton_encoder_mean_speed_higher.Active; }
+		set { checkbutton_encoder_mean_speed_higher.Active = value; } //used on Compujump
 	}
 	public double EncoderMeanSpeedHigherValue {
 		get { return Convert.ToDouble(spinbutton_encoder_mean_speed_higher.Value); }
+		set { spinbutton_encoder_mean_speed_higher.Value = value; } //used on Compujump
 	}
 	
 	public bool EncoderMeanSpeedLower {
 		get { return checkbutton_encoder_mean_speed_lower.Active; }
+		set { checkbutton_encoder_mean_speed_lower.Active = value; } //used on Compujump
 	}
 	public double EncoderMeanSpeedLowerValue {
 		get { return Convert.ToDouble(spinbutton_encoder_mean_speed_lower.Value); }
+		set { spinbutton_encoder_mean_speed_lower.Value = value; } //used on Compujump
 	}
 
 	public bool EncoderMaxSpeedHigher {
