@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -56,8 +56,6 @@ public class ReportWindow {
 	
 	static ReportWindow ReportWindowBox;
 
-	Gtk.Window parent;
-	
 	//private int sessionID;
 
 	Report report;
@@ -68,9 +66,9 @@ public class ReportWindow {
 
 	ReportWindow (Gtk.Window parent, Report report ) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "report_window", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "report_window.glade", "report_window", "chronojump");
 		gladeXML.Autoconnect(this);
-		this.parent = parent;
+		report_window.Parent = parent;
 		
 		//put an icon to window
 		UtilGtk.IconWindow(report_window);
