@@ -69,6 +69,7 @@ public class SessionAddEditWindow {
 	string [] levels;
 
 	bool addSession;
+	private bool textviewChanging = false;
 	
 	private Session currentSession;
 	private Gtk.Button fakeButtonAccept;
@@ -121,7 +122,9 @@ public class SessionAddEditWindow {
 
 			//showSportStuffWithLoadedData();
 		}
-			
+
+		textview.Buffer.Changed += new EventHandler(textviewChanged);
+		textviewChanging = false;
 	}
 	
 	static public SessionAddEditWindow Show (Gtk.Window parent, Session currentSession)
@@ -189,10 +192,33 @@ public class SessionAddEditWindow {
 
 	}
 
-	void on_entries_required_changed (object o, EventArgs args) {
+	void on_entries_required_changed (object o, EventArgs args)
+	{
+		entry_name.Text = Util.MakeValidSQL(entry_name.Text);
+
 		showHideButtonAccept();
 	}
-	
+
+	private void on_entry_place_changed (object o, EventArgs args)
+	{
+		entry_place.Text = Util.MakeValidSQL(entry_place.Text);
+	}
+
+	private void textviewChanged(object o,EventArgs args)
+	{
+		if(textviewChanging)
+			return;
+
+		textviewChanging = true;
+
+		TextBuffer tb = o as TextBuffer;
+		if (o == null)
+			return;
+
+		tb.Text = Util.MakeValidSQL(tb.Text);
+		textviewChanging = false;
+	}
+
 	void showHideButtonAccept() {
 		if(entry_name.Text.ToString().Length > 0 &&
 			( ! (!radiobutton_diff_sports.Active && 
@@ -524,8 +550,10 @@ public class SessionAddEditWindow {
 		genericWin.Button_accept.Clicked += new EventHandler(on_sport_add_accepted);
 	}
 
-	private void on_sport_add_accepted (object o, EventArgs args) {
+	private void on_sport_add_accepted (object o, EventArgs args)
+	{
 		genericWin.Button_accept.Clicked -= new EventHandler(on_sport_add_accepted);
+
 		string newSportName = genericWin.EntrySelected;
 		if(Sqlite.Exists(false, Constants.SportTable, newSportName) ||
 				newSportName == Catalog.GetString(Constants.SportUndefined) || //let's save problems
@@ -562,7 +590,6 @@ public class SessionAddEditWindow {
 		//check if name of session exists (is owned by other session),
 		//but all is ok if the name is the same as the old name (editing)
 		string name = Util.RemoveTildeAndColon(entry_name.Text);
-		name = Util.RemoveChar(name, '"');
 
 		bool sessionNameExists = Sqlite.Exists (false, Constants.SessionTable, name);
 		if(sessionNameExists && name != currentSession.Name ) {
@@ -590,8 +617,6 @@ public class SessionAddEditWindow {
 
 			string place = Util.RemoveTildeAndColon(entry_place.Text);
 			string comments = Util.RemoveTildeAndColon(textview.Buffer.Text);
-			place = Util.RemoveChar(place, '"');
-			comments = Util.RemoveChar(comments, '"');
 
 			if(addSession) 
 				currentSession = new Session (name, place,
@@ -689,12 +714,15 @@ public class SessionLoadWindow {
 
 		//put an icon to window
 		UtilGtk.IconWindow(session_load);
-		
+
 		createTreeView(treeview_session_load, false, false);
 		store = getStore(false, false);
 		treeview_session_load.Model = store;
 		fillTreeView(treeview_session_load, store, false, false);
 
+		store.SetSortColumnId(1, Gtk.SortType.Descending); //date
+		store.ChangeSortColumn();
+
 		button_accept.Sensitive = false;
 		entry_search_filter.CanFocus = true;
 		entry_search_filter.IsFocus = true;
@@ -720,7 +748,7 @@ public class SessionLoadWindow {
 		TreeStore s;
 		if(showContacts && showEncoder)
 			s = new TreeStore(
-				typeof (string), typeof (string), typeof (string), typeof (string), //number, name, place, date
+				typeof (string), typeof (string), typeof (string), typeof (string), //number (hidden), date, name, place
 				typeof (string), typeof (string), typeof (string), typeof (string), //persons, sport, spllity, level
 				typeof (string), typeof (string), typeof (string), typeof(string), //jumps s,r, runs s, i, 
 				typeof (string), typeof (string), typeof (string), 	//rt, pulses, mc
@@ -729,7 +757,7 @@ public class SessionLoadWindow {
 			       	);
 		else if(showContacts && ! showEncoder)
 			s = new TreeStore(
-				typeof (string), typeof (string), typeof (string), typeof (string), //number, name, place, date
+				typeof (string), typeof (string), typeof (string), typeof (string), //number (hidden), date, name, place
 				typeof (string), typeof (string), typeof (string), typeof (string), //persons, sport, spllity, level
 				typeof (string), typeof (string), typeof (string), typeof(string), //jumps s,r, runs s, i, 
 				typeof (string), typeof (string), typeof (string), 	//rt, pulses, mc
@@ -737,20 +765,35 @@ public class SessionLoadWindow {
 			       	);
 		else if(! showContacts && showEncoder)
 			s = new TreeStore(
-				typeof (string), typeof (string), typeof (string), typeof (string), //number, name, place, date
+				typeof (string), typeof (string), typeof (string), typeof (string), //number (hidden), date, name, place
 				typeof (string), typeof (string), typeof (string), typeof (string), //persons, sport, spllity, level
 				typeof (string), typeof (string), 			//encoder s, c
 				typeof (string)						//comments
 			       	);
 		else // ! showContacts && ! showEncoder
 			s = new TreeStore(
-				typeof (string), typeof (string), typeof (string), typeof (string), //number, name, place, date
+				typeof (string), typeof (string), typeof (string), typeof (string), //number (hidden), date, name, place
 				typeof (string), typeof (string), typeof (string), typeof (string), //persons, sport, spllity, level
 				typeof (string)						//comments
 			       	);
+
+		//s.SetSortFunc (0, UtilGtk.IdColumnCompare); //not needed, it's hidden
+		s.SetSortFunc (1, dateColumnCompare);
+		s.ChangeSortColumn();
+
 		return s;
 	}
 
+
+	private static int dateColumnCompare (TreeModel model, TreeIter iter1, TreeIter iter2)
+	{
+		DateTime val1;
+		DateTime val2;
+		val1 = UtilDate.FromSql(model.GetValue(iter1, 1).ToString());
+		val2 = UtilDate.FromSql(model.GetValue(iter2, 1).ToString());
+
+		return DateTime.Compare(val1, val2);
+	}
 	
 	static public SessionLoadWindow Show (Gtk.Window parent, WindowType type)
 	{
@@ -764,14 +807,29 @@ public class SessionLoadWindow {
 		return SessionLoadWindowBox;
 	}
 	
-	private void createTreeView (Gtk.TreeView tv, bool showContacts, bool showEncoder) {
+	private void createTreeView (Gtk.TreeView tv, bool showContacts, bool showEncoder)
+	{
 		tv.HeadersVisible=true;
 		int count = 0;
+
+		Gtk.TreeViewColumn colID = new Gtk.TreeViewColumn(Catalog.GetString ("Number"), new CellRendererText(), "text", count);
+		colID.SortColumnId = count ++;
+		colID.SortIndicator = true;
+		colID.Visible = false; //hidden
+		tv.AppendColumn (colID);
+
+		//tv.AppendColumn ( Catalog.GetString ("Date"), new CellRendererText(), "text", count++);
+		Gtk.TreeViewColumn colDate = new Gtk.TreeViewColumn(Catalog.GetString ("Date"), new CellRendererText(), "text", count);
+		colDate.SortColumnId = count ++;
+		colDate.SortIndicator = true;
+		tv.AppendColumn (colDate);
+
+		Gtk.TreeViewColumn colName = new Gtk.TreeViewColumn(Catalog.GetString ("Name"), new CellRendererText(), "text", count);
+		colName.SortColumnId = count ++;
+		colName.SortIndicator = true;
+		tv.AppendColumn (colName);
 		
-		tv.AppendColumn ( Catalog.GetString ("Number"), new CellRendererText(), "text", count++);
-		tv.AppendColumn ( Catalog.GetString ("Name"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Place"), new CellRendererText(), "text", count++);
-		tv.AppendColumn ( Catalog.GetString ("Date"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Persons"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Sport"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Specialty"), new CellRendererText(), "text", count++);
@@ -842,6 +900,10 @@ public class SessionLoadWindow {
 		fillTreeView(treeview_session_load, store,
 				checkbutton_show_data_jump_run.Active, checkbutton_show_data_encoder.Active);
 		
+		store.SetSortColumnId(1, Gtk.SortType.Descending); //date
+		store.ChangeSortColumn();
+
+
 		/*
 		 * after clicking on checkbuttons, treeview row gets unselected
 		 * call onSelectionEntry to see if there's a row selected
@@ -882,9 +944,11 @@ public class SessionLoadWindow {
 				myLevel = Catalog.GetString(myStringFull[6]);
 
 			if(showContacts && showEncoder)
-				store.AppendValues (myStringFull[0], myStringFull[1], 
-						myStringFull[2], 
+				store.AppendValues (
+						myStringFull[0], 	//session num
 						myStringFull[3],	//session date
+						myStringFull[1], 	//session name
+						myStringFull[2], 	//session place
 						myStringFull[8],	//number of jumpers x session
 						mySport,		//personsSport
 						mySpeciallity,		//personsSpeciallity
@@ -901,9 +965,11 @@ public class SessionLoadWindow {
 						myStringFull[7]		//description of session
 						);
 			else if(showContacts && ! showEncoder)
-				store.AppendValues (myStringFull[0], myStringFull[1], 
-						myStringFull[2], 
+				store.AppendValues (
+						myStringFull[0], 	//session num
 						myStringFull[3],	//session date
+						myStringFull[1], 	//session name
+						myStringFull[2], 	//session place
 						myStringFull[8],	//number of jumpers x session
 						mySport,		//personsSport
 						mySpeciallity,		//personsSpeciallity
@@ -918,9 +984,11 @@ public class SessionLoadWindow {
 						myStringFull[7]		//description of session
 						);
 			else if(! showContacts && showEncoder)
-				store.AppendValues (myStringFull[0], myStringFull[1], 
-						myStringFull[2], 
+				store.AppendValues (
+						myStringFull[0], 	//session num
 						myStringFull[3],	//session date
+						myStringFull[1], 	//session name
+						myStringFull[2], 	//session place
 						myStringFull[8],	//number of jumpers x session
 						mySport,		//personsSport
 						mySpeciallity,		//personsSpeciallity
@@ -930,9 +998,11 @@ public class SessionLoadWindow {
 						myStringFull[7]		//description of session
 						);
 			else // ! showContacts && ! showEncoder
-				store.AppendValues (myStringFull[0], myStringFull[1], 
-						myStringFull[2], 
+				store.AppendValues (
+						myStringFull[0], 	//session num
 						myStringFull[3],	//session date
+						myStringFull[1], 	//session name
+						myStringFull[2], 	//session place
 						myStringFull[8],	//number of jumpers x session
 						mySport,		//personsSport
 						mySpeciallity,		//personsSpeciallity
