@@ -19,9 +19,11 @@
  */
 
 using System;
+using System.IO;
 using Gtk;
 using Gdk;
 using Glade;
+using Mono.Unix;
 
 public class SplashWindow
 {
@@ -31,11 +33,14 @@ public class SplashWindow
 	[Widget] Gtk.ProgressBar progressbarRate;
 	[Widget] Gtk.ProgressBar progressbarSubRate;
 	[Widget] Gtk.Label myLabel;
-	[Widget] Gtk.Button button_cancel;
+	[Widget] Gtk.Button button_close;
 
-	
-	public Gtk.Button fakeButtonCancel;
+	[Widget] Gtk.Button button_open_database_folder;
+	[Widget] Gtk.Button button_open_docs_folder;
+
+	[Widget] Gtk.Button fakeButtonClose;
 	public bool FakeButtonCreated = false;
+	string progVersion = "";
 	
 	static SplashWindow SplashWindowBox;
 
@@ -48,18 +53,21 @@ public class SplashWindow
 		//put an icon to window
 		UtilGtk.IconWindow(splash_window);
 
-		fakeButtonCancel = new Gtk.Button();
+		FakeButtonClose = new Gtk.Button();
 		FakeButtonCreated = true;
 
-		CancelButtonShow(false);
 		hideAllProgressbars();
 
+		//hidden always excepted when called to be shown (see below)
+		button_open_database_folder.Hide();
+		button_open_docs_folder.Hide();
+
 		//put logo image
 		Pixbuf pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameLogo320);
 		image_logo.Pixbuf = pixbuf;
 	}
-	
+
 	static public SplashWindow Show ()
 	{
 		if (SplashWindowBox == null) {
@@ -105,30 +113,56 @@ public class SplashWindow
 	public void UpdateLabel (string text) {
 		myLabel.Text = text;
 	}
-	
-	/* 
-	 * cancel	
-	 * for SPing
-	 */
-	public void CancelButtonShow(bool show) {
-		if(show)
-			button_cancel.Show();
+
+	public void Show_button_open_database_folder () {
+		button_open_database_folder.Show();
+	}
+	private void on_button_open_database_folder_clicked (object o, EventArgs args)
+	{
+		string database_url = Util.GetDatabaseDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
+		string database_temp_url = Util.GetDatabaseTempDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
+
+		System.IO.FileInfo file1 = new System.IO.FileInfo(database_url); //potser cal una arrobar abans (a windows)
+		System.IO.FileInfo file2 = new System.IO.FileInfo(database_temp_url); //potser cal una arrobar abans (a windows)
+
+		if(file1.Exists)
+			System.Diagnostics.Process.Start(Util.GetDatabaseDir());
+		else if(file2.Exists)
+			System.Diagnostics.Process.Start(Util.GetDatabaseTempDir());
 		else
-			button_cancel.Hide();
-	}
-	
-	protected void on_button_cancel_clicked (object o, EventArgs args)
-	{
-		fakeButtonCancel.Click();
-	}
-	
-	public Button FakeButtonCancel 
-	{
-		set { fakeButtonCancel = value; }
-		get { return fakeButtonCancel; }
+			new DialogMessage(Constants.MessageTypes.WARNING, Constants.DatabaseNotFound);
 	}
 
-			
+	public void Show_button_open_docs_folder () {
+		button_open_docs_folder.Show();
+	}
+	private void on_button_open_docs_folder_clicked (object o, EventArgs args)
+	{
+		LogB.Information("Opening docs at: " + Path.GetFullPath(Util.GetManualDir()));
+		try {
+			System.Diagnostics.Process.Start(Path.GetFullPath(Util.GetManualDir()));
+		} catch {
+			new DialogMessage(Constants.MessageTypes.WARNING,
+					"Sorry, folder does not exist." + "\n\n" +
+					Path.GetFullPath(Util.GetManualDir())
+					);
+		}
+	}
+
+	public void ShowButtonClose()
+	{
+		button_close.Show();
+	}
+
+	public void Button_close_label (string str) {
+		button_close.Label = str;
+	}
+
+	protected void on_button_close_clicked (object o, EventArgs args)
+	{
+		fakeButtonClose.Click();
+		Hide();
+	}
 
 	public void Destroy () {
 		//it seem on some machines (MacOSX) splash_window maybe is Destroyed previously because on_delete_event it's called
@@ -159,8 +193,22 @@ public class SplashWindow
 		LogB.Debug("splash_window hide end");
 	}
 
+	public string ProgVersion {
+		set { progVersion = value; }
+	}
+
 	private void on_delete_event (object o, DeleteEventArgs args) {
 		splash_window.Destroy ();
 	}
-}
 
+	public Button Button_close {
+		get { return button_close; }
+	}
+
+	public Button FakeButtonClose
+	{
+		set { fakeButtonClose = value; }
+		get { return fakeButtonClose; }
+	}
+
+}
