@@ -27,14 +27,18 @@ public class Preferences
 	 * these are sent to preferences window
 	 */
 
-	public int digitsNumber;
+	//appearance tab
+	public enum MaximizedTypes { NO, YES, YESUNDECORATED};
+	public MaximizedTypes maximized;
+	public bool personWinHide;
+	public bool encoderCaptureShowOnlyBars;
+
 	public bool showPower;
 	public bool showStiffness;
 	public bool showInitialSpeed;
 	public bool showAngle;
 	public bool showQIndex;
 	public bool showDjIndex;
-	public bool askDeletion;
 	public bool weightStatsPercent;		//AKA weightPercentPreferred
 	public bool heightPreferred;
 	public bool metersSecondsPreferred;
@@ -58,7 +62,9 @@ public class Preferences
 	public bool encoderCaptureCheckFullyExtended;
 	public int encoderCaptureCheckFullyExtendedValue;
 	public Constants.EncoderAutoSaveCurve encoderAutoSaveCurve;
+	public int encoderCaptureBarplotFontSize;
 	public bool encoderShowStartAndDuration;
+	public bool encoderCaptureCutByTriggers;
 	
 	//encoder other
 	public bool encoderPropulsive;
@@ -70,7 +76,12 @@ public class Preferences
 	public string language;
 	public bool RGraphsTranslate;
 	public bool useHeightsOnJumpIndexes;
-	
+
+	//advanced tab
+	public bool askDeletion;
+	public int digitsNumber;
+	public bool muteLogs;
+
 	/*
 	 * these are NOT sent to preferences window
 	 */
