@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -163,16 +163,16 @@ public class Report : ExportSession
 		}
 		
 		if(ShowSimpleRuns) 
-			printRuns(Catalog.GetString("Simple runs"));
+			printRuns(Catalog.GetString("Simple races"));
 		
 		if (ShowIntervalRuns) {
 			string myTitle = "";
 			if(ShowIntervalRunsWithSubruns) {
-				myTitle = Catalog.GetString("interval runs") + 
-						" (" + Catalog.GetString("with tracks") + ")";
+				myTitle = Catalog.GetString("interval races") +
+						" (" + Catalog.GetString("with laps") + ")";
 			} else {
-				myTitle = Catalog.GetString("interval runs") + 
-						" (" + Catalog.GetString("without tracks") + ")";
+				myTitle = Catalog.GetString("interval races") +
+						" (" + Catalog.GetString("without laps") + ")";
 			}
 			printRunsInterval(ShowIntervalRunsWithSubruns, myTitle);
 		}
