@@ -193,6 +193,8 @@ class SqliteEncoder : Sqlite
 	
 	//WARNING because SqliteEncoder.Select may not return nothing, and then cannot be assigned to eSQL
 	//see: delete_encoder_curve(bool dbconOpened, int uniqueID)
+	//and: manageCurvesOfThisSignal
+	//
 	//don't care for the 0, 0, 0  because selection will be based on the myUniqueID and only one row will be returned
 	//or
 	//pass uniqueID==-1 and personID, sessionID, signalOrCurve values, and will return some records
@@ -267,8 +269,9 @@ class SqliteEncoder : Sqlite
 
 		ArrayList array = new ArrayList(1);
 
-		EncoderSQL es = new EncoderSQL();
-		while(reader.Read()) {
+		EncoderSQL eSQL = new EncoderSQL();
+		while(reader.Read())
+		{
 			string [] strFull = reader[15].ToString().Split(new char[] {':'});
 			EncoderConfiguration econf = new EncoderConfiguration(
 				(Constants.EncoderConfigurationNames) 
@@ -290,7 +293,7 @@ class SqliteEncoder : Sqlite
 				videoURL = addURLpath(fixOSpath(reader[14].ToString()));
 			
 			//LogB.SQL(econf.ToString(":", true));
-			es = new EncoderSQL (
+			eSQL = new EncoderSQL (
 					reader[0].ToString(),			//uniqueID
 					Convert.ToInt32(reader[1].ToString()),	//personID	
 					Convert.ToInt32(reader[2].ToString()),	//sessionID
@@ -312,8 +315,9 @@ class SqliteEncoder : Sqlite
 					reader[18].ToString(),			//future3
 					reader[19].ToString()			//EncoderExercise.name
 					);
-			array.Add (es);
+			array.Add (eSQL);
 		}
+
 		reader.Close();
 		if(! dbconOpened)
 			Sqlite.Close();
@@ -733,16 +737,22 @@ class SqliteEncoder : Sqlite
 			"future3 TEXT )";	//weightAngle (unused)
 		dbcmd.ExecuteNonQuery();
 	}
-	
-	public static void InsertExercise(bool dbconOpened, string name, int percentBodyWeight, 
+
+	//if uniqueID == -1, NULL will be used (correlative uniqueID)
+	//uniqueID != -1 when an exercise is downloaded from server on compujump and need to have the same uniqueID as server
+	public static void InsertExercise(bool dbconOpened, int uniqueID, string name, int percentBodyWeight,
 			string ressistance, string description, string speed1RM)	 //speed1RM decimal point = '.'
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
 
+		string uniqueIDStr = "NULL";
+		if(uniqueID != -1)
+			uniqueIDStr = uniqueID.ToString();
+
 		dbcmd.CommandText = "INSERT INTO " + Constants.EncoderExerciseTable +  
 				" (uniqueID, name, percentBodyWeight, ressistance, description, future1, future2, future3)" +
-				" VALUES (NULL, \"" + name + "\", " + percentBodyWeight + ", \"" + 
+				" VALUES (" + uniqueIDStr + ", \"" + name + "\", " + percentBodyWeight + ", \"" +
 				ressistance + "\", \"" + description + "\", \"" + speed1RM + "\", '', '')";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -764,7 +774,7 @@ class SqliteEncoder : Sqlite
 		
 		foreach(string line in iniEncoderExercises) {
 			string [] parts = line.Split(new char[] {':'});
-			InsertExercise(true, parts[0], Convert.ToInt32(parts[1]), parts[2], parts[3], parts[4]);
+			InsertExercise(true, -1, parts[0], Convert.ToInt32(parts[1]), parts[2], parts[3], parts[4]);
 		}
 
 		addEncoderFreeExercise();
@@ -776,13 +786,13 @@ class SqliteEncoder : Sqlite
 	{
 		bool exists = Sqlite.Exists (true, Constants.EncoderExerciseTable, "Free");
 		if(! exists)
-			InsertExercise(true, "Free", 0, "", "", "");
+			InsertExercise(true, -1, "Free", 0, "", "", "");
 	}
 	protected internal static void addEncoderJumpExercise()
 	{
 		bool exists = Sqlite.Exists (true, Constants.EncoderExerciseTable, "Jump");
 		if(! exists)
-			InsertExercise(true, "Jump", 100, "", "", "");
+			InsertExercise(true, -1, "Jump", 100, "", "", "");
 	}
 	protected internal static void addEncoderInclinedExercises()
 	{
@@ -794,7 +804,7 @@ class SqliteEncoder : Sqlite
 		
 		foreach(string line in iniEncoderExercises) {
 			string [] parts = line.Split(new char[] {':'});
-			InsertExercise(true, parts[0], Convert.ToInt32(parts[1]), parts[2], parts[3], parts[4]);
+			InsertExercise(true, -1, parts[0], Convert.ToInt32(parts[1]), parts[2], parts[3], parts[4]);
 		}
 	}
 
