@@ -15,13 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
 using System.Data;
 using System.IO;
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 using Mono.Data.Sqlite;
 
 
@@ -237,7 +238,63 @@ class SqliteJumpType : Sqlite
 			Sqlite.Close();
 		}
 	}
+	
+	//use SelectJumpTypes object. Since 1.6.3
+	public static List<object> SelectJumpTypesNew(bool dbconOpened, string allJumpsName, string filter, bool onlyName) 
+	{
+		//allJumpsName: add and "allJumpsName" value
+		//filter:
+		//	"" all jumps,
+		//	"TC" only with previous fall,
+		//	"nonTC" only not with previous fall
+		//	used in gui/stats.cs
+		//onlyName: return only type name
 
+		string whereString = "";
+		if(filter == "TC") { whereString = " WHERE startIn == 0 "; }
+		else if(filter == "nonTC") { whereString = " WHERE startIn == 1 "; }
+
+		openIfNeeded(dbconOpened);
+
+		dbcmd.CommandText = "SELECT * " +
+			" FROM " + Constants.JumpTypeTable + " " +
+			whereString +
+			" ORDER BY uniqueID";
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		List<object> types = new List<object>();
+
+		SelectJumpTypes type;
+		if(allJumpsName != "") {
+			type = new SelectJumpTypes(allJumpsName);
+			types.Add(type);
+		}
+
+		while(reader.Read()) {
+			if(onlyName) {
+				type = new SelectJumpTypes(reader[1].ToString());
+			} else {
+				type = new SelectJumpTypes(
+						Convert.ToInt32(reader[0]), 	//uniqueID
+						reader[1].ToString(),		//nameEnglish
+						Util.IntToBool(Convert.ToInt32(reader[2].ToString())), 	//startIn
+						Util.IntToBool(Convert.ToInt32(reader[3].ToString())), 	//hasWeight
+						reader[4].ToString()); 		//description
+			}
+			types.Add(type);
+		}
+
+		reader.Close();
+		closeIfNeeded(dbconOpened);
+
+		return types;
+	}
+	//on newly cereated code use above method
 	public static string[] SelectJumpTypes(bool dbconOpened, string allJumpsName, string filter, bool onlyName) 
 	{
 		//allJumpsName: add and "allJumpsName" value
@@ -247,11 +304,11 @@ class SqliteJumpType : Sqlite
 		//	"nonTC" only not with previous fall
 		//	used in gui/stats.cs
 		//onlyName: return only type name
-	
+
 		string whereString = "";
 		if(filter == "TC") { whereString = " WHERE startIn == 0 "; }
 		else if(filter == "nonTC") { whereString = " WHERE startIn == 1 "; }
-	
+
 		if(! dbconOpened)	
 			Sqlite.Open();
 
@@ -259,7 +316,7 @@ class SqliteJumpType : Sqlite
 			" FROM " + Constants.JumpTypeTable + " " +
 			whereString +
 			" ORDER BY uniqueID";
-		
+
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -309,6 +366,51 @@ class SqliteJumpType : Sqlite
 		return myTypes;
 	}
 
+	//use SelectJumpTypes object. Since 1.6.3
+	public static List<object> SelectJumpRjTypesNew(string allJumpsName, bool onlyName) 
+	{
+		Sqlite.Open();
+		dbcmd.CommandText = "SELECT * " +
+			" FROM " + Constants.JumpRjTypeTable + " " +
+			" ORDER BY uniqueID";
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		List<object> types = new List<object>();
+
+		SelectJumpRjTypes type;
+		if(allJumpsName != "") {
+			type = new SelectJumpRjTypes(allJumpsName);
+			types.Add(type);
+		}
+
+		while(reader.Read()) {
+			if(onlyName) {
+				type = new SelectJumpRjTypes(reader[1].ToString());
+			} else {
+				type = new SelectJumpRjTypes(
+						Convert.ToInt32(reader[0]), 	//uniqueID
+						reader[1].ToString(),		//nameEnglish
+						Util.IntToBool(Convert.ToInt32(reader[2].ToString())), 	//startIn
+						Util.IntToBool(Convert.ToInt32(reader[3].ToString())), 	//hasWeight
+						Util.IntToBool(Convert.ToInt32(reader[4].ToString())), 	//jumpsLimited
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[5].ToString())), 	//fixedValue
+						reader[6].ToString() 		//description
+					    );
+			}
+			types.Add(type);
+		}
+
+		reader.Close();
+		Sqlite.Close();
+
+		return types;
+	}
+	//on newly cereated code use above method
 	public static string[] SelectJumpRjTypes(string allJumpsName, bool onlyName) 
 	{
 		Sqlite.Open();
