@@ -22,10 +22,20 @@ using System;
 using System.Data;
 using System.IO;
 using Mono.Data.Sqlite;
+using System.Collections; //ArrayList
 
 
 class SqlitePreferences : Sqlite
 {
+	public const string EncoderExerciseIDGravitatory = "encoderExerciseIDGravitatory";
+	public const string EncoderExerciseIDInertial = "encoderExerciseIDInertial";
+	public const string EncoderContractionGravitatory = "encoderContractionGravitatory";
+	public const string EncoderContractionInertial = "encoderContractionInertial";
+	public const string EncoderLateralityGravitatory = "encoderLateralityGravitatory";
+	public const string EncoderLateralityInertial = "encoderLateralityInertial";
+	public const string EncoderMassGravitatory = "encoderMassGravitatory";
+	public const string EncoderWeightsInertial = "encoderWeightsInertial";
+
 	protected internal static new void createTable()
 	{
 		dbcmd.CommandText = 
@@ -50,6 +60,10 @@ class SqlitePreferences : Sqlite
 				else
 					Insert ("chronopicPort", Constants.ChronopicDefaultPortLinux, dbcmdTr);
 
+				//appearance
+				Insert ("maximized", Preferences.MaximizedTypes.NO.ToString(), dbcmdTr);
+				Insert ("personWinHide", "False", dbcmdTr);
+				Insert ("encoderCaptureShowOnlyBars", "False", dbcmdTr);
 				Insert ("digitsNumber", "3", dbcmdTr);
 				Insert ("showPower", "True", dbcmdTr);
 				Insert ("showStiffness", "True", dbcmdTr);
@@ -95,12 +109,34 @@ class SqlitePreferences : Sqlite
 				Insert ("encoderCaptureMinHeightInertial", "5", dbcmdTr);
 				Insert ("encoderCaptureCheckFullyExtended", "True", dbcmdTr);
 				Insert ("encoderCaptureCheckFullyExtendedValue", "4", dbcmdTr);
+				Insert ("encoderCaptureBarplotFontSize", "14", dbcmdTr);
 				Insert ("encoderShowStartAndDuration", "False", dbcmdTr);
+				Insert ("encoderCaptureCutByTriggers", "False", dbcmdTr);
 				Insert ("encoderPropulsive", "True", dbcmdTr);
 				Insert ("encoderSmoothEccCon", "0.6", dbcmdTr);
 				Insert ("encoderSmoothCon", "0.7", dbcmdTr);
 				Insert ("encoder1RMMethod", Constants.Encoder1RMMethod.WEIGHTED2.ToString(), dbcmdTr);
 
+				ArrayList encoderExercises =
+					SqliteEncoder.SelectEncoderExercises(true, -1, true);
+
+				if(encoderExercises.Count > 0) {
+					EncoderExercise ex = (EncoderExercise) encoderExercises[0];
+					Insert (EncoderExerciseIDGravitatory, ex.uniqueID.ToString());
+					Insert (EncoderExerciseIDInertial, ex.uniqueID.ToString());
+				}
+				else {
+					Insert (EncoderExerciseIDGravitatory, "1");
+					Insert (EncoderExerciseIDInertial, "1");
+				}
+
+				Insert (EncoderContractionGravitatory, Constants.Concentric);
+				Insert (EncoderContractionInertial, Constants.EccentricConcentric);
+				Insert (EncoderLateralityGravitatory, "RL");
+				Insert (EncoderLateralityInertial, "RL");
+				Insert (EncoderMassGravitatory, "10");
+				Insert (EncoderWeightsInertial, "0");
+
 				Insert ("videoDevice", "0", dbcmdTr); //first
 				Insert ("inertialmomentum", "0.01", dbcmdTr);
 				Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale(), dbcmdTr);
@@ -108,6 +144,7 @@ class SqlitePreferences : Sqlite
 				Insert ("useHeightsOnJumpIndexes", "True", dbcmdTr);
 				Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), dbcmdTr); 
 				Insert ("email", "", dbcmdTr);
+				Insert ("muteLogs", "False", dbcmdTr);
 				
 				//removed on 1.37
 				//Insert ("encoderConfiguration", new EncoderConfiguration().ToStringOutput(EncoderConfiguration.Outputs.SQL), dbcmdTr);
@@ -200,8 +237,13 @@ class SqlitePreferences : Sqlite
 			//LogB.Information(reader[0].ToString() + ":" + reader[1].ToString());
 
 	 		//these are sent to preferences window
-			if(reader[0].ToString() == "digitsNumber")
-				preferences.digitsNumber = Convert.ToInt32(reader[1].ToString());
+			if(reader[0].ToString() == "maximized")
+				preferences.maximized = (Preferences.MaximizedTypes)
+					Enum.Parse(typeof(Preferences.MaximizedTypes), reader[1].ToString());
+			else if(reader[0].ToString() == "personWinHide")
+				preferences.personWinHide = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == "encoderCaptureShowOnlyBars")
+				preferences.encoderCaptureShowOnlyBars = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showPower")
 				preferences.showPower = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showStiffness")
@@ -214,8 +256,6 @@ class SqlitePreferences : Sqlite
 				preferences.showQIndex = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showDjIndex")
 				preferences.showDjIndex = reader[1].ToString() == "True";
-			else if(reader[0].ToString() == "askDeletion")
-				preferences.askDeletion = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "weightStatsPercent")
 				preferences.weightStatsPercent = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "heightPreferred")
@@ -241,8 +281,12 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == "encoderAutoSaveCurve")
 				preferences.encoderAutoSaveCurve = (Constants.EncoderAutoSaveCurve) 
 					Enum.Parse(typeof(Constants.EncoderAutoSaveCurve), reader[1].ToString()); 
+			else if(reader[0].ToString() == "encoderCaptureBarplotFontSize")
+				preferences.encoderCaptureBarplotFontSize = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "encoderShowStartAndDuration")
 				preferences.encoderShowStartAndDuration = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == "encoderCaptureCutByTriggers")
+				preferences.encoderCaptureCutByTriggers = reader[1].ToString() == "True";
 			//encoder other
 			else if(reader[0].ToString() == "encoderPropulsive")
 				preferences.encoderPropulsive = reader[1].ToString() == "True";
@@ -293,6 +337,13 @@ class SqlitePreferences : Sqlite
 				preferences.thresholdRuns = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "thresholdOther")
 				preferences.thresholdOther = Convert.ToInt32(reader[1].ToString());
+			//advanced tab
+			else if(reader[0].ToString() == "digitsNumber")
+				preferences.digitsNumber = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "askDeletion")
+				preferences.askDeletion = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == "muteLogs")
+				preferences.muteLogs = reader[1].ToString() == "True";
 
 			else if(reader[0].ToString() == "machineID")
 				preferences.machineID = reader[1].ToString();
