@@ -25,6 +25,7 @@ using System.Collections; //ArrayList
 using System.Collections.Generic; //List<T>
 using System.Diagnostics; 	//for detect OS
 using System.IO; 		//for detect OS
+using System.Globalization; 	//Unicode
 
 //this class tries to be a space for methods that are used in different classes
 public class Util
@@ -278,6 +279,55 @@ public class Util
 		return false;
 	}
 
+	public static string MakeValidSQLAndFileName(string name)
+	{
+		name = MakeValidFileName(MakeValidSQL(name));
+		name = name.Replace(@"\","");
+
+		return name;
+	}
+	//http://stackoverflow.com/a/847251
+	public static string MakeValidFileName(string name)
+	{
+		string invalidChars = System.Text.RegularExpressions.Regex.Escape( new string( System.IO.Path.GetInvalidFileNameChars() ) );
+		string invalidRegStr = string.Format( @"([{0}]*\.+$)|([{0}]+)", invalidChars );
+
+		return System.Text.RegularExpressions.Regex.Replace( name, invalidRegStr, "_" );
+	}
+	public static string MakeValidSQL(string str)
+	{
+		/*
+		 * This code sometimes does not work with '
+		 * below code is better
+		char [] trimChars = {'"','\''};
+		return str.Trim(trimChars);
+		*/
+
+		StringBuilder myStringBuilder = new StringBuilder(str);
+		myStringBuilder.Replace("'", "");
+		myStringBuilder.Replace("\"", "");
+		return myStringBuilder.ToString();
+	}
+
+	//to pass latin chars to JSON
+	//http://stackoverflow.com/a/249126
+	public static string RemoveAccents(string text)
+	{
+		var normalizedString = text.Normalize(NormalizationForm.FormD);
+		var stringBuilder = new StringBuilder();
+
+		foreach (var c in normalizedString)
+		{
+			var unicodeCategory = CharUnicodeInfo.GetUnicodeCategory(c);
+			if (unicodeCategory != UnicodeCategory.NonSpacingMark)
+			{
+				stringBuilder.Append(c);
+			}
+		}
+
+		return stringBuilder.ToString().Normalize(NormalizationForm.FormC);
+	}
+
 	public static string RemoveTilde(string myString) 
 	{
 		StringBuilder myStringBuilder = new StringBuilder(myString);
@@ -304,7 +354,7 @@ public class Util
 		myStringBuilder.Replace(".", " ");
 		return myStringBuilder.ToString();
 	}
-	
+
 	public static string RemoveTab(string myString) 
 	{
 		StringBuilder myStringBuilder = new StringBuilder(myString);
@@ -874,6 +924,45 @@ public class Util
 		}
 	}
 	
+	/*
+	 * force sensor suff ------------------>
+	 */
+
+	//to store force sensor data and graphs
+	public static string GetForceSensorDir()
+	{
+		return Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump" + Path.DirectorySeparatorChar + "forceSensor");
+	}
+	public static void CreateForceSensorDirIfNeeded ()
+	{
+		string dir = GetForceSensorDir();
+		if( ! Directory.Exists(dir)) {
+			Directory.CreateDirectory (dir);
+			LogB.Information ("created dir:", dir);
+		}
+	}
+
+	//forceSensor organized by sessions.
+	public static string GetForceSensorSessionDir (int sessionID)
+	{
+		return GetForceSensorDir() + Path.DirectorySeparatorChar + sessionID.ToString();
+	}
+	public static void CreateForceSensorSessionDirIfNeeded (int sessionID)
+	{
+		string dir = GetForceSensorSessionDir(sessionID);
+		if( ! Directory.Exists(dir)) {
+			Directory.CreateDirectory (dir);
+			LogB.Information ("created dir:", dir);
+		}
+	}
+
+	/*
+	 * <--------------- end of force sensor suff
+	 */
+
+
 	//videos ar organized by sessions. Photos no.	
 	public static string GetVideoSessionDir (int sessionID) {
 		return GetVideosDir() + Path.DirectorySeparatorChar + sessionID.ToString();
@@ -955,6 +1044,12 @@ public class Util
 
 	/********** end of multimedia paths ************/
 	
+	public static string GetThemeDir() {
+		return Path.Combine(GetDataDir(), "theme");
+	}
+	public static string GetThemeFile() {
+		return Path.Combine(GetThemeDir(), "gtk-2.0" + Path.DirectorySeparatorChar + "gtkrc");
+	}
 
 	/********** start of encoder paths ************/
 
@@ -962,9 +1057,29 @@ public class Util
 		return Path.Combine(Path.GetTempPath(), "encoder_set_export.csv");
 	}
 
+	public static string GetEncoderTriggerFileName() {
+		return Path.Combine(Path.GetTempPath(), "encoder_trigger.txt");
+	}
+	public static string GetEncoderTriggerDateTimeFileName() {
+		return Path.Combine(Path.GetTempPath(), "encoder_trigger_" + UtilDate.ToFile(DateTime.Now) + ".txt");
+	}
+
 	/********** end of encoder paths ************/
 
 
+	/********** start of rfid paths ************/
+
+	public static string GetRFIDCaptureScript() {
+		return Path.Combine(GetPrefixDir(), "bin/chronojump_rfid_capture.py");
+	}
+	public static string GetRFIDCapturedFile() {
+		return Path.Combine(Path.GetTempPath(), "chronojump_rfid.txt");
+	}
+
+
+	/********** end of rfid paths ************/
+
+
 	public static string GetManualDir() {
 		//we are on:
 		//lib/chronojump/ (Unix) or bin/ (win32)
