@@ -21,6 +21,7 @@
 using System;
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
+using Mono.Unix;
 
 //this class tries to be a space for methods that are used in different classes
 public class UtilDate
@@ -58,7 +59,6 @@ public class UtilDate
 		if(date == null || date == "")
 			return DateTime.Now;
 
-
 		/*
 		   maybe date format is before 0.72 (d/m/Y)
 		   this is still here and not in a standalone conversion
@@ -87,4 +87,20 @@ public class UtilDate
 		return dt;
 	}
 
+	public static string GetCurrentYearMonthStr()
+	{
+		DateTime dt = DateTime.Now;
+
+		return UtilAll.DigitsCreate(dt.Year,4) + "-" + Catalog.GetString(dt.ToString("MMMM"));
+	}
+
+	//get a string of last month
+	public static string GetCurrentYearLastMonthStr()
+	{
+		DateTime dt = DateTime.Now;
+		dt = dt.AddMonths(-1);
+
+		return UtilAll.DigitsCreate(dt.Year,4) + "-" + Catalog.GetString(dt.ToString("MMMM"));
+	}
+
 }
