@@ -233,6 +233,29 @@ public class UtilEncoder
 	
 	/********** end of encoder paths ************/
 
+
+	/********** start of r-scripts paths ************/
+
+	public static string GetSprintPath() {
+		return System.IO.Path.Combine(Util.GetDataDir(), "r-scripts");
+	}
+	public static string GetSprintPhotocellsScript() {
+		return System.IO.Path.Combine(GetSprintPath(), "sprintPhotocells.R");
+	}
+
+	public static string GetSprintImage() {
+		return System.IO.Path.Combine(Path.GetTempPath(), "sprintGraph.png");
+	}
+
+	public static string GetmifPath() {
+		return System.IO.Path.Combine(Util.GetDataDir(), "r-scripts");
+	}
+	public static string GetmifScript() {
+		return System.IO.Path.Combine(GetSprintPath(), "maximumIsometricForce.R");
+	}
+
+	/********** end of r-scripts paths ************/
+
 	private static string changeSpaceToSpaceMark(string myString) 
 	{
 		StringBuilder myStringBuilder = new StringBuilder(myString);
@@ -294,10 +317,20 @@ public class UtilEncoder
 		while ( ! ( File.Exists(outputFileCheck) || CancelRScript) );
 	}
 	*/
-	
-	public static EncoderGraphROptions PrepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate, bool debug, bool crossValidate) 
+
+	//R plots on Windows using Cairo, need to know if it's windows or not
+	public static string OperatingSystemForRGraphs()
 	{
 		string operatingSystem = "Linux";
+		if (UtilAll.IsWindows())
+			operatingSystem = "Windows";
+
+		return operatingSystem;
+	}
+
+	public static EncoderGraphROptions PrepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate, bool debug, bool crossValidate, string triggerStr)
+	{
+		string operatingSystem = OperatingSystemForRGraphs();
 			
 		title = Util.RemoveBackSlash(title);
 		title = Util.RemoveChar(title, '\''); 
@@ -314,7 +347,6 @@ public class UtilEncoder
 			//es.OutputData2 = es.OutputData2.Replace("\\","/");
 			//es.SpecialData = es.SpecialData.Replace("\\","/");
 			es.EncoderTempPath = es.EncoderTempPath.Replace("\\","/");
-			operatingSystem = "Windows";
 		}
 		
 	 	//if translators add ";", it will be converted to ','
@@ -351,10 +383,27 @@ public class UtilEncoder
 				title, operatingSystem,
 				Util.StringArrayToString(Constants.EncoderEnglishWords,";"),
 				Util.StringArrayToString(encoderTranslatedWordsOK,";"),
-				debug, crossValidate
+				debug, crossValidate, triggerStr
 				);
 	}
 
+	public static string RProcessBinURL()
+	{
+		string pBin="Rscript";
+		if (UtilAll.IsWindows())
+		{
+			//on Windows we need the \"str\" to call without problems in path with spaces
+			pBin = "\"" + System.IO.Path.Combine(Util.GetPrefixDir(), "bin" + Path.DirectorySeparatorChar + "Rscript.exe") + "\"";
+		}
+		else if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.MACOSX)
+		{
+			pBin = Constants.RScriptOSX;
+		}
+
+		LogB.Information("pBin:", pBin);
+		return pBin;
+	}
+
 
 	//Inertia Momentum
 	//TODO: make this work with encoderRProc
@@ -609,12 +658,14 @@ public class UtilEncoder
 
 
 	public static string EncoderSaveCurve(string fileNameSignal, 
-			int start, int duration, 
+			int start, int duration,
 			int inertialCheckStart, int inertialCheckDuration, 
 			bool inertialCheckPositive, //has to be positive (true) or negative (false)
 			int sessionID, int uniqueID, string personName, string timeStamp, int curveIDMax) 
 	{
 		string contents = Util.ReadFile(fileNameSignal, false);
+
+		LogB.Information("EncoderSaveCurve start:" + start.ToString() + "; duration:" + duration.ToString());
 		
 			
 		/*
@@ -747,6 +798,8 @@ public class UtilEncoder
 							Constants.EncoderConfigurationNames.LINEARONPLANE));
 				list.Add(new EncoderConfiguration(
 							Constants.EncoderConfigurationNames.LINEARONPLANEWEIGHTDIFFANGLE));
+				list.Add(new EncoderConfiguration(
+							Constants.EncoderConfigurationNames.LINEARONPLANEWEIGHTDIFFANGLEMOVPULLEY));
 			} else {
 				list.Add(new EncoderConfiguration(
 							Constants.EncoderConfigurationNames.LINEARINERTIAL));
@@ -790,6 +843,8 @@ public class UtilEncoder
 							Constants.EncoderConfigurationNames.ROTARYAXISINERTIALLATERAL));
 				list.Add(new EncoderConfiguration(
 							Constants.EncoderConfigurationNames.ROTARYAXISINERTIALMOVPULLEY));
+				list.Add(new EncoderConfiguration(
+							Constants.EncoderConfigurationNames.ROTARYAXISINERTIALLATERALMOVPULLEY));
 			}
 		}
 		return list;
